version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_analysis.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      bes1992_analysis.do                             *;
*       Date:           January 31, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:      	Replicate main results regarding voter utility	*;
*						for the substantive application in Chapter 10 	*;
*						looking at ideology, gender, and party support 	*;
*						in the 1992 UK elections						*;
* 	    Input File:     bes1992_small.dta                        		*;
*       Output File:    bes1992_analysis.log                            *;
*       Data Output:    none                                            *;             
*       Previous file:  bes1992_small.dta								*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*		Do men and women hold different positions on our three policy	*;
*		dimensions?														*;
*     ****************************************************************  *;

sort female;

* Defense;

sum defense_self;
scalar defense_sd = r(sd);
di defense_sd;

sum defense_self if female==0;
scalar defense_male = r(mean);
di defense_male;

sum defense_self if female==1;
scalar defense_fem = r(mean);
di defense_fem;

di defense_fem-defense_male;
di ((defense_fem-defense_male)/defense_sd)*100;

ttest defense_self, by(female);

* Government Intervention;

sum gov_intervention_self2;
scalar gov_sd = r(sd);
di gov_sd;

sum gov_intervention_self2 if female==0;
scalar gov_male = r(mean);
di gov_male;

sum gov_intervention_self2 if female==1;
scalar gov_fem = r(mean);
di gov_fem;

di gov_fem-gov_male;
di ((gov_fem-gov_male)/gov_sd)*100;

ttest gov_intervention_self2, by(female);

* Women's Rights;

sum womensrights_self;
scalar women_sd = r(sd);
di women_sd;

sum womensrights_self if female==0;
scalar women_male = r(mean);
di women_male;

sum womensrights_self if female==1;
scalar women_fem = r(mean);
di women_fem;

di women_fem-women_male;
di ((women_fem-women_male)/women_sd)*100;

ttest womensrights_self, by(female);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 10.4 in Chapter 10				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

*     ****************************************************************  *;
*		Number of individuals											*;
*     ****************************************************************  *;

di e(N)/3;

*     ****************************************************************  *;
*		Compare coefficients on ideological distance variables			*;
*     ****************************************************************  *;

di ((_b[defense_distance]/_b[gov_intervention_distance])-1)*100;

di ((_b[defense_distance]/_b[less_womensrights_distance])-1)*100;

lincom _b[defense_distance]-_b[gov_intervention_distance];

lincom _b[defense_distance]-_b[less_womensrights_distance];

*     ****************************************************************  *;
*		Modifying effect of gender on salience of defense				*;
*     ****************************************************************  *;

lincom _b[female_defense], level(90);
lincom _b[female_defense], level(95);

*     ****************************************************************  *;
*		Effect of increasing distance wrt defense on voter utility		*;
*     ****************************************************************  *;

* Men;

lincom _b[defense_distance];

* Women;

lincom _b[defense_distance]+_b[female_defense];

* How much smaller is effect for women?;

di (((_b[defense_distance]+_b[female_defense])/_b[defense_distance])-1)*100;

*     ****************************************************************  *;
*		Modifying effect of gender on salience of government 			*;
*		intervention													*;
*     ****************************************************************  *;

lincom _b[female_gov_intervention], level(90);
lincom _b[female_gov_intervention], level(95);

*     ****************************************************************  *;
*		Effect of increasing distance wrt government intervention on 	*;
*		voter utility													*;
*     ****************************************************************  *;

lincom _b[gov_intervention_distance], level(95);

lincom _b[gov_intervention_distance]+_b[female_gov_intervention], level(95);

di (((_b[gov_intervention_distance]+_b[female_gov_intervention])/_b[gov_intervention_distance])-1)*100;

*     ****************************************************************  *;
*		Modifying effect of gender on salience of women's rights		*;
*     ****************************************************************  *;

lincom _b[female_less_womensrights], level(90);
lincom _b[female_less_womensrights], level(95);

*     ****************************************************************  *;
*		Effect of increasing distance wrt women's rights on voter 		*;
*		utility															*;
*     ****************************************************************  *;

lincom _b[less_womensrights_distance];

lincom _b[less_womensrights_distance]+_b[female_less_womensrights];

di (((_b[less_womensrights_distance]+_b[female_less_womensrights])/_b[less_womensrights_distance])-1)*100;

*     ****************************************************************  *;
*		No difference in salience across issues for women				*;
*     ****************************************************************  *;

lincom (_b[gov_intervention_distance]+_b[female_gov_intervention])-(_b[defense_distance]+_b[female_defense]);

lincom (_b[gov_intervention_distance]+_b[female_gov_intervention])-(_b[less_womensrights_distance]+_b[female_less_womensrights]);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 10.1 in Stata showing how the 		*;
*		effect of a one unit increase in ideological distance on voter	*;
*		utility varies by gender for each of the three issue areas.		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Create a 9 x 6 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot3 = J(9, 6, .);
matrix coln plot3 = estimate lo_95 hi_95 se lo_90 hi_90 ;

*     ****************************************************************  *;
*		Grab information												*;
*     ****************************************************************  *;

* Defense;
* Men;

lincom _b[defense_distance], level(95);
matrix plot3[1,1]=r(estimate);
matrix plot3[1,2]=r(lb);
matrix plot3[1,3]=r(ub);
matrix plot3[1,4]=r(se);
lincom _b[defense_distance], level(90);
matrix plot3[1,5]=r(lb);
matrix plot3[1,6]=r(ub);

* Women;

lincom _b[defense_distance]+_b[female_defense], level(95);
matrix plot3[2,1]=r(estimate);
matrix plot3[2,2]=r(lb);
matrix plot3[2,3]=r(ub);
matrix plot3[2,4]=r(se);
lincom _b[defense_distance]+_b[female_defense], level(90);
matrix plot3[2,5]=r(lb);
matrix plot3[2,6]=r(ub);

* Interaction;

lincom _b[female_defense], level(95);
matrix plot3[3,1]=r(estimate);
matrix plot3[3,2]=r(lb);
matrix plot3[3,3]=r(ub);
matrix plot3[3,4]=r(se);
lincom _b[female_defense], level(90);
matrix plot3[3,5]=r(lb);
matrix plot3[3,6]=r(ub);

* Government Intervention;
* Men;

lincom _b[gov_intervention_distance], level(95);
matrix plot3[4,1]=r(estimate);
matrix plot3[4,2]=r(lb);
matrix plot3[4,3]=r(ub);
matrix plot3[4,4]=r(se);
lincom _b[gov_intervention_distance], level(90);
matrix plot3[4,5]=r(lb);
matrix plot3[4,6]=r(ub);

* Women;

lincom _b[gov_intervention_distance]+_b[female_gov_intervention], level(95);
matrix plot3[5,1]=r(estimate);
matrix plot3[5,2]=r(lb);
matrix plot3[5,3]=r(ub);
matrix plot3[5,4]=r(se);
lincom _b[gov_intervention_distance]+_b[female_gov_intervention], level(90);
matrix plot3[5,5]=r(lb);
matrix plot3[5,6]=r(ub);

* Interaction;

lincom _b[female_gov_intervention], level(95);
matrix plot3[6,1]=r(estimate);
matrix plot3[6,2]=r(lb);
matrix plot3[6,3]=r(ub);
matrix plot3[6,4]=r(se);
lincom _b[female_gov_intervention], level(90);
matrix plot3[6,5]=r(lb);
matrix plot3[6,6]=r(ub);

* Women's Rights;
* Men;

lincom _b[less_womensrights_distance], level(95);
matrix plot3[7,1]=r(estimate);
matrix plot3[7,2]=r(lb);
matrix plot3[7,3]=r(ub);
matrix plot3[7,4]=r(se);
lincom _b[less_womensrights_distance], level(90);
matrix plot3[7,5]=r(lb);
matrix plot3[7,6]=r(ub);

* Women;

lincom _b[less_womensrights_distance]+_b[female_less_womensrights], level(95);
matrix plot3[8,1]=r(estimate);
matrix plot3[8,2]=r(lb);
matrix plot3[8,3]=r(ub);
matrix plot3[8,4]=r(se);
lincom _b[less_womensrights_distance]+_b[female_less_womensrights], level(90);
matrix plot3[8,5]=r(lb);
matrix plot3[8,6]=r(ub);

* Interaction;

lincom _b[female_less_womensrights], level(95);
matrix plot3[9,1]=r(estimate);
matrix plot3[9,2]=r(lb);
matrix plot3[9,3]=r(ub);
matrix plot3[9,4]=r(se);
lincom _b[female_less_womensrights], level(90);
matrix plot3[9,5]=r(lb);
matrix plot3[9,6]=r(ub);


matrix list plot3;

*     ****************************************************************  *;
*		Produce Figure 10.1 using coefplot								*;
*     ****************************************************************  *;

coefplot (matrix(plot3[.,1]), se(plot3[.,4]) offset(0) lwidth(thick) 
		m(smcircle) msize(small) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))), 
		legend(off) xtitle("Effect Size", size(2)) level(95 90) 
		xlab(-1 -0.8 -0.6 -0.4 -0.2 0 0.2 0.4 0.6, tlcolor(black) labcolor(black) labsize(2) format(%9.1f) ) 		
		coeflabels(r1="Effect of Defense Distance among Men" r2="Effect of Defense Distance among Women" 
		r3="Difference:Defense Distance x Female" r4="Effect of Government Intervention Distance among Men" 
		r5="Effect of Government Intervention Distance among Women" r6="Difference: Government Intervention x Female"
		r7="Effect of Women's Rights Distance among Men" r8="Effect of Women's Rights Distance among Women" r9="Difference: Women's Rights x Female", 	
		tlcolor(black) labcolor(black) labsize(2)) 
		yscale(noline) xscale(noline) mlabel format(%9.2f) mlabposition(12) mlabgap(*2) mlabsize(2)  
		xline(0, lcolor(gray)) scheme(burd);
		

*     ****************************************************************  *;
*		Gender-Genderation Gap Possibility								*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 postwar_birth1 postwar_birth3 female_postwar1 female_postwar3  workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

lincom _b[female1];

lincom _b[female1]+_b[female_postwar1];

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 10.2 in Stata showing how the 		*;
*		effect of being female on voter utility varies across the 		*;
*		observed range of values for Government Intervention when 		*;
*		Defense and Women's Rigts are set at their mean values for the	*;
*		Conservative Party.												*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get some information that we'll want.							*;
*     ****************************************************************  *;

tab defense_distance;
tab defense_distance if female==0;
tab defense_distance if female==1;

tab gov_intervention_distance if party_alternative==1;
tab gov_intervention_distance if party_alternative==1 & female==0;
tab gov_intervention_distance if party_alternative==1 & female==1;

tab less_womensrights_distance;
tab less_womensrights_distance if female==0;
tab less_womensrights_distance if female==1;

sum defense_distance if party_alternative==1, detail;
scalar defense_mean_cons=r(mean);
di defense_mean_cons;

sum less_womensrights_distance if party_alternative==1,detail;
scalar womensrights_mean_cons=r(mean);
di womensrights_mean_cons;

*     ****************************************************************  *;
*		Estimate model													*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

vce;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar b7=b[1,7];
scalar b8=b[1,8];
scalar b9=b[1,9];
scalar b10=b[1,10];
scalar b11=b[1,11];
scalar b12=b[1,12];
scalar b13=b[1,13];
scalar b14=b[1,14];
scalar b15=b[1,15];
scalar b16=b[1,16];
scalar b17=b[1,17];
scalar b18=b[1,18];
scalar b19=b[1,19];
scalar b20=b[1,20];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar varb6=V[6,6];
scalar varb7=V[7,7];

scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb7b2=V[7,2];
scalar covb7b4=V[7,4];
scalar covb7b6=V[7,6];
scalar covb2b4=V[2,4];
scalar covb2b6=V[2,6];
scalar covb4b6=V[4,6];

scalar list b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18 b19 b20 varb1 varb2 varb3 varb4 varb5 varb6 varb7 covb1b3 covb7b2 covb7b4 covb7b6 covb2b4 covb2b6 covb4b6;

*     ****************************************************************  *;
*		Government intervention											*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3   workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3 , group(respondent_id);

*     ****************************************************************  *;
*		Get effect of being female for distinct values of Government	*;
*		Intervention using Stata's lincom command.						*;
*     ****************************************************************  *;

lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*0+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*1+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*2+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*3+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*4+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*5+_b[female_less_womensrights]*womensrights_mean_cons;
lincom _b[female1]+_b[female_defense]*defense_mean_cons+_b[female_gov_intervention]*6+_b[female_less_womensrights]*womensrights_mean_cons;

*     ****************************************************************  *;
*		Now get effect of being female manually, treating Government	*;
*		Intervention as continuous										*;
*     ****************************************************************  *;

generate MV=(_n-1)/10;

replace MV=. if _n>62;

gen conbx_gov=b7+b2*defense_mean_cons+b4*MV+b6*womensrights_mean_cons if _n<62;

gen consx_gov=sqrt(varb7+varb2*(defense_mean_cons^2)+varb4*(MV^2)		
		+varb6*(womensrights_mean_cons^2)+2*defense_mean_cons*covb7b2+2*MV*covb7b4+2*womensrights_mean_cons*covb7b6
		+2*defense_mean_cons*MV*covb2b4+2*womensrights_mean_cons*defense_mean_cons*covb2b6+2*womensrights_mean_cons*MV*covb4b6) if _n<62;
				
scalar z=invnormal(0.975);
di z;

gen lowerx_gov=conbx_gov-(z*consx_gov);

gen upperx_gov=conbx_gov+(z*consx_gov);

*     ****************************************************************  *;
*		Produce Figure 10.2												*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line upperx_gov MV, color(ebblue) clpattern(longdash) 
		|| line lowerx_gov MV, color(ebblue) clpattern(longdash)  
		|| line conbx_gov MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) xtitle("Government Intervention Distance", size(2)) 	
			ytitle("Percentage of Observations", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,  
		 	xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-2.5 -2 -1.5 -1 -0.5 0 0.5 1 1.5 2 2.5, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);	    	

*     ****************************************************************  *;
*		Produce Figure 10.3 was produced in pgfplots, not Stata			*;
*		However, we did need information for the histograms on the base	*;
*		of Figure 10.3a and 10.3b.										*; 
*     ****************************************************************  *;

tab party_alternative;

keep if party_alternative==1;

keep defense_distance gov_intervention_distance less_womensrights_distance;

drop if defense_distance==.;
drop if gov_intervention_distance==.;
drop if less_womensrights_distance==.;

*     ****************************************************************  *;
*		Figure 10.3a - When women's rights are 0						*;
*     ****************************************************************  *;

sum;
scalar total=r(N);
di total;

sort less_womensrights_distance defense_distance gov_intervention_distance;

sum if defense_distance==0 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent000=(r(N)/total)*100;
di percent000; 

sum if defense_distance==0 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent010=(r(N)/total)*100;
di percent010;

sum if defense_distance==0 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent020=(r(N)/total)*100;
di percent020;

sum if defense_distance==0 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent030=(r(N)/total)*100;
di percent030;

sum if defense_distance==0 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent040=(r(N)/total)*100;
di percent040; 

sum if defense_distance==0 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent050=(r(N)/total)*100;
di percent050; 

sum if defense_distance==0 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent060=(r(N)/total)*100;
di percent060;


sum if defense_distance==1 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent100=(r(N)/total)*100;
di percent100; 

sum if defense_distance==1 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent110=(r(N)/total)*100;
di percent110;

sum if defense_distance==1 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent120=(r(N)/total)*100;
di percent120;

sum if defense_distance==1 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent130=(r(N)/total)*100;
di percent130;

sum if defense_distance==1 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent140=(r(N)/total)*100;
di percent140; 

sum if defense_distance==1 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent150=(r(N)/total)*100;
di percent150; 

sum if defense_distance==1 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent160=(r(N)/total)*100;
di percent160;


sum if defense_distance==2 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent200=(r(N)/total)*100;
di percent200; 

sum if defense_distance==2 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent210=(r(N)/total)*100;
di percent210;

sum if defense_distance==2 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent220=(r(N)/total)*100;
di percent220;

sum if defense_distance==2 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent230=(r(N)/total)*100;
di percent230;

sum if defense_distance==2 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent240=(r(N)/total)*100;
di percent240; 

sum if defense_distance==2 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent250=(r(N)/total)*100;
di percent250; 

sum if defense_distance==2 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent260=(r(N)/total)*100;
di percent260;


sum if defense_distance==3 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent300=(r(N)/total)*100;
di percent300; 

sum if defense_distance==3 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent310=(r(N)/total)*100;
di percent310;

sum if defense_distance==3 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent320=(r(N)/total)*100;
di percent320;

sum if defense_distance==3 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent330=(r(N)/total)*100;
di percent330;

sum if defense_distance==3 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent340=(r(N)/total)*100;
di percent340; 

sum if defense_distance==3 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent350=(r(N)/total)*100;
di percent350; 

sum if defense_distance==3 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent360=(r(N)/total)*100;
di percent360;  


sum if defense_distance==4 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent400=(r(N)/total)*100;
di percent400; 

sum if defense_distance==4 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent410=(r(N)/total)*100;
di percent410;

sum if defense_distance==4 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent420=(r(N)/total)*100;
di percent420;

sum if defense_distance==4 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent430=(r(N)/total)*100;
di percent430;

sum if defense_distance==4 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent440=(r(N)/total)*100;
di percent440; 

sum if defense_distance==4 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent450=(r(N)/total)*100;
di percent450; 

sum if defense_distance==4 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent460=(r(N)/total)*100;
di percent460;


sum if defense_distance==5 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent500=(r(N)/total)*100;
di percent500; 

sum if defense_distance==5 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent510=(r(N)/total)*100;
di percent510;

sum if defense_distance==5 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent520=(r(N)/total)*100;
di percent520;

sum if defense_distance==5 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent530=(r(N)/total)*100;
di percent530;

sum if defense_distance==5 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent540=(r(N)/total)*100;
di percent540; 

sum if defense_distance==5 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent550=(r(N)/total)*100;
di percent550; 

sum if defense_distance==5 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent560=(r(N)/total)*100;
di percent560; 


sum if defense_distance==6 & gov_intervention_distance==0 & less_womensrights_distance==0;
scalar percent600=(r(N)/total)*100;
di percent600; 

sum if defense_distance==6 & gov_intervention_distance==1 & less_womensrights_distance==0;
scalar percent610=(r(N)/total)*100;
di percent610;

sum if defense_distance==6 & gov_intervention_distance==2 & less_womensrights_distance==0;
scalar percent620=(r(N)/total)*100;
di percent620;

sum if defense_distance==6 & gov_intervention_distance==3 & less_womensrights_distance==0;
scalar percent630=(r(N)/total)*100;
di percent630;

sum if defense_distance==6 & gov_intervention_distance==4 & less_womensrights_distance==0;
scalar percent640=(r(N)/total)*100;
di percent640; 

sum if defense_distance==6 & gov_intervention_distance==5 & less_womensrights_distance==0;
scalar percent650=(r(N)/total)*100;
di percent650; 

sum if defense_distance==6 & gov_intervention_distance==6 & less_womensrights_distance==0;
scalar percent660=(r(N)/total)*100;
di percent660;

*     ****************************************************************  *;
*		Figure 10.3b - When women's rights are 1						*;
*     ****************************************************************  *;

sort less_womensrights_distance defense_distance gov_intervention_distance;

sum if defense_distance==0 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent001=(r(N)/total)*100;
di percent001; 

sum if defense_distance==0 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent011=(r(N)/total)*100;
di percent011;

sum if defense_distance==0 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent021=(r(N)/total)*100;
di percent021;

sum if defense_distance==0 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent031=(r(N)/total)*100;
di percent031;

sum if defense_distance==0 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent041=(r(N)/total)*100;
di percent041; 

sum if defense_distance==0 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent051=(r(N)/total)*100;
di percent051; 

sum if defense_distance==0 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent061=(r(N)/total)*100;
di percent061;


sum if defense_distance==1 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent101=(r(N)/total)*100;
di percent101; 

sum if defense_distance==1 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent111=(r(N)/total)*100;
di percent111;

sum if defense_distance==1 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent121=(r(N)/total)*100;
di percent121;

sum if defense_distance==1 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent131=(r(N)/total)*100;
di percent131;

sum if defense_distance==1 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent141=(r(N)/total)*100;
di percent141; 

sum if defense_distance==1 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent151=(r(N)/total)*100;
di percent151; 

sum if defense_distance==1 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent161=(r(N)/total)*100;
di percent161;


sum if defense_distance==2 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent201=(r(N)/total)*100;
di percent201; 

sum if defense_distance==2 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent211=(r(N)/total)*100;
di percent211;

sum if defense_distance==2 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent221=(r(N)/total)*100;
di percent221;

sum if defense_distance==2 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent231=(r(N)/total)*100;
di percent231;

sum if defense_distance==2 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent241=(r(N)/total)*100;
di percent241; 

sum if defense_distance==2 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent251=(r(N)/total)*100;
di percent251; 

sum if defense_distance==2 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent261=(r(N)/total)*100;
di percent261;


sum if defense_distance==3 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent301=(r(N)/total)*100;
di percent301; 

sum if defense_distance==3 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent311=(r(N)/total)*100;
di percent311;

sum if defense_distance==3 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent321=(r(N)/total)*100;
di percent321;

sum if defense_distance==3 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent331=(r(N)/total)*100;
di percent331;

sum if defense_distance==3 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent341=(r(N)/total)*100;
di percent341; 

sum if defense_distance==3 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent351=(r(N)/total)*100;
di percent351; 

sum if defense_distance==3 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent361=(r(N)/total)*100;
di percent361;  


sum if defense_distance==4 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent401=(r(N)/total)*100;
di percent401; 

sum if defense_distance==4 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent411=(r(N)/total)*100;
di percent411;

sum if defense_distance==4 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent421=(r(N)/total)*100;
di percent421;

sum if defense_distance==4 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent431=(r(N)/total)*100;
di percent431;

sum if defense_distance==4 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent441=(r(N)/total)*100;
di percent441; 

sum if defense_distance==4 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent451=(r(N)/total)*100;
di percent451; 

sum if defense_distance==4 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent461=(r(N)/total)*100;
di percent461;


sum if defense_distance==5 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent501=(r(N)/total)*100;
di percent501; 

sum if defense_distance==5 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent511=(r(N)/total)*100;
di percent511;

sum if defense_distance==5 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent521=(r(N)/total)*100;
di percent521;

sum if defense_distance==5 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent531=(r(N)/total)*100;
di percent531;

sum if defense_distance==5 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent541=(r(N)/total)*100;
di percent541; 

sum if defense_distance==5 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent551=(r(N)/total)*100;
di percent551; 

sum if defense_distance==5 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent561=(r(N)/total)*100;
di percent561; 


sum if defense_distance==6 & gov_intervention_distance==0 & less_womensrights_distance==1;
scalar percent601=(r(N)/total)*100;
di percent601; 

sum if defense_distance==6 & gov_intervention_distance==1 & less_womensrights_distance==1;
scalar percent611=(r(N)/total)*100;
di percent611;

sum if defense_distance==6 & gov_intervention_distance==2 & less_womensrights_distance==1;
scalar percent621=(r(N)/total)*100;
di percent621;

sum if defense_distance==6 & gov_intervention_distance==3 & less_womensrights_distance==1;
scalar percent631=(r(N)/total)*100;
di percent631;

sum if defense_distance==6 & gov_intervention_distance==4 & less_womensrights_distance==1;
scalar percent641=(r(N)/total)*100;
di percent641; 

sum if defense_distance==6 & gov_intervention_distance==5 & less_womensrights_distance==1;
scalar percent651=(r(N)/total)*100;
di percent651; 

sum if defense_distance==6 & gov_intervention_distance==6 & less_womensrights_distance==1;
scalar percent661=(r(N)/total)*100;
di percent661;           

log close;
clear;