version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_analysis2.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      bes1992_analysis2.do                            *;
*       Date:           January 31, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:      	Replicate results regarding the substantive 	*;
*						effect for government intervention in the		*;
*						substantive application in Chapter 10 looking 	*;
*						at ideology, gender, and party support in the 	*;
*						1992 UK elections related to Tables 10.5 and 	*;
*						10.6											*;
* 	    Input File:     bes1992_small.dta                        		*;
*       Output File:    bes1992_analysis2.log                           *;
*       Data Output:    none                                            *;             
*       Previous file:  bes1992_small.dta								*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_small.dta", clear;

desc;

sum;

*     ****************************************************************  *;
*		Estimate model													*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3   workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

*     ****************************************************************  *;
*		Get the information for making Table 10.5 in Chapter 10			*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get some values for our baseline scenario						*;
*     ****************************************************************  *;

sum income;
tab income;
sum age;
tab age;
tab workingclass;
sum education;
tab education;

sum defense_distance if alternative1==1,detail;
sum defense_distance if alternative1==2,detail;
sum defense_distance if alternative1==3,detail;

sum gov_intervention_distance if alternative1==1,detail;
sum gov_intervention_distance if alternative1==2,detail;
sum gov_intervention_distance if alternative1==3,detail;

sum less_womensrights_distance if alternative1==1,detail;
sum less_womensrights_distance if alternative1==2,detail;
sum less_womensrights_distance if alternative1==3,detail;

*     ****************************************************************  *;
*		We're interested in the marginal effect of increasing distance	*;
*		for government intervention for Conservative Party on the		*;
*		probability of voting for each of the parties.					*;
*		Party 1: Conservatives, Party 2: Labour, Party 3: Lib Dems		*;
*		Baseline party is Labour (2).									*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3   workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3 , group(respondent_id);

preserve;

set seed 339487731;
            
drawnorm MG_b1-MG_b20, n(10000) means(e(b)) cov(e(V)) clear;

save simulated_betas, replace;

restore;

merge using simulated_betas;

summarize _merge;

drop _merge;

sum MG*;

scalar h_defense_distance1 = 1;
scalar h_defense_distance2 = 2;
scalar h_defense_distance3 = 1;

scalar h_gov_intervention_distance1 = 2;
scalar h_gov_intervention_distance2 = 1;
scalar h_gov_intervention_distance3 = 1;

scalar h_less_womensrights_distance1 = 1;
scalar h_less_womensrights_distance2 = 1;
scalar h_less_womensrights_distance3 = 1;

scalar h_age = 47;
scalar h_income = 6;
scalar h_education = 1;
scalar h_female = 1;
scalar h_male = 0;
scalar h_constant = 1;
scalar h_workingclass = 0;
scalar h_tradeunion = 0;

clogit choice defense_distance female_defense gov_intervention_distance  female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3   workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3 , group(respondent_id);

*     ****************************************************************  *;
*		Male voters														*;
*     ****************************************************************  *;

generate x_betahat_men_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_male + MG_b3*h_gov_intervention_distance1 + MG_b4*h_gov_intervention_distance1*h_male +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_male + MG_b7*h_male + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion + MG_b19*h_constant;

generate x_betahat_men_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_male + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_male + MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_male;

generate x_betahat_men_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_male + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_male +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_male + MG_b8*h_male + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion + MG_b20*h_constant;

gen e_betahat_men_cons = exp(x_betahat_men_cons);
gen e_betahat_men_lab = exp(x_betahat_men_lab);
gen e_betahat_men_libdem = exp(x_betahat_men_libdem);

*     ****************************************************************  *;
*		Baseline predicted probability men								*;
*     ****************************************************************  *;

gen prob_cons_men = e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

gen prob_lab_men = e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

gen prob_libdem_men = e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

di prob_cons_men prob_lab_men prob_libdem_men;

sum prob_cons_men prob_lab_men prob_libdem_men;

centile prob_cons_men prob_lab_men prob_libdem_men, centile(2.5 97.5);

*     ****************************************************************  *;
*		Female voters													*;
*     ****************************************************************  *;

generate x_betahat_women_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_female
 + MG_b3*h_gov_intervention_distance1 + MG_b4*h_gov_intervention_distance1*h_female
 +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_female
 + MG_b7*h_female + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion + MG_b19*h_constant;

generate x_betahat_women_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_female
 + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_female
 +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_female;

generate x_betahat_women_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_female
 + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_female
 +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_female
 + MG_b8*h_female + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion + MG_b20*h_constant;
 
gen e_betahat_women_cons = exp(x_betahat_women_cons);
gen e_betahat_women_lab = exp(x_betahat_women_lab);
gen e_betahat_women_libdem = exp(x_betahat_women_libdem);

*     ****************************************************************  *;
*		Baseline predicted probability women							*;
*     ****************************************************************  *;

gen prob_cons_women = e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

gen prob_lab_women = e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

gen prob_libdem_women = e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

di prob_cons_women prob_lab_women prob_libdem_women;

sum prob_cons_women prob_lab_women prob_libdem_women;

centile prob_cons_women prob_lab_women prob_libdem_women, centile(2.5 97.5);

*     ****************************************************************  *;
*		Check probabilities sum to 1									*;
*     ****************************************************************  *;

di prob_cons_men + prob_lab_men + prob_libdem_men;
di prob_cons_women + prob_lab_women + prob_libdem_women;

*     ****************************************************************  *;
*		Marginal effect													*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		(i) Conservative Party - men - direct marginal effect			*;
*     ****************************************************************  *;

gen me_cons_men = prob_cons_men*(1-prob_cons_men)*MG_b3;

sum me_cons_men;
centile me_cons_men, centile(2.5 97.5);

*     ****************************************************************  *;
*		(ii) Conservative Party - women - direct marginal effect		*;
*     ****************************************************************  *;

gen me_cons_women = prob_cons_women*(1-prob_cons_women)*(MG_b3+MG_b4);

sum me_cons_women;
centile me_cons_women, centile(2.5 97.5);

*     ****************************************************************  *;
*		(iii) Labour Party - men - cross-marginal effect				*;
*     ****************************************************************  *;

gen me_lab_men = -prob_cons_men*(prob_lab_men)*MG_b3;

sum me_lab_men;
centile me_lab_men, centile(2.5 97.5);

*     ****************************************************************  *;
*		(iv) Labour Party - women - cross-marginal effect				*;
*     ****************************************************************  *;

gen me_lab_women = -prob_cons_women*(prob_lab_women)*(MG_b3+MG_b4);

sum me_lab_women;
centile me_lab_women, centile(2.5 97.5);

*     ****************************************************************  *;
*		(v) Lib Dems - men - cross-marginal effect						*;
*     ****************************************************************  *;

gen me_libdem_men = -prob_cons_men*(prob_libdem_men)*MG_b3;

sum me_libdem_men;
centile me_libdem_men, centile(2.5 97.5);

*     ****************************************************************  *;
*		(vi) Lib Dems - women - cross-marginal effect					*;
*     ****************************************************************  *;

gen me_libdem_women = -prob_cons_women*(prob_libdem_women)*(MG_b3+MG_b4);

sum me_libdem_women;
centile me_libdem_women, centile(2.5 97.5);

*     ****************************************************************  *;
*		Check cross-marginal and direct marginal effects sum to 0		*;
*     ****************************************************************  *;

di me_cons_men+me_lab_men+me_libdem_men;

di me_cons_women+me_lab_women+me_libdem_women;

*     ****************************************************************  *;
*		Interaction Effect: Modifying Effect of Gender					*;
*     ****************************************************************  *;

gen interaction_cons = me_cons_women- me_cons_men;
sum interaction_cons;
centile interaction_cons, centile(2.5 97.5);
gen interaction_cons_percent = ((me_cons_women- me_cons_men)/me_cons_men)*100;
sum interaction_cons_percent;
centile interaction_cons_percent, centile(2.5 97.5);


gen interaction_lab = me_lab_women- me_lab_men;
sum interaction_lab;
centile interaction_lab, centile(2.5 97.5);
gen interaction_lab_percent = ((me_lab_women- me_lab_men)/me_lab_men)*100;
sum interaction_lab_percent;
centile interaction_lab_percent, centile(2.5 97.5);

gen interaction_libdem = me_libdem_women- me_libdem_men;
sum interaction_libdem;
centile interaction_libdem, centile(2.5 97.5);
gen interaction_libdem_percent = ((me_libdem_women- me_libdem_men)/me_libdem_men)*100;
sum interaction_libdem_percent;
centile interaction_libdem_percent, centile(2.5 97.5);

*     ****************************************************************  *;
*		Get the information for making Table 10.6 in Chapter 10			*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Rather than marginal effects, let's look at the effect of a two	*;
*		unit increase in distance for government intervention for 		*;
*		Conservative Party on the probability of voting for each of the *;
*		parties. We already have the probabilities in the baseline		*;
*		scenario. We just need the probabilities in the counterfactual	*;
*		scenario and then the differences.								*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		What's an appropriate change in Conservative Party incongruence	*;
*		on this dimension?												*;
*     ****************************************************************  *;

sum gov_intervention_distance if alternative1==1;

*     ****************************************************************  *;
*		Move Conservative Party 2 units									*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Male voters - counterfactual									*;
*     ****************************************************************  *;

generate x_betahat_men_cons2 = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_male + MG_b3*(h_gov_intervention_distance1+2) + MG_b4*(h_gov_intervention_distance1+2)*h_male +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_male + MG_b7*h_male + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion + MG_b19*h_constant;

generate x_betahat_men_lab2 = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_male + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_male +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_male;

generate x_betahat_men_libdem2 = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_male + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_male +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_male + MG_b8*h_male + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion + MG_b20*h_constant;

gen e_betahat_men_cons2 = exp(x_betahat_men_cons2);
gen e_betahat_men_lab2 = exp(x_betahat_men_lab2);
gen e_betahat_men_libdem2 = exp(x_betahat_men_libdem2);

*     ****************************************************************  *;
*		Predicted probability men - counterfactual						*;
*     ****************************************************************  *;

gen prob_cons_men2 = e_betahat_men_cons2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2);

gen prob_lab_men2 = e_betahat_men_lab2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2);

gen prob_libdem_men2 = e_betahat_men_libdem2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2);

di prob_cons_men2 prob_lab_men2 prob_libdem_men2;

sum prob_cons_men2 prob_lab_men2 prob_libdem_men2;

centile prob_cons_men2 prob_lab_men2 prob_libdem_men2, centile(2.5 97.5);

gen diff_cons_men = prob_cons_men2-prob_cons_men;
gen diff_lab_men = prob_lab_men2-prob_lab_men;
gen diff_libdem_men = prob_libdem_men2-prob_libdem_men;

gen diff_cons_men_percent = ((prob_cons_men2-prob_cons_men)/prob_cons_men)*100;
gen diff_lab_men_percent = ((prob_lab_men2-prob_lab_men)/prob_lab_men)*100;
gen diff_libdem_men_percent = ((prob_libdem_men2-prob_libdem_men)/prob_libdem_men)*100;

sum diff_cons_men diff_lab_men diff_libdem_men diff_cons_men_percent diff_lab_men_percent diff_libdem_men_percent;

centile diff_cons_men diff_lab_men diff_libdem_men diff_cons_men_percent diff_lab_men_percent diff_libdem_men_percent, centile(2.5 97.5);

*     ****************************************************************  *;
*		Female voters - counterfactual									*;
*     ****************************************************************  *;

generate x_betahat_women_cons2 = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_female
 + MG_b3*(h_gov_intervention_distance1+2) + MG_b4*(h_gov_intervention_distance1+2)*h_female
 +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_female
 + MG_b7*h_female + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion  + MG_b19*h_constant;

generate x_betahat_women_lab2 = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_female
 + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_female
 +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_female;

generate x_betahat_women_libdem2 = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_female
 + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_female
 +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_female
 + MG_b8*h_female + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion  + MG_b20*h_constant;
 
gen e_betahat_women_cons2 = exp(x_betahat_women_cons2);
gen e_betahat_women_lab2 = exp(x_betahat_women_lab2);
gen e_betahat_women_libdem2 = exp(x_betahat_women_libdem2);

*     ****************************************************************  *;
*		Predicted probability women - counterfactual					*;
*     ****************************************************************  *;

gen prob_cons_women2 = e_betahat_women_cons2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2);

gen prob_lab_women2 = e_betahat_women_lab2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2);

gen prob_libdem_women2 = e_betahat_women_libdem2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2);

di prob_cons_women2 prob_lab_women2 prob_libdem_women2;

sum prob_cons_women2 prob_lab_women2 prob_libdem_women2;

centile prob_cons_women2 prob_lab_women2 prob_libdem_women2, centile(2.5 97.5);

gen diff_cons_women = prob_cons_women2-prob_cons_women;
gen diff_lab_women = prob_lab_women2-prob_lab_women;
gen diff_libdem_women = prob_libdem_women2-prob_libdem_women;

gen diff_cons_women_percent = ((prob_cons_women2-prob_cons_women)/prob_cons_women)*100;
gen diff_lab_women_percent = ((prob_lab_women2-prob_lab_women)/prob_lab_women)*100;
gen diff_libdem_women_percent = ((prob_libdem_women2-prob_libdem_women)/prob_libdem_women)*100;

sum diff_cons_women diff_lab_women diff_libdem_women diff_cons_women_percent diff_lab_women_percent diff_libdem_women_percent;

centile diff_cons_women diff_lab_women diff_libdem_women diff_cons_women_percent diff_lab_women_percent diff_libdem_women_percent, centile(2.5 97.5);

*     ****************************************************************  *;
*		Interaction Effect: Modifying Effect of Gender					*;
*     ****************************************************************  *;

gen interaction_cons2 = diff_cons_women- diff_cons_men;
sum interaction_cons2;
centile interaction_cons2, centile(2.5 97.5);
gen interaction_cons_percent2 = ((diff_cons_women- diff_cons_men)/diff_cons_men)*100;
sum interaction_cons_percent2;
centile interaction_cons_percent2, centile(2.5 97.5);


gen interaction_lab2 = diff_lab_women- diff_lab_men;
sum interaction_lab2;
centile interaction_lab2, centile(2.5 97.5);
gen interaction_lab_percent2 = ((diff_lab_women- diff_lab_men)/diff_lab_men)*100;
sum interaction_lab_percent2;
centile interaction_lab_percent2, centile(2.5 97.5);


gen interaction_libdem2 = diff_libdem_women- diff_libdem_men;
sum interaction_libdem2;
centile interaction_libdem2, centile(2.5 97.5);
gen interaction_libdem_percent2 = ((diff_libdem_women- diff_libdem_men)/diff_libdem_men)*100;
sum interaction_libdem_percent2;
centile interaction_libdem_percent2, centile(2.5 97.5);

*     ****************************************************************  *;
*		Odds ratios														*;
*     ****************************************************************  *;

gen odds_men = exp(MG_b3);
gen odds_men_percent = ((exp(MG_b3))-1)*100;
sum odds_men odds_men_percent;
centile odds_men odds_men_percent, centile(2.5 97.5);

gen odds_women = exp(MG_b3+MG_b4);
gen odds_women_percent = ((exp(MG_b3+MG_b4))-1)*100;
sum odds_women odds_women_percent;
centile odds_women odds_women_percent, centile(2.5 97.5); 

gen interaction= ((odds_women_percent-odds_men_percent)/odds_men_percent)*100;
sum interaction;
centile interaction, centile(2.5 97.5);

log close;
clear;