version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_analysis3.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      bes1992_analysis3.do                            *;
*       Date:           January 31, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:      	Replicate results needed to reproduce Figure 	*;
*						10.4 and most of the results regarding the 		*;
*						substantive effect of being female in Chapter 	*;
*						10												*;
* 	    Input File:     bes1992_small.dta                        		*;
*       Output File:    bes1992_analysis3.log                           *;
*       Data Output:    none                                            *;             
*       Previous file:  bes1992_small.dta								*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_small.dta", clear;

desc;

sum;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce Figure 10.4 showing how the effect of being female on 	*;
*		the probability of voting for the parties in the 1992 UK 		*;
*		elections varies across the values for government intervention.	*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Pick values for baseline scenario								*;
*     ****************************************************************  *;

scalar h_defense_distance1 = 1;
scalar h_defense_distance2 = 2;
scalar h_defense_distance3 = 1;

scalar h_gov_intervention_distance2 = 1;
scalar h_gov_intervention_distance3 = 1;

scalar h_less_womensrights_distance1 = 1;
scalar h_less_womensrights_distance2 = 1;
scalar h_less_womensrights_distance3 = 1;

scalar h_age = 47;
scalar h_income = 6;
scalar h_education = 1;
scalar h_female = 1;
scalar h_male = 0;
scalar h_constant = 1;
scalar h_workingclass = 0;
scalar h_tradeunion = 0;

*     ****************************************************************  *;
*		Estimate model													*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

preserve;

set seed 339487731;

drawnorm MG_b1-MG_b20, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0_cons lo0_cons hi0_cons prob_hat0_lab lo0_lab hi0_lab prob_hat0_libdem lo0_libdem hi0_libdem
				prob_hat1_cons lo1_cons hi1_cons prob_hat1_lab lo1_lab hi1_lab prob_hat1_libdem lo1_libdem hi1_libdem
				diff_hat_cons diff_lo_cons diff_hi_cons diff_hat_lab diff_lo_lab diff_hi_lab diff_hat_libdem diff_lo_libdem diff_hi_libdem
				percent_hat_cons percent_lo_cons percent_hi_cons percent_hat_lab percent_lo_lab percent_hi_lab percent_hat_libdem percent_lo_libdem 					percent_hi_libdem
    			using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/sim1.dta", replace;
    			  		
noisily display "start";

local a=0 ;
while `a' <= 6.1 { ;
{;

*     ****************************************************************  *;
*		Men - baseline													*;
*     ****************************************************************  *;

generate x_betahat_men_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_male + MG_b3*`a' + MG_b4*`a'*h_male +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_male + MG_b7*h_male + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion  + MG_b19*h_constant;

generate x_betahat_men_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_male + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_male +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_male;

generate x_betahat_men_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_male + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_male +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_male + MG_b8*h_male + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion  + MG_b20*h_constant;

gen e_betahat_men_cons = exp(x_betahat_men_cons);
gen e_betahat_men_lab = exp(x_betahat_men_lab);
gen e_betahat_men_libdem = exp(x_betahat_men_libdem);

gen prob_cons_men = e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_lab_men = e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_libdem_men = e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

egen probhat_cons_men =mean(prob_cons_men);
egen probhat_lab_men =mean(prob_lab_men);
egen probhat_libdem_men =mean(prob_libdem_men);

*     ****************************************************************  *;
*		Women - counterfactual											*;
*     ****************************************************************  *;

generate x_betahat_women_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_female
 + MG_b3*`a' + MG_b4*`a'*h_female
 +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_female
 + MG_b7*h_female + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion  + MG_b19*h_constant;

generate x_betahat_women_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_female
 + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_female
 +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_female;

generate x_betahat_women_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_female
 + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_female
 +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_female
 + MG_b8*h_female + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion  + MG_b20*h_constant;
 
gen e_betahat_women_cons = exp(x_betahat_women_cons);
gen e_betahat_women_lab = exp(x_betahat_women_lab);
gen e_betahat_women_libdem = exp(x_betahat_women_libdem);

gen prob_cons_women = e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_lab_women = e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_libdem_women = e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

egen probhat_cons_women =mean(prob_cons_women);
egen probhat_lab_women =mean(prob_lab_women);
egen probhat_libdem_women =mean(prob_libdem_women);

gen diff_cons=prob_cons_women - prob_cons_men;
gen diff_lab=prob_lab_women - prob_lab_men;
gen diff_libdem=prob_libdem_women - prob_libdem_men;

egen diffhat_cons=mean(diff_cons);
egen diffhat_lab=mean(diff_lab);
egen diffhat_libdem=mean(diff_libdem);

gen diff_percent_cons=(diff_cons/prob_cons_men)*100;
gen diff_percent_lab=(diff_lab/prob_lab_men)*100;
gen diff_percent_libdem=(diff_libdem/prob_libdem_men)*100;

egen diffhat_percent_cons=mean(diff_percent_cons);
egen diffhat_percent_lab=mean(diff_percent_lab);
egen diffhat_percent_libdem=mean(diff_percent_libdem);

tempname prob_hat0_cons lo0_cons hi0_cons prob_hat0_lab lo0_lab hi0_lab prob_hat0_libdem lo0_libdem hi0_libdem prob_hat1_cons lo1_cons hi1_cons prob_hat1_lab lo1_lab hi1_lab prob_hat1_libdem lo1_libdem hi1_libdem diff_hat_cons diff_lo_cons diff_hi_cons diff_hat_lab diff_lo_lab diff_hi_lab diff_hat_libdem diff_lo_libdem diff_hi_libdem percent_hat_cons percent_lo_cons percent_hi_cons percent_hat_lab percent_lo_lab percent_hi_lab percent_hat_libdem percent_lo_libdem percent_hi_libdem;

_pctile prob_cons_men, p(2.5,97.5) ;
scalar `lo0_cons' = r(r1);
scalar `hi0_cons' = r(r2);

_pctile prob_lab_men, p(2.5,97.5) ;
scalar `lo0_lab' = r(r1);
scalar `hi0_lab' = r(r2);

_pctile prob_libdem_men, p(2.5,97.5) ;
scalar `lo0_libdem' = r(r1);
scalar `hi0_libdem' = r(r2);

_pctile prob_cons_women, p(2.5,97.5) ;
scalar `lo1_cons' = r(r1);
scalar `hi1_cons' = r(r2);

_pctile prob_lab_women, p(2.5,97.5) ;
scalar `lo1_lab' = r(r1);
scalar `hi1_lab' = r(r2);

_pctile prob_libdem_women, p(2.5,97.5) ;
scalar `lo1_libdem' = r(r1);
scalar `hi1_libdem' = r(r2);

_pctile diff_cons, p(2.5,97.5) ;
scalar `diff_lo_cons' = r(r1);
scalar `diff_hi_cons' = r(r2);

_pctile diff_lab, p(2.5,97.5) ;
scalar `diff_lo_lab' = r(r1);
scalar `diff_hi_lab' = r(r2);

_pctile diff_libdem, p(2.5,97.5) ;
scalar `diff_lo_libdem' = r(r1);
scalar `diff_hi_libdem' = r(r2);

_pctile diff_percent_cons, p(2.5,97.5) ;
scalar `percent_lo_cons' = r(r1);
scalar `percent_hi_cons' = r(r2);

_pctile diff_percent_lab, p(2.5,97.5) ;
scalar `percent_lo_lab' = r(r1);
scalar `percent_hi_lab' = r(r2);

_pctile diff_percent_libdem, p(2.5,97.5) ;
scalar `percent_lo_libdem' = r(r1);
scalar `percent_hi_libdem' = r(r2);

scalar `prob_hat0_cons' = probhat_cons_men;
scalar `prob_hat0_lab' = probhat_lab_men;
scalar `prob_hat0_libdem' = probhat_libdem_men;
scalar `prob_hat1_cons' = probhat_cons_women;
scalar `prob_hat1_lab' = probhat_lab_women;
scalar `prob_hat1_libdem' = probhat_libdem_women;
scalar `diff_hat_cons' = diffhat_cons;
scalar `diff_hat_lab' = diffhat_lab;
scalar `diff_hat_libdem' = diffhat_libdem;
scalar `percent_hat_cons' = diffhat_percent_cons;
scalar `percent_hat_lab' = diffhat_percent_lab;
scalar `percent_hat_libdem' = diffhat_percent_libdem;

post mypost (`prob_hat0_cons') (`lo0_cons') (`hi0_cons') (`prob_hat0_lab') (`lo0_lab') (`hi0_lab') (`prob_hat0_libdem') (`lo0_libdem') (`hi0_libdem') (`prob_hat1_cons') (`lo1_cons') (`hi1_cons') (`prob_hat1_lab') (`lo1_lab') (`hi1_lab') (`prob_hat1_libdem') (`lo1_libdem') (`hi1_libdem') (`diff_hat_cons') (`diff_lo_cons') (`diff_hi_cons') (`diff_hat_lab') (`diff_lo_lab') (`diff_hi_lab') (`diff_hat_libdem') (`diff_lo_libdem') (`diff_hi_libdem') (`percent_hat_cons') (`percent_lo_cons') (`percent_hi_cons') (`percent_hat_lab') (`percent_lo_lab') (`percent_hi_lab') (`percent_hat_libdem') (`percent_lo_libdem') (`percent_hi_libdem');

};

drop x_betahat_men_cons x_betahat_men_lab x_betahat_men_libdem e_betahat_men_cons e_betahat_men_lab e_betahat_men_libdem prob_cons_men prob_lab_men prob_libdem_men probhat_cons_men probhat_lab_men probhat_libdem_men x_betahat_women_cons x_betahat_women_lab x_betahat_women_libdem e_betahat_women_cons e_betahat_women_lab e_betahat_women_libdem prob_cons_women prob_lab_women prob_libdem_women probhat_cons_women probhat_lab_women probhat_libdem_women diff_cons diff_lab diff_libdem diff_percent_cons diff_percent_lab diff_percent_libdem diffhat_cons diffhat_lab diffhat_libdem diffhat_percent_cons diffhat_percent_lab diffhat_percent_libdem;
	
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/sim1.dta";

*     ****************************************************************  *;
*		Let's make some marginal effect plots - Conservatives 			*;
*     ****************************************************************  *;

gen MV = (_n-1)/10 if _n<62;

*     ****************************************************************  *;
*		Similar to Figure 10.4a except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *;    
	    
graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
			|| line diff_hi_cons MV, color(ebblue) clpattern(longdash) 
			|| line diff_lo_cons MV, color(ebblue) clpattern(longdash)  
			|| line diff_hat_cons MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
				ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
				xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
				ytitle("Percentage of Respondents", axis(2) size(2))
     			xscale(titlegap(4)) yscale(titlegap(4)) 
			|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
			||, xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    		ylabel(-0.5 -0.4 -0.3 -0.2 -0.1 0 0.1, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    		ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    		
	    		
*     ****************************************************************  *;
*		Similar to Figure 10.4b except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *; 

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_cons MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_cons MV, color(ebblue) clpattern(longdash)  
		|| line percent_hat_cons MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||, xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-80 -60 -40 -20  0 20, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    	   
*     ****************************************************************  *;
*		Let's make some marginal effect plots - Labour 					*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Similar to Figure 10.4c except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *; 
	    
graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line diff_hi_lab MV, color(ebblue) clpattern(longdash) 
		|| line diff_lo_lab MV, color(ebblue) clpattern(longdash)  
		|| line diff_hat_lab MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-0.10 -0.05 0 0.05 0.10 , tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    	
*     ****************************************************************  *;
*		Similar to Figure 10.4d except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *; 

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_lab MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_lab MV, color(ebblue) clpattern(longdash)  
		|| line percent_hat_lab MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||, xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-120 -80  -40  0 40 80 120 160 200, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Let's make some marginal effect plots - Lib Dem					*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Similar to Figure 10.4e except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *;    

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line diff_hi_libdem MV, color(ebblue) clpattern(longdash) 
		|| line diff_lo_libdem MV, color(ebblue) clpattern(longdash)  
		|| line diff_hat_libdem MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-0.1 0 0.1 0.2 0.3 0.4 0.5, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);	    

*     ****************************************************************  *;
*		Similar to Figure 10.4f except that we use simulated point		*;
*		estimates														*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_libdem MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_libdem MV, color(ebblue) clpattern(longdash)  
		|| line percent_hat_libdem MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-100  -50  0 50 100 120 150 200 250, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    

*     ****************************************************************  *;
*		We recommend using the point estimates directly from the 		*;
*		original coefficients rather than from the simulated 			*;
*		coefficients													*;
*     ****************************************************************  *;
	    
*     ****************************************************************  *;
*		So, let's get point estimates directly from coefficients		*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

*     ****************************************************************  *;
*		Men - baseline													*;
*     ****************************************************************  *;

generate x_betahat_men_cons = _b[defense_distance]*h_defense_distance1 + _b[female_defense]*h_defense_distance1*h_male + _b[gov_intervention_distance]*MV + _b[female_gov_intervention]*MV*h_male +  _b[less_womensrights_distance]*h_less_womensrights_distance1 + _b[female_less_womensrights]*h_less_womensrights_distance1*h_male + _b[female1]*h_male + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

generate x_betahat_men_lab = _b[defense_distance]*h_defense_distance2 + _b[female_defense]*h_defense_distance2*h_male + _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_male +  _b[less_womensrights_distance]*h_less_womensrights_distance2 + _b[female_less_womensrights]*h_less_womensrights_distance2*h_male;

generate x_betahat_men_libdem = _b[defense_distance]*h_defense_distance3 + _b[female_defense]*h_defense_distance3*h_male + _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_male +  _b[less_womensrights_distance]*h_less_womensrights_distance3 + _b[female_less_womensrights]*h_less_womensrights_distance3*h_male + _b[female3]*h_male + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;

gen e_betahat_men_cons = exp(x_betahat_men_cons);
gen e_betahat_men_lab = exp(x_betahat_men_lab);
gen e_betahat_men_libdem = exp(x_betahat_men_libdem);

gen prob_cons_men = e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_lab_men = e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_libdem_men = e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

*     ****************************************************************  *;
*		Women - counterfactual											*;
*     ****************************************************************  *;

generate x_betahat_women_cons = _b[defense_distance]*h_defense_distance1 + _b[female_defense]*h_defense_distance1*h_female
 + _b[gov_intervention_distance]*MV + _b[female_gov_intervention]*MV*h_female
 +  _b[less_womensrights_distance]*h_less_womensrights_distance1 + _b[female_less_womensrights]*h_less_womensrights_distance1*h_female
 + _b[female1]*h_female + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

generate x_betahat_women_lab = _b[defense_distance]*h_defense_distance2 + _b[female_defense]*h_defense_distance2*h_female
 + _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_female
 +  _b[less_womensrights_distance]*h_less_womensrights_distance2 + _b[female_less_womensrights]*h_less_womensrights_distance2*h_female;

generate x_betahat_women_libdem = _b[defense_distance]*h_defense_distance3 + _b[female_defense]*h_defense_distance3*h_female
 + _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_female
 +  _b[less_womensrights_distance]*h_less_womensrights_distance3 + _b[female_less_womensrights]*h_less_womensrights_distance3*h_female
 + _b[female3]*h_female + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;
 
gen e_betahat_women_cons = exp(x_betahat_women_cons);
gen e_betahat_women_lab = exp(x_betahat_women_lab);
gen e_betahat_women_libdem = exp(x_betahat_women_libdem);

gen prob_cons_women = e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_lab_women = e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_libdem_women = e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

gen diff_cons=prob_cons_women - prob_cons_men;
gen diff_lab=prob_lab_women - prob_lab_men;
gen diff_libdem=prob_libdem_women - prob_libdem_men;

gen diff_percent_cons=(diff_cons/prob_cons_men)*100;
gen diff_percent_lab=(diff_lab/prob_lab_men)*100;
gen diff_percent_libdem=(diff_libdem/prob_libdem_men)*100;

*     ****************************************************************  *;
*		Remake plots to compare. Compare point estimates calculated		*;
*		from simulation with point estimates from coefficients.			*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Let's make some marginal effect plots - Conservatives			*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Figure 10.4a 													*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line diff_hi_cons MV, color(ebblue) clpattern(longdash) 
		|| line diff_lo_cons MV, color(ebblue) clpattern(longdash)
		|| line diff_cons MV,color(black) lwidth(medthick) legend(off) clpattern(solid)   
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||, xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-0.5 -0.4 -0.3 -0.2 -0.1 0 0.1, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Figure 10.4b 													*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_cons MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_cons MV, color(ebblue) clpattern(longdash)
		|| line diff_percent_cons MV,color(black) lwidth(medthick) legend(off) clpattern(solid)   
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2.5))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-80 -60 -40 -20  0 20, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Let's make some marginal effect plots - Labour					*;
*     ****************************************************************  *;
	    
*     ****************************************************************  *;
*		Figure 10.4c 													*;
*     ****************************************************************  *;	    

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line diff_hi_lab MV, color(ebblue) clpattern(longdash) 
		|| line diff_lo_lab MV, color(ebblue) clpattern(longdash) 
		|| line diff_lab MV,color(black) lwidth(medthick) legend(off) clpattern(solid)    
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-0.10 -0.05 0 0.05 0.10 , tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Figure 10.4d 													*;
*     ****************************************************************  *;	    

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_lab MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_lab MV, color(ebblue) clpattern(longdash)
		|| line diff_percent_lab MV,color(black) lwidth(medthick) legend(off) clpattern(solid)     
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-120 -80  -40  0 40 80 120 160 200, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Let's make some marginal effect plots - Lib Dem					*;
*     ****************************************************************  *;
	    
*     ****************************************************************  *;
*		Figure 10.4e 													*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line diff_hi_libdem MV, color(ebblue) clpattern(longdash) 
		|| line diff_lo_libdem MV, color(ebblue) clpattern(longdash)
		|| line diff_libdem MV,color(black) lwidth(medthick) legend(off) clpattern(solid)      
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-0.1 0 0.1 0.2 0.3 0.4 0.5, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Figure 10.4f 													*;
*     ****************************************************************  *;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) lcolor(white) yaxis(2) 
		|| line percent_hi_libdem MV, color(ebblue) clpattern(longdash) 
		|| line percent_lo_libdem MV, color(ebblue) clpattern(longdash)
		|| line diff_percent_libdem MV,color(black) lwidth(medthick) legend(off) clpattern(solid)       
			ytitle("Effect of being Female", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Government Intervention Distance (Conservative Party)", size(2)) 
			ytitle("Percentage of Respondents", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 6) clpatter(shortdash) color(black) 
		||,   xlabel(0 1 2 3 4 5 6, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-100  -50  0 50 100 120 150 200 250, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 10 20 30, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
tab gov_intervention_distance if party_alternative==1;

sum diff_cons diff_percent_cons;
sum diff_lab diff_percent_lab;

list diff_percent_lab if MV==0;
list prob_lab_men if MV==0;
list prob_lab_women if MV==0;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce Figure 10.5 showing how the odds and percentage change	*;
*		in the odds of voting for the Conservatives rather than Labour	*;
*		change for women as opposed to men when we vary the ideological	*;
*		distance to the Conservative Party on the government 			*;
*		intervention dimension 											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop _merge;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/simul.dta", replace;	
		
noisily display "start";

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

local a=0 ;
while `a' <= 6 { ;
{;

lincom (_b[female1]+_b[female_gov_intervention]*`a'), or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/simul.dta";

gen MV1 = (_n-1)/10 if _n<62;

gen odds_percent=(odds_hat-1)*100;
gen odds_percent_lo=(odds_lo-1)*100;
gen odds_percent_hi=(odds_hi-1)*100;

gen yline=1;

tab gov_intervention_distance if alternative1==1;

list odds_hat odds_percent if MV1==0;

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) yaxis(2)
		|| line odds_hat MV1, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_lo MV1, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_hi MV1, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV1, clwidth(thin) clcolor(black) clpattern(longdash)
		|| ,
			xlabel(0 1 2 3 4 5 6, nogrid labsize(2))
			ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
			ylabel(0 1 2 3 4 5, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			ytitle("Effect of being Female", size(2))
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Government Intervention Distance", size(2)) 
			xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

graph twoway hist gov_intervention_distance if party_alternative==1, percent color(gs13) yaxis(2)
		|| line odds_percent MV1, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_percent_lo MV1, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_percent_hi MV1, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| ,
			xlabel(0 1 2 3 4 5 6 , nogrid labsize(2))
			ylabel(0 5 10 15 20 25, axis(2) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Effect of being Female", size(2))
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Government Intervention Distance", size(2)) 
			xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

log close;
exit;