version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes1992_collectdata.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      bes1992_collectdata.do                          *;
*       Date:           January 31, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:      	Collect data necessary to help produce some of	*;
*						the figures in Chapter 10						*;
* 	    Input File:     bes1992_small.dta                        		*;
*       Output File:    bes1992_collectdata.log                         *;
*       Data Output:    bes_female.csv, bes_female2.csv, sim_pred.csv,	*; 
*						and sim_pred2.csv								*;            
*       Previous file:  bes1992_small.dta								*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Collect information related to Figure 10.4  					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Pick values for baseline scenario								*;
*     ****************************************************************  *;

scalar h_defense_distance1 = 1;
scalar h_defense_distance2 = 2;
scalar h_defense_distance3 = 1;

scalar h_gov_intervention_distance2 = 1;
scalar h_gov_intervention_distance3 = 1;

scalar h_less_womensrights_distance1 = 1;
scalar h_less_womensrights_distance2 = 1;
scalar h_less_womensrights_distance3 = 1;

scalar h_age = 47;
scalar h_income = 6;
scalar h_education = 1;
scalar h_female = 1;
scalar h_male = 0;
scalar h_constant = 1;
scalar h_workingclass = 0;
scalar h_tradeunion = 0;

*     ****************************************************************  *;
*		Estimate model													*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

preserve;

set seed 339487731;

drawnorm MG_b1-MG_b20, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0_cons lo0_cons hi0_cons prob_hat0_lab lo0_lab hi0_lab prob_hat0_libdem lo0_libdem hi0_libdem
				prob_hat1_cons lo1_cons hi1_cons prob_hat1_lab lo1_lab hi1_lab prob_hat1_libdem lo1_libdem hi1_libdem
				diff_hat_cons diff_lo_cons diff_hi_cons diff_hat_lab diff_lo_lab diff_hi_lab diff_hat_libdem diff_lo_libdem diff_hi_libdem
				percent_hat_cons percent_lo_cons percent_hi_cons percent_hat_lab percent_lo_lab percent_hi_lab percent_hat_libdem percent_lo_libdem 					percent_hi_libdem
    			using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/sim1.dta", replace;
    			  		
noisily display "start";

local a=0 ;
while `a' <= 6.1 { ;
{;

*     ****************************************************************  *;
*		Men - baseline													*;
*     ****************************************************************  *;

generate x_betahat_men_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_male + MG_b3*`a' + MG_b4*`a'*h_male +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_male + MG_b7*h_male + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion  + MG_b19*h_constant;

generate x_betahat_men_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_male + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_male +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_male;

generate x_betahat_men_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_male + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_male +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_male + MG_b8*h_male + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion  + MG_b20*h_constant;

gen e_betahat_men_cons = exp(x_betahat_men_cons);
gen e_betahat_men_lab = exp(x_betahat_men_lab);
gen e_betahat_men_libdem = exp(x_betahat_men_libdem);

gen prob_cons_men = e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_lab_men = e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);
gen prob_libdem_men = e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

egen probhat_cons_men =mean(prob_cons_men);
egen probhat_lab_men =mean(prob_lab_men);
egen probhat_libdem_men =mean(prob_libdem_men);

*     ****************************************************************  *;
*		Women - counterfactual											*;
*     ****************************************************************  *;

generate x_betahat_women_cons = MG_b1*h_defense_distance1 + MG_b2*h_defense_distance1*h_female
 + MG_b3*`a' + MG_b4*`a'*h_female
 +  MG_b5*h_less_womensrights_distance1 + MG_b6*h_less_womensrights_distance1*h_female
 + MG_b7*h_female + MG_b9*h_age + MG_b11*h_workingclass + MG_b13*h_income + MG_b15*h_education + MG_b17*h_tradeunion  + MG_b19*h_constant;

generate x_betahat_women_lab = MG_b1*h_defense_distance2 + MG_b2*h_defense_distance2*h_female
 + MG_b3*h_gov_intervention_distance2 + MG_b4*h_gov_intervention_distance2*h_female
 +  MG_b5*h_less_womensrights_distance2 + MG_b6*h_less_womensrights_distance2*h_female;

generate x_betahat_women_libdem = MG_b1*h_defense_distance3 + MG_b2*h_defense_distance3*h_female
 + MG_b3*h_gov_intervention_distance3 + MG_b4*h_gov_intervention_distance3*h_female
 +  MG_b5*h_less_womensrights_distance3 + MG_b6*h_less_womensrights_distance3*h_female
 + MG_b8*h_female + MG_b10*h_age + MG_b12*h_workingclass + MG_b14*h_income + MG_b16*h_education + MG_b18*h_tradeunion  + MG_b20*h_constant;
 
gen e_betahat_women_cons = exp(x_betahat_women_cons);
gen e_betahat_women_lab = exp(x_betahat_women_lab);
gen e_betahat_women_libdem = exp(x_betahat_women_libdem);

gen prob_cons_women = e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_lab_women = e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);
gen prob_libdem_women = e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

egen probhat_cons_women =mean(prob_cons_women);
egen probhat_lab_women =mean(prob_lab_women);
egen probhat_libdem_women =mean(prob_libdem_women);

gen diff_cons=prob_cons_women - prob_cons_men;
gen diff_lab=prob_lab_women - prob_lab_men;
gen diff_libdem=prob_libdem_women - prob_libdem_men;

egen diffhat_cons=mean(diff_cons);
egen diffhat_lab=mean(diff_lab);
egen diffhat_libdem=mean(diff_libdem);

gen diff_percent_cons=(diff_cons/prob_cons_men)*100;
gen diff_percent_lab=(diff_lab/prob_lab_men)*100;
gen diff_percent_libdem=(diff_libdem/prob_libdem_men)*100;

egen diffhat_percent_cons=mean(diff_percent_cons);
egen diffhat_percent_lab=mean(diff_percent_lab);
egen diffhat_percent_libdem=mean(diff_percent_libdem);

tempname prob_hat0_cons lo0_cons hi0_cons prob_hat0_lab lo0_lab hi0_lab prob_hat0_libdem lo0_libdem hi0_libdem prob_hat1_cons lo1_cons hi1_cons prob_hat1_lab lo1_lab hi1_lab prob_hat1_libdem lo1_libdem hi1_libdem diff_hat_cons diff_lo_cons diff_hi_cons diff_hat_lab diff_lo_lab diff_hi_lab diff_hat_libdem diff_lo_libdem diff_hi_libdem percent_hat_cons percent_lo_cons percent_hi_cons percent_hat_lab percent_lo_lab percent_hi_lab percent_hat_libdem percent_lo_libdem percent_hi_libdem;

_pctile prob_cons_men, p(2.5,97.5) ;
scalar `lo0_cons' = r(r1);
scalar `hi0_cons' = r(r2);

_pctile prob_lab_men, p(2.5,97.5) ;
scalar `lo0_lab' = r(r1);
scalar `hi0_lab' = r(r2);

_pctile prob_libdem_men, p(2.5,97.5) ;
scalar `lo0_libdem' = r(r1);
scalar `hi0_libdem' = r(r2);

_pctile prob_cons_women, p(2.5,97.5) ;
scalar `lo1_cons' = r(r1);
scalar `hi1_cons' = r(r2);

_pctile prob_lab_women, p(2.5,97.5) ;
scalar `lo1_lab' = r(r1);
scalar `hi1_lab' = r(r2);

_pctile prob_libdem_women, p(2.5,97.5) ;
scalar `lo1_libdem' = r(r1);
scalar `hi1_libdem' = r(r2);

_pctile diff_cons, p(2.5,97.5) ;
scalar `diff_lo_cons' = r(r1);
scalar `diff_hi_cons' = r(r2);

_pctile diff_lab, p(2.5,97.5) ;
scalar `diff_lo_lab' = r(r1);
scalar `diff_hi_lab' = r(r2);

_pctile diff_libdem, p(2.5,97.5) ;
scalar `diff_lo_libdem' = r(r1);
scalar `diff_hi_libdem' = r(r2);

_pctile diff_percent_cons, p(2.5,97.5) ;
scalar `percent_lo_cons' = r(r1);
scalar `percent_hi_cons' = r(r2);

_pctile diff_percent_lab, p(2.5,97.5) ;
scalar `percent_lo_lab' = r(r1);
scalar `percent_hi_lab' = r(r2);

_pctile diff_percent_libdem, p(2.5,97.5) ;
scalar `percent_lo_libdem' = r(r1);
scalar `percent_hi_libdem' = r(r2);

scalar `prob_hat0_cons' = probhat_cons_men;
scalar `prob_hat0_lab' = probhat_lab_men;
scalar `prob_hat0_libdem' = probhat_libdem_men;
scalar `prob_hat1_cons' = probhat_cons_women;
scalar `prob_hat1_lab' = probhat_lab_women;
scalar `prob_hat1_libdem' = probhat_libdem_women;
scalar `diff_hat_cons' = diffhat_cons;
scalar `diff_hat_lab' = diffhat_lab;
scalar `diff_hat_libdem' = diffhat_libdem;
scalar `percent_hat_cons' = diffhat_percent_cons;
scalar `percent_hat_lab' = diffhat_percent_lab;
scalar `percent_hat_libdem' = diffhat_percent_libdem;

post mypost (`prob_hat0_cons') (`lo0_cons') (`hi0_cons') (`prob_hat0_lab') (`lo0_lab') (`hi0_lab') (`prob_hat0_libdem') (`lo0_libdem') (`hi0_libdem') (`prob_hat1_cons') (`lo1_cons') (`hi1_cons') (`prob_hat1_lab') (`lo1_lab') (`hi1_lab') (`prob_hat1_libdem') (`lo1_libdem') (`hi1_libdem') (`diff_hat_cons') (`diff_lo_cons') (`diff_hi_cons') (`diff_hat_lab') (`diff_lo_lab') (`diff_hi_lab') (`diff_hat_libdem') (`diff_lo_libdem') (`diff_hi_libdem') (`percent_hat_cons') (`percent_lo_cons') (`percent_hi_cons') (`percent_hat_lab') (`percent_lo_lab') (`percent_hi_lab') (`percent_hat_libdem') (`percent_lo_libdem') (`percent_hi_libdem');

};

drop x_betahat_men_cons x_betahat_men_lab x_betahat_men_libdem e_betahat_men_cons e_betahat_men_lab e_betahat_men_libdem prob_cons_men prob_lab_men prob_libdem_men probhat_cons_men probhat_lab_men probhat_libdem_men x_betahat_women_cons x_betahat_women_lab x_betahat_women_libdem e_betahat_women_cons e_betahat_women_lab e_betahat_women_libdem prob_cons_women prob_lab_women prob_libdem_women probhat_cons_women probhat_lab_women probhat_libdem_women diff_cons diff_lab diff_libdem diff_percent_cons diff_percent_lab diff_percent_libdem diffhat_cons diffhat_lab diffhat_libdem diffhat_percent_cons diffhat_percent_lab diffhat_percent_libdem;
	
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/sim1.dta";

gen MV = (_n-1)/10 if _n<62;
	    
*     ****************************************************************  *;
* 		Grab information for the confidence intervals in Figure 10.4	*;
*     ****************************************************************  *;

keep MV diff_lo_cons diff_hi_cons percent_lo_cons percent_hi_cons diff_lo_lab diff_hi_lab percent_lo_lab percent_hi_lab diff_lo_libdem diff_hi_libdem percent_lo_libdem percent_hi_libdem diff_hat_cons diff_hat_lab diff_hat_libdem percent_hat_cons percent_hat_lab percent_hat_libdem;

order MV diff_lo_cons diff_hi_cons  diff_lo_lab diff_hi_lab diff_lo_libdem diff_hi_libdem percent_lo_cons percent_hi_cons percent_lo_lab percent_hi_lab percent_lo_libdem percent_hi_libdem diff_hat_cons diff_hat_lab diff_hat_libdem percent_hat_cons percent_hat_lab percent_hat_libdem;

drop if MV>6;

outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes_female.csv", comma nonames replace;

clear;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Collect information related to Figure 10.5  					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/simul2.dta", replace;	
		
noisily display "start";

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

local a=0 ;
while `a' <= 6 { ;
{;

lincom (_b[female1]+_b[female_gov_intervention]*`a'), or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/simul2.dta";

gen MV1 = (_n-1)/10 if _n<62;

gen odds_percent=(odds_hat-1)*100;
gen odds_percent_lo=(odds_lo-1)*100;
gen odds_percent_hi=(odds_hi-1)*100;

keep MV odds_hat odds_lo odds_hi odds_percent odds_percent_lo odds_percent_hi;
    
order MV;

drop if _n>61;
   
outsheet using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_application/bes_female2.csv", comma nonames replace;

clear;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Collect data on regions of statistical significance in Figures	*;
*		10.3a and 10.3b													*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*		Figure 10.3a -- womens rights are 0								*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

preserve;

postutil clear;

postfile mypost p z def gov
    			using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim3.dta", replace;
    			  		
noisily display "start";

local b=0 ;

forvalues a = 0(0.1)6 {;

forvalues b = 0(0.1)6 {;

lincom _b[female1]+_b[female_defense]*`a'+_b[female_gov_intervention]*`b'+_b[female_less_womensrights]*0;
	
tempname p z ;
	
scalar `p' = r(p);
scalar `z' = r(estimate);

post mypost (`p') (`z') (`a') (`b');

display "." _c;

};

};

display "";
	
postclose mypost;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim3.dta", clear;

order def gov z p;

keep if p<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim_pred.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*		Figure 10.3b -- womens rights are 1								*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

postutil clear;

postfile mypost p z def gov
    			using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim4.dta", replace;
    			  		
noisily display "start";

local b=0 ;

forvalues a = 0(0.1)6 {;

forvalues b = 0(0.1)6 {;

lincom _b[female1]+_b[female_defense]*`a'+_b[female_gov_intervention]*`b'+_b[female_less_womensrights]*1;
	
tempname p z ;
	
scalar `p' = r(p);
scalar `z' = r(estimate);

post mypost (`p') (`z') (`a') (`b');

display "." _c;

};

};
	
display "";
	
postclose mypost;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim4.dta", clear;

order def gov z p;

keep if p<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim_pred2.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*		Womens rights are 3.2											*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

postutil clear;

postfile mypost p z def gov
    			using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim5.dta", replace;
    			  		
noisily display "start";

local b=0 ;

forvalues a = 0(0.1)6 {;

forvalues b = 0(0.1)6 {;

lincom _b[female1]+_b[female_defense]*`a'+_b[female_gov_intervention]*`b'+_b[female_less_womensrights]*3.2;
	
tempname p z ;
	
scalar `p' = r(p);
scalar `z' = r(estimate);

post mypost (`p') (`z') (`a') (`b');

display "." _c;

};

};

display "";
	
postclose mypost;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim5.dta", clear;

order def gov z p;

keep if p<0.05;

sum;

clear;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\bes1992_small.dta", clear;

*     ****************************************************************  *;
*		Womens rights are 3.3											*;
*     ****************************************************************  *;

clogit choice defense_distance female_defense gov_intervention_distance female_gov_intervention less_womensrights_distance female_less_womensrights female1 female3 age1 age3 workingclass1 workingclass3 income_other1 income_other3 education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

postutil clear;

postfile mypost p z def gov
    			using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim6.dta", replace;
    			  		
noisily display "start";

local b=0 ;

forvalues a = 0(0.1)6 {;

forvalues b = 0(0.1)6 {;

lincom _b[female1]+_b[female_defense]*`a'+_b[female_gov_intervention]*`b'+_b[female_less_womensrights]*3.3;
	
tempname p z ;
	
scalar `p' = r(p);
scalar `z' = r(estimate);

post mypost (`p') (`z') (`a') (`b');

display "." _c;

};

};

display "";
	
postclose mypost;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_application\sim6.dta", clear;

order def gov z p;

keep if p<0.05;

sum;

log close;
clear;