version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter10_exercise1/bes1992_exercise1.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      bes1992_exercise1.do                            *;
*       Date:           February 2, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:        Replicate results for Question 1 in Chapter 10	*;
* 	    Input File:     bes1992_small.dta                        		*;
*       Output File:    bes1992_exercise1.log                           *;
*       Data Output:    none                                            *;             
*       Previous file:  bes1992_small.dta								*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter10_exercise1\bes1992_small.dta", clear;

desc;

sum;

*     ****************************************************************  *;
*		Produce results shown in Table 10.7 in Chapter 10				*;
*     ****************************************************************  *;

clogit choice gov_intervention_distance female_gov_intervention female1 female3 age1 age3   workingclass1 workingclass3 income_other1 income_other3  education1 education3 trade_union1 trade_union3 alternative1 alternative3, group(respondent_id);

*     ****************************************************************  *;
*		Number of individuals											*;
*     ****************************************************************  *;

di e(N)/3;

*     ****************************************************************  *;
*		Marginal effects on utility										*;
*     ****************************************************************  *;

* Men;

di _b[gov_intervention_distance];

* Women;

di _b[gov_intervention_distance]+_b[female_gov_intervention]*1;

* Modifying effect of being female;

di _b[female_gov_intervention];

scalar h_gov_intervention_distance1 = 2;
scalar h_gov_intervention_distance2 = 1;
scalar h_gov_intervention_distance3 = 1;

scalar h_age = 30;
scalar h_income = 6;
scalar h_education = 1;
scalar h_female = 1;
scalar h_male = 0;
scalar h_constant = 1;
scalar h_workingclass = 0;
scalar h_tradeunion = 0;

*     ****************************************************************  *;
*		Direct marginal effect of government intervention on the		*;
*		probability of voting conservative - men						*;
*		The numbers will be slightly off from those in the book because	*;
*		there's some rounding in the results presented in the book		*;
*     ****************************************************************  *;

scalar x_betahat_men_cons=  _b[gov_intervention_distance]*h_gov_intervention_distance1 + _b[female_gov_intervention]*h_gov_intervention_distance1*h_male + _b[female1]*h_male + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

di x_betahat_men_cons;

scalar x_betahat_men_lab =  _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_male;

di x_betahat_men_lab;

scalar x_betahat_men_libdem =  _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_male + _b[female3]*h_male + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;

di x_betahat_men_libdem;

scalar e_betahat_men_cons=   exp(_b[gov_intervention_distance]*h_gov_intervention_distance1 + _b[female_gov_intervention]*h_gov_intervention_distance1*h_male + _b[female1]*h_male + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant);

di e_betahat_men_cons;

scalar e_betahat_men_lab=   exp(_b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_male);

di e_betahat_men_lab;

scalar e_betahat_men_libdem = exp(_b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_male + _b[female3]*h_male + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant);

di e_betahat_men_libdem;

scalar prob_men = e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

di prob_men;

scalar marginal_men = prob_men*(1-prob_men)*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_male);

di marginal_men;

*     ****************************************************************  *;
*		Direct marginal effect of government intervention on the		*;
*		probability of voting conservative - women						*;
*     ****************************************************************  *;

scalar x_betahat_women_cons=  _b[gov_intervention_distance]*h_gov_intervention_distance1 + _b[female_gov_intervention]*h_gov_intervention_distance1*h_female + _b[female1]*h_female + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

di x_betahat_women_cons;

scalar x_betahat_women_lab =  _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_female;

di x_betahat_women_lab;

scalar x_betahat_women_libdem =  _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_female + _b[female3]*h_female + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;

di x_betahat_women_libdem;

scalar e_betahat_women_cons=   exp( _b[gov_intervention_distance]*h_gov_intervention_distance1 + _b[female_gov_intervention]*h_gov_intervention_distance1*h_female + _b[female1]*h_female + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant);

di e_betahat_women_cons;

scalar e_betahat_women_lab=  exp(_b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_female);

di e_betahat_women_lab;

scalar e_betahat_women_libdem = exp(_b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_female + _b[female3]*h_female + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant);

di e_betahat_women_libdem;

scalar prob_women = e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

di prob_women;

scalar marginal_women = prob_women*(1-prob_women)*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_female);

di marginal_women;

*     ****************************************************************  *;
*		Modifying effect of being female on direct marginal effect		*;
*     ****************************************************************  *;

di marginal_women - marginal_men;

*     ****************************************************************  *;
*		Cross marginal effects on probability - labour - men			*;
*     ****************************************************************  *;

scalar prob_men_lab = e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

di prob_men_lab;

scalar crossmarginal_men = -prob_men*prob_men_lab*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_male);

di crossmarginal_men;

*     ****************************************************************  *;
*		Cross marginal effects on probability - labour - women			*;
*     ****************************************************************  *;

scalar prob_women_lab = e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

di prob_women_lab;

scalar crossmarginal_women = -prob_women*prob_women_lab*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_female);

di crossmarginal_women;

*     ****************************************************************  *;
*		Cross marginal effects on probability - libdem - men			*;
*     ****************************************************************  *;

scalar prob_men_libdem = e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem);

di prob_men_libdem;

scalar crossmarginal_men_libdem = -prob_men*prob_men_libdem*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_male);

di crossmarginal_men_libdem;

*     ****************************************************************  *;
*		Cross marginal effects on probability - libdem - women			*;
*     ****************************************************************  *;

scalar prob_women_libdem = e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem);

di prob_women_libdem;

scalar crossmarginal_women_libdem = -prob_women*prob_women_libdem*(_b[gov_intervention_distance]+_b[female_gov_intervention]*h_female);

di crossmarginal_women_libdem;

*     ****************************************************************  *;
*		Direct marginal effects and cross-marginal effects should sum	*;
*		to 0															*;
*     ****************************************************************  *;

di marginal_men + crossmarginal_men + crossmarginal_men_libdem;
di marginal_women + crossmarginal_women + crossmarginal_women_libdem;

*     ****************************************************************  *;
*		Men: Discrete change - counterfactual							*;
*		Increase gov_intervention_distance by 2 units for conservatives	*;
*     ****************************************************************  *;

scalar h_gov_intervention_distance1c=4;

scalar x_betahat_men_cons2=  _b[gov_intervention_distance]*h_gov_intervention_distance1c + _b[female_gov_intervention]*h_gov_intervention_distance1c*h_male + _b[female1]*h_male + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

di x_betahat_men_cons2;

scalar x_betahat_men_lab2 =  _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_male;

di x_betahat_men_lab2;

scalar x_betahat_men_libdem2 =  _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_male + _b[female3]*h_male + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;

di x_betahat_men_libdem2;

scalar e_betahat_men_cons2=   exp(_b[gov_intervention_distance]*h_gov_intervention_distance1c + _b[female_gov_intervention]*h_gov_intervention_distance1c*h_male + _b[female1]*h_male + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant);

di e_betahat_men_cons2;

scalar e_betahat_men_lab2=   exp( _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_male);

di e_betahat_men_lab2;

scalar e_betahat_men_libdem2 = exp(_b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_male + _b[female3]*h_male + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant);

di e_betahat_men_libdem2;

scalar prob_men2 = e_betahat_men_cons2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2);

di prob_men2;

di prob_men2-prob_men;

*     ****************************************************************  *;
*		Women: Discrete change - counterfactual							*;
*		Increase gov_intervention_distance by 2 units for conservatives	*;
*     ****************************************************************  *;

scalar x_betahat_women_cons2=  _b[gov_intervention_distance]*h_gov_intervention_distance1c + _b[female_gov_intervention]*h_gov_intervention_distance1c*h_female + _b[female1]*h_female + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant;

di x_betahat_women_cons2;

scalar x_betahat_women_lab2 =  _b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_female;

di x_betahat_women_lab2;

scalar x_betahat_women_libdem2 =  _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_female + _b[female3]*h_female + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant;

di x_betahat_women_libdem2;

scalar e_betahat_women_cons2=   exp(_b[gov_intervention_distance]*h_gov_intervention_distance1c + _b[female_gov_intervention]*h_gov_intervention_distance1c*h_female + _b[female1]*h_female + _b[age1]*h_age + _b[workingclass1]*h_workingclass + _b[income_other1]*h_income + _b[education1]*h_education + _b[trade_union1]*h_tradeunion  + _b[alternative1]*h_constant);

di e_betahat_women_cons2;

scalar e_betahat_women_lab2=  exp(_b[gov_intervention_distance]*h_gov_intervention_distance2 + _b[female_gov_intervention]*h_gov_intervention_distance2*h_female);

di e_betahat_women_lab2;

scalar e_betahat_women_libdem2 = exp( _b[gov_intervention_distance]*h_gov_intervention_distance3 + _b[female_gov_intervention]*h_gov_intervention_distance3*h_female + _b[female3]*h_female + _b[age3]*h_age + _b[workingclass3]*h_workingclass + _b[income_other3]*h_income + _b[education3]*h_education + _b[trade_union3]*h_tradeunion  + _b[alternative3]*h_constant);

di e_betahat_women_libdem2;

scalar prob_women2 = e_betahat_women_cons2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2);

di prob_women2;

di prob_women2-prob_women;

di (prob_women2-prob_women)-(prob_men2-prob_men);

*     ****************************************************************  *;
*		Odds ratio - men												*;
*     ****************************************************************  *;

di (exp(_b[gov_intervention_distance]*2)-1)*100;

*     ****************************************************************  *;
*		Odds ratio - women												*;
*     ****************************************************************  *;

di (exp((_b[gov_intervention_distance]+_b[female_gov_intervention])*2)-1)*100;

*     ****************************************************************  *;
*		Modifying effect of being female								*;
*     ****************************************************************  *;

di ((exp((_b[gov_intervention_distance]+_b[female_gov_intervention])*2)-1)*100)-((exp(_b[gov_intervention_distance]*2)-1)*100);
di (((exp((_b[gov_intervention_distance]+_b[female_gov_intervention])*2)-1)*100)-((exp(_b[gov_intervention_distance]*2)-1)*100))/((exp(_b[gov_intervention_distance]*2)-1)*100)*100;

log close;
clear;

