version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise2/parties.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      parties.do                               		*;
*       Date:           1/17/202                                        *;
*       Author:         MG                                             	*;
*       Purpose:        Replicate results for Question 2 in Chapter 3	*;
*       Input File:     coxappend.dta                                   *;
*       Output File:    parties.log                              		*;
*       Data Output:    coxappend.dta                                   *;
*       Previous file:                                                  *;
*       Machine:                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 10m;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise2/coxappend.dta";

*     ****************************************************************  *;
*           Summary Statistics                                          *;
*     ****************************************************************  *;

sum;

*     ****************************************************************  *;
*		Variable Names													*;
*		enpv = Number of Parties										*;
*		eneth = Social Divisions										*;
*		lnml = Electoral Permissiveness									*;
*		lmleneth = Social Divisons x Electoral Permissiveness			*;
*     ****************************************************************  *;

sum eneth;
sum lnml;

*     ****************************************************************  *;
*		Results for uncentered model in Table 3.3 (second column)		*;
*     ****************************************************************  *;

regress enpv eneth lnml  lmleneth if drop==0;

vif;

*     ****************************************************************  *;
*		Mean center variables in order to produce results in Table 3.3	*;
*     ****************************************************************  *;

summarize eneth, meanonly;
gen centered_eneth = eneth - r(mean);

summarize lnml, meanonly;
gen centered_lnml = lnml - r(mean);

gen centered_eneth_lnml= centered_eneth*centered_lnml;

*     ****************************************************************  *;
*		Results for mean-centered model in Table 3.3 (first column)		*;
*     ****************************************************************  *;

regress enpv centered_eneth centered_lnml  centered_eneth_lnml if drop==0;

vif;

*     ****************************************************************  *;
*		Calculate the marginal effect of Social Divisions when 			*;
*		Electoral Permissiveness is 0									*;
*     ****************************************************************  *;

lincom _b[centered_eneth]-_b[centered_eneth_lnml]*1.53;

*     ****************************************************************  *;
*		Calculate the marginal effect of Electoral Permissiveness when	*;
*		Social Divisions is 0											*;
*     ****************************************************************  *;

lincom _b[centered_lnml]-_b[centered_eneth_lnml]*1.57;

*     ****************************************************************  *;
*		Calculate the constant from the uncentered model				*;
*     ****************************************************************  *;

lincom _b[_cons]-_b[centered_eneth]*1.57-_b[centered_lnml]*1.53+_b[centered_eneth_lnml]*1.57*1.53;

log close;

clear;

