version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise3/responsiveness.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      responsiveness.do                               *;
*       Date:           1/17/2022                                       *;
*       Author:         MG                                             	*;
*       Purpose:        Replicate results for Question 3 in Chapter 3   *;
*       Input File:     AJPS2006.dta                                   	*;
*       Output File:    responsiveness.log                              *;
*       Data Output:    AJPS2006.dta                                   	*;
*       Previous file:                                                  *;
*       Machine:                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set matsize 400;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise3/AJPS2006.dta";

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Below is the replication code from Adams et al. 2006 to create	*;
*		the final version of their dataset.								*;
*     ****************************************************************  *;
*     ****************************************************************  *;

iis partnum;

tis electnum;

egen clnum = group(ctrynum electnum);

/***********************************************************************/
/* Generate variables -- not all of these are used in the final models */
/***********************************************************************/

generate pshift2 = (partyshift2 * (9/200));
generate pshiftt12 = (partyshiftprev * (9/200));
generate pshiftt22 = (partyshiftminustwo * (9/200));

generate pshift2a = abs(pshift2);

generate vshift = vshiftidparty + vshiftmsparty;

generate idvshift = idparty * vshift;

generate idpshift = idparty * pshift2a;

generate msparty = 0;
replace msparty = 1 if idparty==0;

generate msvshift = msparty * vshift;

generate dir = 0;
replace dir = 1 if leftwingparty==1;
replace dir = -1 if rightwingparty==1;

generate centpart = 0;
replace centpart = 1 if dir==0;

generate cconverge = centpart * diffANCPun;

generate dirpshift = dir * pshift2;

generate moderate = 0;
replace moderate = 1 if dirpshift>0;
/*replace moderate = -1 if dirpshift<0;*/

generate modid = moderate * idparty;
generate pshiftmod = moderate * pshift2a;
generate idpshiftmod = moderate * pshift2a * idparty;

generate iddpshift = idparty * dirpshift;

generate dir2 = 0;
replace dir2 = -1 if leftwingparty==1;
replace dir2 = 1 if rightwingparty==1;

generate dirvshift = dir2 * vshift;

sort clnum;

by clnum: generate lvotec = ln(votecurrent);
by clnum: generate lvotec1 = ln(voteminusone);
by clnum: generate lvotec2 = ln(voteminustwo);

by clnum: generate votec = votecurrent - voteminusone;
by clnum: generate votec1 = voteminusone - voteminustwo;

by clnum: egen converge = sum(pshiftmod);
/*replace converge = converge * unweighted_AN;*/

generate idconverge = idparty * converge;

generate lvgain = lvotec - lvotec1;
generate lvgainone = lvotec1 - lvotec2;

generate cgovunemp = ingovnow * changeunemp3;
generate cgovgdp = ingovnow * changegdp3;

generate federal = 0;
replace federal = 1 if fedundim>0;

generate logmag = ln(magnitude);

/* these just pick up Communists in Spain */
generate idfederal = idparty * federal;
generate idlogmag = idparty * logmag;

by clnum: generate numgov = sum(ingovnow);

generate coalgov = 0;
replace coalgov = 1 if numgov > 1;

generate ccogovun = changeunemp3 * coalgov;
generate ccogovgdp = changegdp3 * coalgov;

generate Gunemp = Green * changeunemp3;

generate pshiftAN = unweighted_AN * pshift2a;
generate vshiftAN = unweighted_AN * vshift;

generate dirid = dir * idparty;

generate pvoteshift = votec1 * pshiftt12;

tsset partnum electnum;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Replication for Question 3 in Chapter 3 begins					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

label var pshift2 "change in party position";
rename pshift2  party_shift;
label variable vshift "Public opinion shift";
rename vshift opinion_shift;
label var idparty "Niche party";
rename idparty niche_party;
gen opinion_niche=opinion_shift*niche_party;
label var opinion_niche "Public opinion shift X niche party";
label var pshiftt12 "Previous policy shift";
label var votec1 "Previous change in vote share";
label var pvoteshift "Previous policy shift X previous change in vote share";

*     ****************************************************************  *;
*		Produce results from the standard interaction model shown in 	*;
*		Table S.2 in the Solutions chapter.								*;
*     ****************************************************************  *;

regress party_shift niche_party opinion_niche opinion_shift  pshiftt12 votec1 pvoteshift Italy Britain Greece Luxembourg Denmark Netherlands Spain, cluster(clnum);

*     ****************************************************************  *;
*		Calculate the marginal effect of Public Opinion Shift when the	*;
*		party is a niche party.											*;
*     ****************************************************************  *;

lincom _b[opinion_shift]+_b[opinion_niche];

*     ****************************************************************  *;
*		Produce results from the alternative interaction model shown in *;
*		Table 3.4 and later in Table S.2 in the Solutions chapter.		*;
*     ****************************************************************  *;

gen opinion_mainstream=opinion_shift*(1-niche_party);

regress party_shift niche_party opinion_mainstream opinion_niche pshiftt12 votec1 pvoteshift Italy Britain Greece Luxembourg Denmark Netherlands Spain, cluster(clnum);

*     ****************************************************************  *;
*		Is the effect of Public Opinion Shift different for mainstream	*;
*		parties as opposed to niche parties? This is captured by the 	*;
*		interaction term in the standard interaction model. However, we	*;
*		can also calculate it from the alternative interaction model.	*;
*		Here are two ways of doing it.									*;
*     ****************************************************************  *;

lincom _b[opinion_niche]-_b[opinion_mainstream];

test _b[opinion_niche]=_b[opinion_mainstream];

log close;

clear;
