version 13.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise5/race_gender.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      race_gender.do                            		*;
*       Date:           January 17, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:        Replicate results for Question54 in Chapter 3   *;
* 	    Input File:     anes2016_small.dta       		                *;
*       Output File:    none			                                *;
*       Data Output:    none                                            *;             
*       Previous file:  					     						*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter3_exercise5\anes2016_small.dta", clear;

*     ****************************************************************  *;
*           Variable description and summary statistics                 *;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*       Drop respondents who are not white or black						*;
*     ****************************************************************  *;

keep if white==1 | black==1;

*     ****************************************************************  *;
*		Generate interaction term for gender and race					*;
*     ****************************************************************  *;

gen female_black = female*black;
gen female_white = female*white;
gen male_black = male*black;
gen male_white = male*white;

order respondent_id female male black white female_black female_white male_black male_white;

*     ****************************************************************  *;
*		Produce results from the standard interaction model shown in 	*;
*		Table S.4 in the Solutions chapter.								*;
*     ****************************************************************  *;

regress like_republican female black female_black age;

*     ****************************************************************  *;
*		Produce results from alternative interaction model I shown in 	*;
*		Table 3.6 in Chapter 3 and Table S.4 in the Solutions chapter.	*;
*		This is the model where White men are the reference category.	*;
*     ****************************************************************  *;

regress like_republican female_white  male_black  female_black age;

*     ****************************************************************  *;
*		Calculate the interaction effect of gender and race				*;
*     ****************************************************************  *;

lincom _b[female_black]-_b[female_white]-_b[male_black];

*     ****************************************************************  *;
*		Produce results from alternative interaction model II shown in 	*;
*		Table S.4 in the Solutions chapter.	This is the model where 	*;
*		Black women are the reference category.							*;
*     ****************************************************************  *;

regress like_republican   female_white  male_black  male_white age;

estat vce;

log close;

clear;

