version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter4_exercise1/race2.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      race2.do                               			*;
*       Date:           1/17/2022                                       *;
*       Author:         MG                                             	*;
*       Purpose:        Replicate results for Question 1 in Chapter 4   *;
*       Input File:     rep_banks_2012a.dta                             *;
*       Output File:    race.log                              			*;
*       Data Output:    rep_banks_2012a.dta                             *;
*       Previous file:                                                  *;
*       Machine:                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter3_exercise4/rep_banks_2012a.dta", clear;

*     ****************************************************************  *;
*           Summary Statistics                                          *;
*     ****************************************************************  *;

sum;

*     ****************************************************************  *;
*		Label and rename variables to match the discussion in Question	*;
*		4 in the Exercises at the end of Chapter 3						*;
*     ****************************************************************  *;

label var anger "anger";
label var racresent1 "symbolic resentment";
rename racresent1 symbolic_resentment;
gen resentment_anger=anger*symbolic_resentment;
label var resentment_anger "symbolic resentment -- angry";
label var angerres1 "anger * symbolic resentment";
rename racpolicy racepolicy;
gen resentment_calm = symbolic_resentment*(1-anger);
label var resentment_calm "symbolic resentment -- calm";

*     ****************************************************************  *;
*		Produce results from the standard interaction model shown in 	*;
*		Table 4.1 in Chapter 4 and Table S.5 in the Solutions chapter.	*;
*     ****************************************************************  *;

regress racepolicy symbolic_resentment anger resentment_anger;

*     ****************************************************************  *;
*		Obtain variance-covariance matrix of estimated coefficients		*;
*     ****************************************************************  *;

estat vce;

*     ****************************************************************  *;
*		Obtain degrees of freedom										*;
*     ****************************************************************  *;

scalar df=e(df_r);

display df;

*     ****************************************************************  *;
*		Obtain critical t-value for this degrees of freedom 			*;
*		assuming an alpha level of 0.05					  				*;
*     ****************************************************************  *;

di invttail(df,0.025);

*     ****************************************************************  *;
*		Calculate marginal effect of Symbolic Racism when Anger = 0		*;
*     ****************************************************************  *;

lincom _b[symbolic_resentment];

return list;

*     ****************************************************************  *;
*		Calculate marginal effect of Symbolic Racism when Anger = 1		*;
*     ****************************************************************  *;

lincom _b[symbolic_resentment]+_b[resentment_anger];

return list;

*     ****************************************************************  *;
*		Calculate the effect of Anger when Symbolic Racism = 0			*;
*     ****************************************************************  *;

lincom _b[anger];

return list;

*     ****************************************************************  *;
*		Calculate the effect of Anger when Symbolic Racism = 0.5		*;
*     ****************************************************************  *;

lincom _b[anger]+_b[resentment_anger]*0.5;

return list;

*     ****************************************************************  *;
*		Calculate the effect of Anger when Symbolic Racism = 1			*;
*     ****************************************************************  *;

lincom _b[anger]+_b[resentment_anger]*1;

return list;

*     ****************************************************************  *;
*		Calculate the predicted value of Oppose Race Policies when		*;
*		Symbolic Racism = 0.5 and Anger = 0								*;
*     ****************************************************************  *;

lincom _b[_cons]+_b[symbolic_resentment]*0.5;

return list;

*     ****************************************************************  *;
*		Calculate the predicted value of Oppose Race Policies when		*;
*		Symbolic Racism = 0.5 and Anger = 1								*;
*     ****************************************************************  *;

lincom _b[_cons]+_b[symbolic_resentment]*0.5+_b[anger]+_b[resentment_anger]*0.5;

return list;

*     ****************************************************************  *;
*		Calculate the difference in the predicted value of Oppose Race 	*;
*		Policies when Symbolic Racism = 0.5 and we change Anger from 0	*;
*		to 1. This is the effect of Anger when Symbolic Racism = 0.5	*;
*     ****************************************************************  *;

lincom _b[_cons]+_b[symbolic_resentment]*0.5+_b[anger]+_b[resentment_anger]*0.5-(_b[_cons]+_b[symbolic_resentment]*0.5);

lincom _b[anger]+_b[resentment_anger]*0.5;

log close;

clear;
