version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter5_exercise1/exercise1.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      exercise1.do                               		*;
*       Date:           1/21/202                                        *;
*       Author:         MG                                             	*;
*       Purpose:        Replicate results for Question 1 in Chapter 5	*;
*       Input File:     final.dta                                   	*;
*       Output File:    exercise1.log                              		*;
*       Data Output:    final.dta                                   	*;
*       Previous file:                                                  *;
*       Machine:                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*        Load skeleton dataset                                          *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter5_application3\final.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

*     ****************************************************************  *;
*		Generate interaction term										*;
*     ****************************************************************  *;

gen leaders_labor = women_leaders*labor;

*     ****************************************************************  *;
*		Standard interaction model - uncentered							*;
*     ****************************************************************  *;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.8a in Stata showing the marginal	*;
*		effect of demand across the observed range of values for supply.*;
*		Note that the figures in the book were created using pgfplots, 	*;
*		not Stata														*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 100000;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

sum labor;
sum women_leaders;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=((_n-1)/100);

replace MV=. if _n>11200;

gen conbx=b1+b3*MV if _n<11300;

gen consx=sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) if _n<11300;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Limit to range of observed data.								*;
*     ****************************************************************  *;

replace MV=. if MV<8.62;
replace MV=. if MV>111.02;

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 5.8a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist labor, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
		ytitle("Marginal Effect of Demand", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
		xtitle("Supply (Ratio of Female to Male Labor Force Participation)", size(2.5))  
		ytitle("Percentage of Observations", axis(2) size(2.5))
     	xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(-1 111) clpatter(shortdash) color(black) 
	||, xlabel(0 10 20 30 40 50 60 70 80 90 100 110, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    ylabel(0 2 4 6 8 10, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);


*     ****************************************************************  *;
*		Calculate the value of supply at which the confidence interval	*;
*		for the marginal effect of demand is narrowest.	This differs	*;
*		from the answer in the book only because of the rounding that 	*;
*		is used in the book when presenting covariances and variances.	*;
*     ****************************************************************  *;

di covb1b3;
di varb3;

di -covb1b3/varb3;
di -(-0.000207/0.000003);

*     ****************************************************************  *;
*		We can also check this numerically to 2 decimal places.			*;
*     ****************************************************************  *;

gen gap = upperx-lowerx;
sum gap;
scalar min_gap = r(min);
di min_gap;
list MV if gap==min_gap;

sum labor;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 5.8b in Stata showing the marginal	*;
*		effect of supply across the observed range of values for demand.*;
*		Note that the figures in the book were created using pgfplots, 	*;
*		not Stata														*;
*     ****************************************************************  *;
*     ****************************************************************  *;

drop MV conbx consx lowerx upperx gap;

regress womens_representation women_leaders labor leaders_labor effectivequota polity;

sum labor;
sum women_leaders;

*     ****************************************************************  *;
*		Obtain the coefficients, variances, and covariances necessary	*;
*		to calculate marginal effects and confidence intervals.			*;
*     ****************************************************************  *;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

estat vce;

generate MV=((_n-1)/100);

gen conbx=b2+b3*MV if _n<9400;

gen consx=sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2) if _n<9400;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Limit to range of observed data.								*;
*     ****************************************************************  *;

replace MV=. if MV<7.98;
replace MV=. if MV>91.83;

*     ****************************************************************  *;
*		Draw the plot. The histogram differs slightly from the one 		*;
*		shown in Figure 5.8b because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist women_leaders, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV, color(ebblue) clpattern(longdash) 
	|| line lowerx MV, color(ebblue) clpattern(longdash)  
	|| line conbx MV,color(black) lwidth(medthick) legend(off) clpattern(solid) 
		ytitle("Marginal Effect of Supply", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
		xtitle("Demand", size(2.5)) ytitle("Percentage of Observations", axis(2) size(2.5))
     	xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(-1 100) clpatter(shortdash) color(black) 
	||, xlabel(0 10 20 30 40 50 60 70 80 90 100, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.2 -0.1 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 , tlcolor(black) labcolor(black) axis(1) labsize(2))  
	    ylabel(0 2 4 6 8 10 12 14, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd); 



*     ****************************************************************  *;
*		Calculate the value of demand at which the confidence interval	*;
*		for the marginal effect of supply is narrowest.	This differs	*;
*		from the answer in the book only because of the rounding that 	*;
*		is used in the book when presenting covariances and variances.	*;
*     ****************************************************************  *;

di covb3b2;
di varb3;

di -covb3b2/varb3;
di -(-0.000107/0.000003);

*     ****************************************************************  *;
*		We can also check this numerically to 2 decimal places.			*;
*     ****************************************************************  *;

gen gap = upperx-lowerx;
sum gap;
scalar min_gap = r(min);
di min_gap;
list MV if gap==min_gap;

sum women_leaders;


*     ****************************************************************  *;
*		Calculate the value of demand at which the confidence interval	*;
*		for the marginal effect of supply cuts the zero line using the 	*;
*		information in Appendix D.	The values don't perfectly match	*;
*		the answers in the book. This is because of the rounding that 	*;
*		is used in the book when presenting covariances and variances. 	*;
*     ****************************************************************  *;

* lower bound;

di (-(2*b2*b3-2*t*t*covb3b2)+sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3));

*     ****************************************************************  *;
*		We can also check this numerically by looking at the value of	*;
*		MV where lowerx and upperx switch signs in the data editor.		*;
*     ****************************************************************  *;

* upper bound;

di (-(2*b2*b3-2*t*t*covb3b2)-sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3));

log close;

clear;

