version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter5_exercise2/exercise2.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      exercise2.do                               		*;
*       Date:           1/21/202                                        *;
*       Author:         MG                                             	*;
*       Purpose:        Replicate results for Question 2 in Chapter 5	*;
*       Input File:     rep_banks_2012a.dta                             *;
*       Output File:    exercise2.log                              		*;
*       Data Output:    rep_banks_2012a.dta                             *;
*       Previous file:                                                  *;
*       Machine:                                                        *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

 use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter5_exercise2\rep_banks_2012a.dta", clear;

*     ****************************************************************  *;
*           Summary Statistics                                          *;
*     ****************************************************************  *;

sum;

*     ****************************************************************  *;
*		Label and rename variables to match the discussion in Question	*;
*		4 in the Exercises at the end of Chapter 3						*;
*     ****************************************************************  *;

label var anger "anger";
label var racresent1 "symbolic resentment";
rename racresent1 symbolic_resentment;
gen resentment_anger=anger*symbolic_resentment;
label var resentment_anger "symbolic resentment -- angry";
label var angerres1 "anger * symbolic resentment";
rename racpolicy racepolicy;
gen resentment_calm = symbolic_resentment*(1-anger);
label var resentment_calm "symbolic resentment -- calm";

*     ****************************************************************  *;
*		Standard interaction model										*;
*     ****************************************************************  *;

regress racepolicy symbolic_resentment anger resentment_anger;

estat vce;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a marginal effect plot for symbolic racism. Note that 	*;
*		the figures in the book were created using pgfplots, not Stata.	*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Create a 3 x 2 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot = J(3, 2, .);
matrix coln plot = estimate se;

*     ****************************************************************  *;
*		Obtain the point estimates and standard errors for the effects	*;
*		shown in Figure S.1 and place them in the matrix				*;
*     ****************************************************************  *;

lincom _b[symbolic_resentment];
matrix plot[1,1]=r(estimate);
matrix plot[1,2]=r(se);

lincom _b[symbolic_resentment] + _b[resentment_anger];
matrix plot[2,1]=r(estimate);
matrix plot[2,2]=r(se);

lincom _b[resentment_anger];
matrix plot[3,1]=r(estimate);
matrix plot[3,2]=r(se);

*     ****************************************************************  *;
*		Produce the plot using coefplot									*;
*     ****************************************************************  *;

coefplot (matrix(plot[.,1]), se(plot[.,2]) offset(0) 
		lwidth(thick) m(smcircle) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))),  
		legend(off) xtitle("Effect Size", size(2.5)) levels(95) xlab(-0.1 0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1, tlcolor(black) labcolor(black) labsize(2.5))    				
		coeflabels(r1="Symbolic Racism (Calm)" r2="Symbolic Racism (Angry)" r3="Interaction Effect", tlcolor(black) labcolor(black) labsize(2.5)) 
		yscale(noline) xscale(noline) mlabel format(%9.3f) mlabposition(12) mlabgap(*2) mlabsize(2.5)  xline(0, lcolor(gray)) scheme(burd);

*     ****************************************************************  *;
*		Calculate the value of symbolic racism at which the standard	*;
*		error associated with the effect of anger is minimized.			*;
*     ****************************************************************  *;

regress racepolicy symbolic_resentment anger resentment_anger;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb3b2;

di -covb3b2/varb3;
di -0.01125366/0.01550988;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a marginal effect plot for anger. Note that the figures	*;
*		in the book were created using pgfplots, not Stata.				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

generate MV2=(_n-1)/100;

replace MV2=. if _n>101;

gen conbx=b2+b3*MV2 if _n<102;

gen consx=sqrt(varb2+varb3*(MV2^2)+2*MV2*covb3b2) if _n<102;

*     ****************************************************************  *;
*		Obtain degrees of freedom and critical t-value for creating		*;
*		confidence intervals											*;
*     ****************************************************************  *;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

replace MV2=. if MV2>101;

*     ****************************************************************  *;
*		Draw the plot. 													*;
*     ****************************************************************  *;

graph twoway hist symbolic_resentment, percent color(gs13) lcolor(white) yaxis(2) 
	|| line upperx MV2, color(ebblue) clpattern(longdash) 
	|| line lowerx MV2, color(ebblue) clpattern(longdash)  
	|| line conbx MV2,color(black) lwidth(medthick) legend(off) clpattern(solid) 
		ytitle("Marginal Effect of Anger", size(2.5)) title("", size(3)) subtitle("", size(2.5)) 
		xtitle("Symbolic Racism", size(2.5))  
		ytitle("Percentage of Observations", axis(2) size(2.5))
     	xscale(titlegap(4)) yscale(titlegap(4)) 
	|| function y = 0, range(0 1) clpatter(shortdash) color(black) 
	||, xlabel(0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1, tlcolor(black) labcolor(black) labsize(2))
	    ylabel(-0.4 -0.3 -0.2 -0.1 0 0.1 0.2 0.3, tlcolor(black) labcolor(black) axis(1) labsize(2))
	    ylabel(0 5 10 15 20 25, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2)) 
	    yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*		Figure S.2 has five vertical bars representing different 		*;
*		quantities. The values below are slightly different but this is	*;
*		only because of the rounding used in the book.					*;
*     ****************************************************************  *;
	    
lincom _b[anger]+_b[resentment_anger]*0;
lincom _b[anger]+_b[resentment_anger]*0.5;	    
lincom _b[anger]+_b[resentment_anger]*1;
di -covb3b2/varb3;	
di (-(2*b2*b3-2*t*t*covb3b2)+sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3));
di (-(2*b2*b3-2*t*t*covb3b2)-sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3));

log close;

clear;

