version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter6_application1/anes2016_feminism_analysis.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      anes2016_feminism_analysis.do                   *;
*       Date:           January 22, 2022								*;
*       Author:         MG                                         		*;
*       Purpose:      	Replicate main results for first substantive 	*;
*						application in Chapter 6 looking at gender,		*;
*						education, age, and support for feminism		*;
* 	    Input File:     anes2016_small.dta       		                *;
*       Output File:    none			                                *;
*       Data Output:    none                                            *;             
*       Previous file:  					     						*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application1\anes2016_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

*     ****************************************************************  *;
*           Summary statistics											*;
*     ****************************************************************  *;

sum;
sum thermometer_feminist;
sum age if male==1;
sum age if female==1;

*     ****************************************************************  *;
*		Create dummy for college education, BA and up					*;
*     ****************************************************************  *;

gen college_educated=.;
replace college_educated=0 if education<13 & education~=.;
replace college_educated=1 if education>12 & education~=.;
tab college_educated;

*     ****************************************************************  *;
*		Create interaction terms										*;
*     ****************************************************************  *;

gen female_educated=female*college_educated;

gen female_age=female*age;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 6.1 in Chapter 6					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

regress thermometer_feminist female college_educated age female_educated female_age 
			black asian native_american hispanic race_other religion_important left_right;
					
*     ****************************************************************  *;
*		Get precise p-value for coefficient on female_educated			*;
*     ****************************************************************  *;

parmest, list(parm estimate p);

estat vce;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a marginal effect plot similar to the one shown in 		*;
*		Figure 6.9a. The marginal effect of being female across the		*;
*		range of values for age for the non-college educated. 	Note 	*;
*		that the figures in the book were created using pgfplots, not 	*;
*		Stata.															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 6500;

regress thermometer_feminist female college_educated age female_educated female_age 
			black asian native_american hispanic race_other religion_important left_right;

*     ****************************************************************  *;
*		Obtain the necessary coefficients, variances, and covariances	*;
*		to calculate effects and confidence intervals					*;
*     ****************************************************************  *;
			
matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];

scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];

scalar covb1b4=V[1,4];
scalar covb1b5=V[1,5];
scalar covb4b5=V[4,5];

scalar list b1 b2 b3 b4 b5 varb1 varb2 varb3 varb4 varb5 covb1b4 covb1b5 covb4b5;

generate MV=((_n-1)/10)+18;

replace MV=. if _n>722;

gen conbx=b1+b4*0+b5*MV if _n<722;

gen consx=sqrt(varb1+varb4*(0^2)+varb5*(MV^2)+2*0*covb1b4+2*MV*covb1b5+2*0*MV*covb4b5) if _n<722;

scalar df=e(df_r);

di invttail(df,0.025);

scalar t=invttail(df,0.025);

gen lowerx=conbx-(t*consx);

gen upperx=conbx+(t*consx);

*     ****************************************************************  *;
*		Produce the plot in Figure 6.9a. The histogram will be a little	*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist age if college_educated==0,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx MV, clpattern(longdash)  color(ebblue)
		|| line lowerx MV, clpattern(longdash)  color(ebblue)
		|| line conbx MV, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of being Female" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Age" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(10 90) clpattern(shortdash) color(black)
		|| , xlabel(10 20 30 40 50 60 70 80 90, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-8 -6 -4 -2 0 2 4 6 8 10 12 14 16 18, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 1 2 3 4 5 6, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
		
	
*     ****************************************************************  *;
*		Percentage of observations that fall into the different regions	*;
*		in the plot using the cutpoints identified in the data editor.	*;
*     ****************************************************************  *;
		
sum respondent_id if college_educated==0 & age~=.;
scalar total = r(N);
di total;

sum respondent_id if age<63.7 & college_educated==0;
scalar subtotal1=r(N);
di subtotal1;
di (subtotal1/total)*100;

sum respondent_id if age>63.6 & age<78.5 & college_educated==0;
scalar subtotal2=r(N);
di subtotal2;
di (subtotal2/total)*100;

sum respondent_id if age>78.4 & age~=.  & college_educated==0;
scalar subtotal3=r(N);
di subtotal3;
di (subtotal3/total)*100;


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a marginal effect plot similar to the one shown in 		*;
*		Figure 6.9b. The marginal effect of being female across the		*;
*		range of values for age for the college educated. 	Note that	*;
*		the figures in the book were created using pgfplots, not Stata.	*;
*     ****************************************************************  *;
*     ****************************************************************  *;

gen conbx2=b1+b4*1+b5*MV if _n<722;

gen consx2=sqrt(varb1+varb4*(1^2)+varb5*(MV^2)+2*1*covb1b4+2*MV*covb1b5+2*1*MV*covb4b5) if _n<722;

gen lowerx2=conbx2-(t*consx2);

gen upperx2=conbx2+(t*consx2);

*     ****************************************************************  *;
*		Produce the plot in Figure 6.9b. The histogram will be a little	*;
*		different due to different bar widths and locations.			*;
*     ****************************************************************  *;

graph twoway hist age if college_educated==1,  percent color(gs13) lcolor(white) yaxis(2)	
		|| line upperx2 MV, clpattern(longdash)  color(ebblue)
		|| line lowerx2 MV, clpattern(longdash)  color(ebblue)
		|| line conbx2 MV, clpattern(solid) lwidth(medthick) color(black) 
		ytitle("Effect of being Female" ,  size(2.5)) ytitle("Percentage of Observations" , axis(2) size(2.5))
		xtitle("Age" ,  size(2.5)) 
 		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y=0, range(10 90) clpattern(shortdash) color(black)
		|| , xlabel(10 20 30 40 50 60 70 80 90, tlcolor(black) labcolor(black) labsize(2))
		ylabel(-8 -6 -4 -2 0 2 4 6 8 10 12 14 16 18, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
		ylabel(0 1 2 3 4 5 6, axis(2) tlcolor(gs13) labcolor(gs13) labsize(2))
		yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
		xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
		

sum respondent_id if college_educated==1 & age~=.;
scalar total2 = r(N);
di total2;

sum respondent_id if age<77.7 &  college_educated==1;
scalar subtotal4=r(N);
di subtotal4;
di (subtotal4/total2)*100;

sum respondent_id if age>77.6 &  college_educated==1 & age~=.;
scalar subtotal5=r(N);
di subtotal5;
di (subtotal5/total2)*100;

*     ****************************************************************  *;
*		Percentage of respondents where effect of being female is		*;
*		positive.														*;
*     ****************************************************************  *;

sum respondent_id if college_educated~=. & age~=.;
scalar total3 = r(N);
di total3;

di ((subtotal1+subtotal2+subtotal4+subtotal5)/total3)*100;

*     ****************************************************************  *;
*		Percentage of respondents where effect of being female is		*;
*		positive and statistically significant.							*;
*     ****************************************************************  *; 

di ((subtotal1+subtotal4)/total3)*100;

*     ****************************************************************  *;
*		Substantive significance -- effect of being female rather than	*;
*		male for a 25 year old college graduate.						*;
*     ****************************************************************  *;

lincom  _b[female]+_b[female_educated]+_b[female_age]*25;

sum thermometer_feminist if male==1 & age>19 & age<30 & college_educated==1;
scalar mean20=r(mean);
di mean20;

di ((_b[female]+_b[female_educated]+_b[female_age]*25)/mean20)*100;

*     ****************************************************************  *;
*		Substantive significance -- effect of being female rather than	*;
*		male for a 25 year old with no college education.				*;
*     ****************************************************************  *;

lincom  _b[female]+_b[female_age]*25;

sum thermometer_feminist if male==1 & age>19 & age<30 & college_educated==0;
scalar mean20a=r(mean);
di mean20a;
di ((_b[female]+_b[female_age]*25)/mean20a)*100;

*     ****************************************************************  *;
*		Modifying effect of college education in our scenarios			*;
*     ****************************************************************  *;

di  (_b[female]+_b[female_educated]+_b[female_age]*25)-(_b[female]+_b[female_age]*25);

sum thermometer_feminist;

*     ****************************************************************  *;
*		Substantive significance -- effect of being female rather than	*;
*		male for a 55 year old college graduate.						*;
*     ****************************************************************  *;

lincom  _b[female]+_b[female_educated]+_b[female_age]*55;

sum thermometer_feminist if male==1 & age>49 & age<60 & college_educated==1;
scalar mean50=r(mean);
di mean50;

di ((_b[female]+_b[female_educated]+_b[female_age]*55)/mean50)*100;

*     ****************************************************************  *;
*		Compare effect size to when the individual was 25				*;
*     ****************************************************************  *;

di 100-(((_b[female]+_b[female_educated]+_b[female_age]*55)/(_b[female]+_b[female_educated]+_b[female_age]*25))*100);

*     ****************************************************************  *;
*		Substantive significance -- effect of being female rather than	*;
*		male for a 55 year old with no college education.				*;
*     ****************************************************************  *;

lincom  _b[female]+_b[female_age]*55;

sum thermometer_feminist if male==1 & age>49 & age<60 & college_educated==0;
scalar mean50a=r(mean);
di mean50a;
di ((_b[female]+_b[female_age]*55)/mean50a)*100;

*     ****************************************************************  *;
*		Compare effect size to when the individual was 25				*;
*     ****************************************************************  *;

di 100-(((_b[female]+_b[female_age]*55)/(_b[female]+_b[female_age]*25))*100);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Calculate information in Figure 6.10.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

lincom  _b[female]+_b[female_educated]+_b[female_age]*25;
lincom  _b[female]+_b[female_age]*25;
lincom  _b[female]+_b[female_educated]+_b[female_age]*55;
lincom  _b[female]+_b[female_age]*55;

lincom (_b[female]+_b[female_educated]+_b[female_age]*55)-(_b[female]+_b[female_educated]+_b[female_age]*25);
lincom (_b[female]+_b[female_age]*55)-(_b[female]+_b[female_age]*25);
lincom (_b[female]+_b[female_educated]+_b[female_age]*25)-(_b[female]+_b[female_age]*25);
lincom (_b[female]+_b[female_educated]+_b[female_age]*55)-(_b[female]+_b[female_age]*55);

sum thermometer_feminist if male==1 & age>19 & age<30 & college_educated==1;
sum thermometer_feminist if male==1 & age>19 & age<30 & college_educated==0;
sum thermometer_feminist if male==1 & age>49 & age<60 & college_educated==1;
sum thermometer_feminist if male==1 & age>49 & age<60 & college_educated==0;

*     ****************************************************************  *;
*		Effect of education												*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Effect of college education	for men								*;
*     ****************************************************************  *;

lincom _b[college_educated];
sum thermometer_feminist if male==1 & college_educated==0;

*     ****************************************************************  *;
*		Effect of college education	for women							*;
*     ****************************************************************  *;

lincom _b[college_educated]+_b[female_educated];
sum thermometer_feminist if female==1 & college_educated==0;

*     ****************************************************************  *;
*		Compare effect of college education among women and men			*;
*     ****************************************************************  *;

di (_b[college_educated]+_b[female_educated])/(_b[college_educated]);

*     ****************************************************************  *;
*		Effect of age													*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Effect of one additional year for men							*;
*     ****************************************************************  *;

lincom _b[age];

*     ****************************************************************  *;
*		Effect of 30 additional years for men							*;
*     ****************************************************************  *;

lincom _b[age]*30;

*     ****************************************************************  *;
*		Mean level of support for feminism among men in the 20s			*;
*     ****************************************************************  *;

sum thermometer_feminist if male==1 & age>19 & age<30;

*     ****************************************************************  *;
*		Effect of one additional year for women							*;
*     ****************************************************************  *;

lincom _b[age]+_b[female_age];

*     ****************************************************************  *;
*		Effect of 30 additional years for women							*;
*     ****************************************************************  *;

lincom (_b[age]+_b[female_age])*30;

*     ****************************************************************  *;
*		Additional control variables and interaction terms				*;
*     ****************************************************************  *;

regress thermometer_feminist female college_educated age female_educated female_age 
			black asian native_american hispanic race_other religion_important left_right;
			
regress thermometer_feminist female college_educated age female_educated female_age 
			black asian native_american hispanic race_other religion_important left_right married income employed;

gen female_black=female*black;
gen female_asian=female*asian;
gen female_native=female*native_american;
gen female_hispanic=female*hispanic;
gen female_other=female*race_other;
gen female_religion=female*religion_important;
gen female_lr=female*left_right;
gen female_married=female*married;
gen female_income=female*income;
gen female_employed=female*employed;

regress thermometer_feminist female college_educated age female_educated female_age black asian native_american hispanic race_other religion_important  left_right married income employed female_black female_asian female_native female_hispanic female_other female_religion female_lr female_married female_income female_employed;

*     ****************************************************************  *;
*       Replication complete											*;
*     ****************************************************************  *;

log close;

clear;