version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter6_application2/regime_collectdata.log", replace
#delimit ;


*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      regime_collectdata.do                           *;
*       Date:           January 23, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Grab the data necessary to create the 			*;
*						histograms, balls, and significant region in 	*;
*						Figures 6.17 and 6.18							*;
* 	    Input File:     final.dta                                		*;
*       Output File:    regime_collectdata.log                          *;
*       Data Output:    labor.csv, labor0.csv, labor20.csv, 			*;
*						obs_dem.csv,obs_dic.csv, predictions0.csv, 		*;
*						predictions10.csv, predictions20.csv, 			*;
*						predictions30.csv, predictions40.csv,			*;
*						predictions50.csv, predictions60.csv, 			*;
*						predictions70.csv, predictions80.csv, 			*;
*						predictions90.csv, predictions100.csv, 			*;
*						and final.dta 	                                *;             
*       Previous file:                                  				*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Get just the labor (supply) variable							*;
*     ****************************************************************  *;

keep if labor~=.;

keep labor;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\labor.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

*     ****************************************************************  *;
*		Get just the labor (supply) variable for democracy = 0			*;
*     ****************************************************************  *;

keep if labor~=. & polity2==0;

keep labor;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\labor0.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

*     ****************************************************************  *;
*		Get just the labor (supply) variable for democracy = 20			*;
*     ****************************************************************  *;

keep if labor~=. & polity2==20;

keep labor;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\labor20.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

*     ****************************************************************  *;
*		Get democracy and supply scores, but only for democracies		*; 
*     ****************************************************************  *;

keep labor polity2;

drop if polity2<16;

order labor polity2;

gen z=-1;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\obs_dem.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

*     ****************************************************************  *;
*		Get democracy and supply scores, but only for dictatorships		*; 
*     ****************************************************************  *;

keep labor polity2;

drop if polity2>15;

order labor polity2;

gen z=-1;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\obs_dic.csv", comma replace;

clear;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

*     ****************************************************************  *;
*		Make polity variable go from 0 to 20 instead of -10 to +10		*;
*     ****************************************************************  *;

gen polity2=polity+10;

*     ****************************************************************  *;
*		Get data to produce region of statistical significance that 	*;
*		goes with the marginal effect of demand shown in the 3-D plot 	*;
*		shown in Figure 6.17a											*;
*     ****************************************************************  *;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

*     ****************************************************************  *;
*		Stata's memory won't let us get all of the data at once and so	*;
*		we need to calculate it in "strips" of labor values				*;
*     ****************************************************************  *;

* Strip 0;

margins, dydx(women_leaders) at(labor=(0(0.5)10) polity2=(0(0.1)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions0.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions0.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions0.csv", comma replace;

clear;

* Strip 1;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(10(0.5)20) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions10.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions10.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions10.csv" , comma replace;

clear;

* Strip 2;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(20(0.5)30) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions20.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions20.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions20.csv" , comma replace;

clear;

* Strip 3;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(30(0.5)40) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions30.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions30.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions30.csv" , comma replace;

clear;

* Strip 4;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(40(0.5)50) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions40.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions40.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions40.csv" , comma replace;

clear;

* Strip 5;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(50(0.5)60) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions50.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions50.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions50.csv" , comma replace;

clear;

* Strip 6;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(60(0.5)70) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions60.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions60.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions60.csv" , comma replace;

clear;

* Strip 7;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(70(0.5)80) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions70.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions70.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions70.csv" , comma replace;

clear;

* Strip 8;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(80(0.5)90) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions80.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions80.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions80.csv" , comma replace;

clear;

* Strip 9;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(90(0.5)100) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions90.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions90.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions90.csv" , comma replace;

clear;

* Strip 10;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\final.dta", clear;

gen polity2=polity+10;

regress womens_representation c.women_leaders##c.labor##c.polity2 effectivequota;

margins, dydx(women_leaders) at(labor=(100(0.5)111) polity2=(0(0.5)20)) 
		saving("C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions100.dta", replace);

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions100.dta", clear;

rename _at2 labor;
rename _at3 polity2;
rename _margin marginal_effect;

keep labor polity2 marginal_effect _pvalue;

order labor polity2 marginal_effect _pvalue;

keep if _pvalue<0.05;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter6_application2\predictions100.csv" , comma replace;

clear;

log close;

clear;

*     ****************************************************************  *;
*       The End                                                         *;
*     ****************************************************************  *;        
