version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_application/pec2.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec2.do                              			*;
*       Date:           January 28, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for substantive 			*;
*						effects of disproportionality in the  			*;
*						application in Chapter 8 looking at the  		*;
*						determinants of pre-electoral coalition 		*;
*						formation										*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec2.log                             			*;
*       Data Output:    pec_BJPS.dta                                    *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;


*     ****************************************************************  *;
*		Get polarization and threshold measures by election.			*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum threshold;
scalar threshold_mean=r(mean);
di threshold_mean;
scalar threshold_sd=r(sd);
di threshold_sd;

sum polarization;
scalar polarization_mean=r(mean);
di polarization_mean;
scalar polarization_sd=r(sd);
di polarization_sd;
sum polarization, detail;
_pctile polarization, p(25);
return list;
scalar polarization_25 = r(r1);
di polarization_25;
_pctile polarization, p(75);
return list;
scalar polarization_75 = r(r1);
di polarization_75;

sum election;
scalar election_total=r(N);
di election_total;

sum election if threshold>16.74 & threshold~=.;
scalar election_subtotal=r(N);
di election_subtotal;
di (election_subtotal/election_total)*100;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*		Summary statistics												*;
*     ****************************************************************  *;

desc;

summarize pec seatshare incompatibility polarization threshold;

tab pec;

sum polarization if polarization<83.7;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.2 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility, or;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.12 in Stata. Effect of a 		*;
*		standard deviation increase in Disproportionality in a 			*;
*		representative baseline scenario where Disproportionality, 		*;
*		Seatshare, and Ideological Incompatibility are all at their		*;
*		means.															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get values for our variables									*;
*     ****************************************************************  *;

sum seatshare;
scalar seatshare_mean=r(mean);
scalar seatshare_sd=r(sd);
scalar seatshare_plus=seatshare_mean+seatshare_sd;

sum incompatibility;
scalar incompatibility_mean=r(mean);
scalar incompatibility_sd=r(sd);

scalar threshold_plus=threshold_mean+threshold_sd;
scalar polarization_plus=polarization_mean+polarization_sd;
scalar constant=1;

di threshold_sd;
di threshold_mean;
di threshold_plus;
di polarization_sd;
di polarization_mean;
di polarization_plus;
di seatshare_sd;
di seatshare_mean;
di seatshare_plus;
di incompatibility_sd;
di incompatibility_mean;
di constant;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

preserve;

set seed 10101;

drawnorm SN_b1-SN_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi percent_hat percent_lo percent_hi
	prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c diff_hatc diff_loc diff_hic diff_diff_hat diff_diff_lo diff_diff_hi
    percentc_hat percentc_lo percentc_hi diff_percent_hat diff_percent_lo diff_percent_hi
    using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim.dta", replace;	
		
noisily display "start";

local a=0 ;
while `a' <= 100.1 { ;
{;

*     ****************************************************************  *;
*		xbeta in baseline												*;
*     ****************************************************************  *;

generate x_betahat0 = SN_b1*threshold_mean
		+ SN_b2*`a'
		+ SN_b3*threshold_mean*`a'
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		xbeta in counterfactual											*;
*     ****************************************************************  *;
		
generate x_betahat1 = SN_b1*threshold_plus
		+ SN_b2*`a'
		+ SN_b3*threshold_plus*`a'
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		Probability in baseline	and counterfactual						*;
*     ****************************************************************  *;
		
gen prob0 =exp(x_betahat0)/(1+exp(x_betahat0));
gen prob1 =exp(x_betahat1)/(1+exp(x_betahat1));

*     ****************************************************************  *;
*		Change and percentage change in probability						*;
*     ****************************************************************  *;

gen diff=prob1-prob0;
gen percent = (diff/prob0)*100;		
		
egen probhat0 =mean(prob0);
egen probhat1=mean(prob1);
egen diffhat=mean(diff);
egen percenthat=mean(percent);	

*     ****************************************************************  *;
*		Get information for modifying effect of a one unit increase in	*;
*		polarization													*;
*     ****************************************************************  *;
		
generate x_betahat0c = SN_b1*threshold_mean
		+ SN_b2*(`a'+1)
		+ SN_b3*threshold_mean*(`a'+1)
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
generate x_betahat1c = SN_b1*threshold_plus
		+ SN_b2*(`a'+1)
		+ SN_b3*threshold_plus*(`a'+1)
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
gen prob0c =exp(x_betahat0c)/(1+exp(x_betahat0c));
gen prob1c =exp(x_betahat1c)/(1+exp(x_betahat1c));
gen diffc=prob1c-prob0c;
gen diff_diff=diffc-diff;
gen percentc = (diffc/prob0c)*100;
gen diff_percent=percentc-percent;		

egen probhat0c =mean(prob0c);
egen probhat1c=mean(prob1c);
egen diffhatc=mean(diffc);
egen diff_diffhat=mean(diff_diff);
egen percentchat=mean(percentc);
egen diff_percenthat=mean(diff_percent);

tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
         percent_hat percent_lo percent_hi 
         prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c 
         diff_hatc diff_loc diff_hic  diff_diff_hat diff_diff_lo diff_diff_hi
         percentc_hat percentc_lo percentc_hi
         diff_percent_hat diff_percent_lo diff_percent_hi;

_pctile prob0, p(2.5,97.5) ;
scalar `lo0' = r(r1);
scalar `hi0' = r(r2);

_pctile prob1, p(2.5,97.5);
scalar `lo1'= r(r1);
scalar `hi1'= r(r2);

_pctile diff, p(2.5,97.5);
scalar `diff_lo'= r(r1);
scalar `diff_hi'= r(r2);

_pctile percent, p(2.5,97.5);
scalar `percent_lo'= r(r1);
scalar `percent_hi'= r(r2);

scalar `prob_hat0'=probhat0;
scalar `prob_hat1'=probhat1;
scalar `diff_hat'=diffhat;
scalar `percent_hat'=percenthat;

_pctile prob0c, p(2.5,97.5) ;
scalar `lo0c' = r(r1);
scalar `hi0c' = r(r2);

_pctile prob1c, p(2.5,97.5);
scalar `lo1c'= r(r1);
scalar `hi1c'= r(r2);

_pctile diffc, p(2.5,97.5);
scalar `diff_loc'= r(r1);
scalar `diff_hic'= r(r2);

_pctile diff_diff, p(2.5,97.5);
scalar `diff_diff_lo'= r(r1);
scalar `diff_diff_hi'= r(r2);

scalar `prob_hat0c'=probhat0c;
scalar `prob_hat1c'=probhat1c;
scalar `diff_hatc'=diffhatc;
scalar `diff_diff_hat'=diff_diffhat;

_pctile percentc, p(2.5,97.5);
scalar `percentc_lo'= r(r1);
scalar `percentc_hi'= r(r2);

_pctile diff_percent, p(2.5,97.5);
scalar `diff_percent_lo'= r(r1);
scalar `diff_percent_hi'= r(r2);

scalar `percentc_hat'=percentchat;
scalar `diff_percent_hat'=diff_percenthat;

post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
            (`diff_hat') (`diff_lo') (`diff_hi') (`percent_hat') (`percent_lo') (`percent_hi')  
            (`prob_hat0c') (`lo0c') (`hi0c') (`prob_hat1c') (`lo1c') (`hi1c') 
            (`diff_hatc') (`diff_loc') (`diff_hic') (`diff_diff_hat') (`diff_diff_lo') (`diff_diff_hi')
            (`percentc_hat') (`percentc_lo') (`percentc_hi') (`diff_percent_hat') (`diff_percent_lo') (`diff_percent_hi');

};

drop x_betahat0 x_betahat1 prob0 prob1 diff percent probhat0 probhat1 diffhat percenthat 
		x_betahat0c x_betahat1c prob0c prob1c diffc diff_diff probhat0c probhat1c diffhatc diff_diffhat 
        percentc diff_percent percentchat diff_percenthat;
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim.dta";

gen yline=0;

gen MV = (_n-1)/10;

replace MV=. if _n>1001;

*     ****************************************************************  *;
*		Figure 8.12a. The histogram differs slightly from the one 		*;
*		shown in Figure 8.12a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist polarization, percent color(gs13) yaxis(2)
		|| line diff_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line diff_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line diff_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(-0.05 0 .05 0.1 0.15 0.2 0.25 0.3, axis(1) nogrid labsize(2))
			ylabel(0 2 4 6 8  10, axis(2) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Change in Probability", size(2.5))
    		ytitle("Percentage of Observations", color(gs12) axis(2) size(2.5))
    		title("", size(3)) subtitle("", size(3)) xtitle("Polarization", size(2.5)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
                
*     ****************************************************************  *;
*		Figure 8.12b. The histogram differs slightly from the one 		*;
*		shown in Figure 8.12b because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist polarization, percent color(gs13) yaxis(2)
		|| line percent_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line percent_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line percent_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(0 40 80 120 160 200 240 280, axis(1) nogrid labsize(2))
			ylabel(0 2 4 6 8  10, axis(2) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Percentage Change in Probability", size(2.5))
    		ytitle("Percentage of Observations", color(gs12) axis(2) size(2.5))
    		title("", size(3)) subtitle("", size(3)) xtitle("Polarization", size(2.5)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

list percent_hat percent_lo percent_hi if MV==10;
list percent_hat percent_lo percent_hi if MV==29.5;
list percent_hat percent_lo percent_hi if MV==49;

*     ****************************************************************  *;
*		Figure 8.12c. The histogram differs slightly from the one 		*;
*		shown in Figure 8.12c because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist polarization, percent color(gs13) yaxis(2)
		|| line diff_diff_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line diff_diff_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line diff_diff_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue) 
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid) || , 
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(-0.001 0 0.001 0.002 0.003 0.004 0.005, nogrid labsize(2)) 
			ylabel(0 2 4 6 8  10, axis(2) nogrid labsize(2)) 
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off) 
			yline(0, lcolor(black)) 
			ytitle("Interaction Effect", size(2.5)) 
			ytitle("Percentage of Observations", color(gs12) axis(2) size(2.5)) 
			title("", size(3)) subtitle("", size(3)) xtitle("Polarization", size(2.5)) 
			xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
			
list diff_diff_hat diff_diff_lo diff_diff_hi if MV==29.5;

*     ****************************************************************  *;
*		Let's calculate effect of a one standard deviation increase in	*;
*		Disproportionality on the probability of pre-electoral 			*;
*		coalition formation for all of our sample observations			*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

*     ****************************************************************  *;
*		Predicted probability of PEC formation for sample observations	*;
*		using Stata's in-built command									*;
*     ****************************************************************  *;

predict phat;
label var phat "predicted probability";

sum phat;

sum phat, detail;

*     ****************************************************************  *;
*		Predicted probability of PEC formation for sample observations	*;
*		in baseline scenario defined by sample values. This will give	*;
*		the same values as phat and can be used as a check that 		*;
*		code is correct													*;
*     ****************************************************************  *;

predictnl prob_base= exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_base);

*     ****************************************************************  *;
*		Predicted probability of PEC formation for sample observations	*;
*		in counterfactual scenario where we increase Disproportionality	*;
*		by a standard deviation											*;
*     ****************************************************************  *;

predictnl prob_counterfactual= exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_counterfactual);

*     ****************************************************************  *;
*		Change in predicted probability of PEC formation for sample 	*;
*		from baseline to counterfactual scenario						*;
*     ****************************************************************  *;

predictnl change= (exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))), se(se_change);

*     ****************************************************************  *;
*		Percentage change in predicted probability of PEC formation for *;
*		sample from baseline to counterfactual scenario					*;
*     ****************************************************************  *;

predictnl percentage_change= (((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))))/(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))))*100, se(se_change_percent);

*     ****************************************************************  *;
*		Get mean, min, and max for change and percentage change across 	*;
*		our sample observations.										*;
*     ****************************************************************  *;

sum change percentage_change;

*     ****************************************************************  *;
*		Compare to percentage change when our variables were set at 	*;
*		their means that we calculated earlier.							*;
*     ****************************************************************  *;

list percent_hat percent_lo percent_hi if MV==29.5;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.13 in Stata. Show how the effect *;
*		of a standard deviation increase in Disproportionality on the	*;
*		probability of pre-electoral coalition formation varies with	*;
*		the value of Polarization across the sample observations. Note 	*;
*		that the figures in the book were created using pgfplots, not 	*;
*		Stata															*;
*     ****************************************************************  *;
*     ****************************************************************  *;

scalar z=invnormal(0.975);

gen lower_percentage_change=percentage_change-(z*se_change_percent);
gen upper_percentage_change=percentage_change+(z*se_change_percent);

*     ****************************************************************  *;
*		Get error for error bars for percentage change					*;
*     ****************************************************************  *;

gen error1 = z*se_change_percent;
label var error1 "width of error bar in CI for percentage change in one direction";

*     ****************************************************************  *;
*		Produce Figure 8.13												*;
*     ****************************************************************  *;										

graph twoway scatter percentage_change polarization, msymbol(smcircle) mfcolor(ebblue) clwidth(thin) clcolor(ebblue) msize(tiny)
		||  rcap lower_percentage_change upper_percentage_change polarization, lwidth(vvthin) lcolor(gray) msize(thin)
		|| function y = 0, range(0 100) lwidth(thin) color(black) lpattern(dash)
		|| ,  
		ytitle("Percentage Change in Probability of PEC Formation", size(2))  
		title("", size(3)) subtitle("", size(3)) xtitle("Party System Polarization", size(2)) 
		xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2)) ylabel(0 50 100 150 200 250 300 350, nogrid labsize(2))  
		legend(off) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
				
*     ****************************************************************  *;
*		There are no confidence intervals that cross the zero line.		*;
*     ****************************************************************  *;

sum lower_percentage_change if lower_percentage_change<0;
				
*     ****************************************************************  *;
*		Compare percentage change between elections with values of		*;
*		polarization in the lowest quartile to those with values in the	*;
*		highest quartile.												*;
*     ****************************************************************  *;
		
sum percentage_change if polarization<polarization_25;
scalar percentage_change25=r(mean);
di percentage_change25;
sum percentage_change if polarization>polarization_75;
scalar percentage_change75=r(mean);
di percentage_change75;

di percentage_change75/percentage_change25;

*     ****************************************************************  *;
*		Get at modifying effect of one unit increase in Polarization	*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Obtain predicted probability for each observation in the new	*;
*		baseline scenario where polarization is one unit higher than	*;
*		before.															*;
*     ****************************************************************  *;

predictnl prob_base2= exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_base2);

*     ****************************************************************  *;
*		Obtain predicted probability for each observation in the new	*;
*		counterfactual scenario where polarization is one unit higher 	*;
*		than before.													*;
*     ****************************************************************  *;

predictnl prob_counterfactual2= exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_counterfactual2);

*     ****************************************************************  *;
*		We can now calculate the interaction effect as					*;
*		(prob_counterfactual2 - prob_base2) minus						*;
*		(prob_counterfactual - prob_base)								*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		First way below doesn't give us standard errors, but does let 	*;
*		us check that the second way is correct.						*;
*     ****************************************************************  *;

predictnl interaction = (prob_counterfactual2-prob_base2)-(prob_counterfactual - prob_base);

*     ****************************************************************  *;
*		Second way gives us standard errors as well						*;
*     ****************************************************************  *;

predictnl interaction_effect=((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))) - (exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))) - ((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-( exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))), se(se_interaction);

*     ****************************************************************  *;
*		If we wanted to, we can also calculate the interaction effect	*;
*		in terms of marginal effects.									*;
*     ****************************************************************  *;

predictnl interaction_effect_me= ((exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))*(1-exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))*_b[polarization_threshold]) + ((exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))*(1-exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))*(1-2*exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))*(_b[threshold]+_b[polarization_threshold]*polarization)*(_b[polarization]+_b[polarization_threshold]*threshold)), se(se_interaction_me);

*     ****************************************************************  *;
*		Min, max, and mean modifying effect of a one-unit increase in 	*;
*		polarization on a one standard deviation increase in 			*;
*		disproportionalityacross the sample observations.				*;
*     ****************************************************************  *;

sum interaction_effect;

*     ****************************************************************  *;
*		Compare to same interaction (modifying) effect when our 		*;
*		variables were set at their means that we calculated earlier.	*;
*     ****************************************************************  *;

list diff_diff_hat diff_diff_lo diff_diff_hi if MV==29.5;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.14 in Stata. Show how the  		*;
*		interaction effect varies with the probability of pre-electoral *;
*		coalition formation. Note that the figures in the book were 	*;
*		created using pgfplots, not Stata								*;
*     ****************************************************************  *;
*     ****************************************************************  *;

gen lower_interaction_effect=interaction_effect-(z*se_interaction);
gen upper_interaction_effect=interaction_effect+(z*se_interaction);

*     ****************************************************************  *;
*		Get error for error bars for interaction effect					*;
*     ****************************************************************  *;

gen error = z*se_interaction;
label var error "width of error bar in CI in one direction";

*     ****************************************************************  *;
*		Figure 8.14														*;
*     ****************************************************************  *;

graph twoway rcap lower_interaction_effect upper_interaction_effect prob_base, lwidth(vvthin) lcolor(gray) msize(thin)  
		|| scatter interaction_effect prob_base, msymbol(Oh) mlwidth(thin) mlcolor(ebblue) msize(tiny)
		|| lowess interaction_effect prob_base, lwidth(thin) lcolor(gs5) bwidth(0.03)
 		|| function y = 0, range(0 0.4) lwidth(thin) color(black) lpattern(dash)
		ytitle("Interaction Effect", size(2))  
		title("", size(3)) subtitle("", size(3)) xtitle("Probability of Pre-Electoral Coalition Formation", size(2)) 
		xlabel(0 0.05 0.1 0.15 0.2 0.25 0.3 0.35 0.4, nogrid labsize(2)) ylabel(-0.002 0 0.002 0.004 0.006 0.008, nogrid labsize(2))  
		legend(off) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
		
*     ****************************************************************  *;
*		We could also add lowess curves for confidence intervals.		*;
*		Lowess curves for confidence intervals are always positive		*;
*     ****************************************************************  *;

graph twoway rcap lower_interaction_effect upper_interaction_effect prob_base, lwidth(vvthin) lcolor(gray) msize(thin)  
		|| scatter interaction_effect prob_base, msymbol(Oh) mlwidth(thin) mlcolor(ebblue) msize(tiny)
		|| lowess interaction_effect prob_base, lwidth(thin) lcolor(gs5) bwidth(0.03)
		|| lowess lower_interaction_effect prob_base, lcolor(gs5) bwidth(0.03) lpattern(shortdash)
		|| lowess upper_interaction_effect prob_base, lcolor(gs5) bwidth(0.03) lpattern(shortdash)
 		|| function y = 0, range(0 0.4) lwidth(thin) color(black) lpattern(dash)
		ytitle("Interaction Effect", size(2))  
		title("", size(3)) subtitle("", size(3)) xtitle("Probability of Pre-Electoral Coalition Formation", size(2)) 
		xlabel(0 0.05 0.1 0.15 0.2 0.25 0.3 0.35 0.4, nogrid labsize(2)) ylabel(-0.002 0 0.002 0.004 0.006 0.008, nogrid labsize(2))  
		legend(off) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
		
*     ****************************************************************  *;
*		Confidence intervals that cross the zero line					*;
*     ****************************************************************  *;

sum lower_interaction_effect;
scalar obs=r(N);
di obs;
		
sum lower_interaction_effect if lower_interaction_effect<0;
scalar number=r(N);
di number;

di (1-(number/obs))*100;

log close;
exit;
