version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_application/pec4.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec4.do                              			*;
*       Date:           January 30, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Replicate main results for substantive 			*;
*						effects of potential coalition size in the  	*;
*						application in Chapter 8 looking at the  		*;
*						determinants of pre-electoral coalition 		*;
*						formation										*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec2.log                             			*;
*       Data Output:    pec_BJPS.dta                                    *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;


*     ****************************************************************  *;
*		Get polarization and threshold measures by election.			*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum threshold;
scalar threshold_mean=r(mean);
di threshold_mean;
scalar threshold_sd=r(sd);
di threshold_sd;

sum polarization;
scalar polarization_mean=r(mean);
di polarization_mean;
scalar polarization_sd=r(sd);
di polarization_sd;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.2 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility, or;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.16 in Stata. Effect of a 		*;
*		ten unit increase in Coalition Size on the probability of PEC	*;
*		formation when Disproportionality, Seatshare, and Ideological 	*;
*		Incompatibility are all at their means.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get values for our variables									*;
*     ****************************************************************  *;

sum seatshare;
scalar seatshare_mean=r(mean);
scalar seatshare_sd=r(sd);
scalar seatshare_plus=seatshare_mean+seatshare_sd;

sum incompatibility;
scalar incompatibility_mean=r(mean);
scalar incompatibility_sd=r(sd);

scalar threshold_plus=threshold_mean+threshold_sd;
scalar polarization_plus=polarization_mean+polarization_sd;
scalar constant=1;

di threshold_sd;
di threshold_mean;
di threshold_plus;
di polarization_sd;
di polarization_mean;
di polarization_plus;
di seatshare_sd;
di seatshare_mean;
di seatshare_plus;
di incompatibility_sd;
di incompatibility_mean;
di constant;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

preserve;

set seed 10101;

drawnorm SN_b1-SN_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi percent_hat percent_lo percent_hi
	prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c diff_hatc diff_loc diff_hic diff_diff_hat diff_diff_lo diff_diff_hi
    percentc_hat percentc_lo percentc_hi diff_percent_hat diff_percent_lo diff_percent_hi
    using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim4.dta", replace;	
		
noisily display "start";

local a=0 ;
while `a' <= 100.1 { ;
{;

*     ****************************************************************  *;
*		xbeta in baseline												*;
*     ****************************************************************  *;

generate x_betahat0 = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*`a'
		+ SN_b5*`a'*`a'
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		xbeta in counterfactual											*;
*     ****************************************************************  *;
		
generate x_betahat1 = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+10)
		+ SN_b5*(`a'+10)*(`a'+10)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		Probability in baseline	and counterfactual						*;
*     ****************************************************************  *;
		
gen prob0 =exp(x_betahat0)/(1+exp(x_betahat0));
gen prob1 =exp(x_betahat1)/(1+exp(x_betahat1));

*     ****************************************************************  *;
*		Change and percentage change in probability						*;
*     ****************************************************************  *;

gen diff=prob1-prob0;
gen percent = (diff/prob0)*100;		
		
egen probhat0 =mean(prob0);
egen probhat1=mean(prob1);
egen diffhat=mean(diff);
egen percenthat=mean(percent);	

*     ****************************************************************  *;
*		Get information for modifying effect of a one unit increase in	*;
*		coalition size													*;
*     ****************************************************************  *;
		
generate x_betahat0c = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+1)
		+ SN_b5*(`a'+1)*(`a'+1)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
generate x_betahat1c = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+11)
		+ SN_b5*(`a'+11)*(`a'+11)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
gen prob0c =exp(x_betahat0c)/(1+exp(x_betahat0c));
gen prob1c =exp(x_betahat1c)/(1+exp(x_betahat1c));
gen diffc=prob1c-prob0c;
gen diff_diff=diffc-diff;
gen percentc = (diffc/prob0c)*100;
gen diff_percent=percentc-percent;		

egen probhat0c =mean(prob0c);
egen probhat1c=mean(prob1c);
egen diffhatc=mean(diffc);
egen diff_diffhat=mean(diff_diff);
egen percentchat=mean(percentc);
egen diff_percenthat=mean(diff_percent);

tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
         percent_hat percent_lo percent_hi 
         prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c 
         diff_hatc diff_loc diff_hic  diff_diff_hat diff_diff_lo diff_diff_hi
         percentc_hat percentc_lo percentc_hi
         diff_percent_hat diff_percent_lo diff_percent_hi;

_pctile prob0, p(2.5,97.5) ;
scalar `lo0' = r(r1);
scalar `hi0' = r(r2);

_pctile prob1, p(2.5,97.5);
scalar `lo1'= r(r1);
scalar `hi1'= r(r2);

_pctile diff, p(2.5,97.5);
scalar `diff_lo'= r(r1);
scalar `diff_hi'= r(r2);

_pctile percent, p(2.5,97.5);
scalar `percent_lo'= r(r1);
scalar `percent_hi'= r(r2);

scalar `prob_hat0'=probhat0;
scalar `prob_hat1'=probhat1;
scalar `diff_hat'=diffhat;
scalar `percent_hat'=percenthat;

_pctile prob0c, p(2.5,97.5) ;
scalar `lo0c' = r(r1);
scalar `hi0c' = r(r2);

_pctile prob1c, p(2.5,97.5);
scalar `lo1c'= r(r1);
scalar `hi1c'= r(r2);

_pctile diffc, p(2.5,97.5);
scalar `diff_loc'= r(r1);
scalar `diff_hic'= r(r2);

_pctile diff_diff, p(2.5,97.5);
scalar `diff_diff_lo'= r(r1);
scalar `diff_diff_hi'= r(r2);

scalar `prob_hat0c'=probhat0c;
scalar `prob_hat1c'=probhat1c;
scalar `diff_hatc'=diffhatc;
scalar `diff_diff_hat'=diff_diffhat;

_pctile percentc, p(2.5,97.5);
scalar `percentc_lo'= r(r1);
scalar `percentc_hi'= r(r2);

_pctile diff_percent, p(2.5,97.5);
scalar `diff_percent_lo'= r(r1);
scalar `diff_percent_hi'= r(r2);

scalar `percentc_hat'=percentchat;
scalar `diff_percent_hat'=diff_percenthat;

post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
            (`diff_hat') (`diff_lo') (`diff_hi') (`percent_hat') (`percent_lo') (`percent_hi')  
            (`prob_hat0c') (`lo0c') (`hi0c') (`prob_hat1c') (`lo1c') (`hi1c') 
            (`diff_hatc') (`diff_loc') (`diff_hic') (`diff_diff_hat') (`diff_diff_lo') (`diff_diff_hi')
            (`percentc_hat') (`percentc_lo') (`percentc_hi') (`diff_percent_hat') (`diff_percent_lo') (`diff_percent_hi');

};

drop x_betahat0 x_betahat1 prob0 prob1 diff percent probhat0 probhat1 diffhat percenthat 
		x_betahat0c x_betahat1c prob0c prob1c diffc diff_diff probhat0c probhat1c diffhatc diff_diffhat 
        percentc diff_percent percentchat diff_percenthat;
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim4.dta";

gen yline=0;

gen MV = (_n-1)/10;

replace MV=. if _n>1001;

*     ****************************************************************  *;
*		Figure 8.16a. The histogram differs slightly from the one 		*;
*		shown in Figure 8.16a because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist seatshare, percent color(gs13) yaxis(2)
		|| line diff_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line diff_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line diff_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(-0.025 -0.02 -0.015 -0.01 -0.005 0 0.005 0.01 0.015 0.02 0.025, axis(1) nogrid labsize(2))
			ylabel(0 2 4 6 8, axis(2) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Change in Probability", size(2))
    		ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
    		title("", size(3)) subtitle("", size(3)) xtitle("Expected Coalition Size", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
    		
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

sum seatshare;
scalar total=r(N);
di total;

sum seatshare if seatshare<22.7;
scalar subtotal1 = r(N);
di subtotal1;
di (subtotal1/total)*100;

sum seatshare if seatshare>41.5 & seatshare~=.;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;  
            
*     ****************************************************************  *;
*		Figure 8.16b. The histogram differs slightly from the one 		*;
*		shown in Figure 8.16b because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist seatshare, percent color(gs13) yaxis(2)
		|| line percent_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line percent_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line percent_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(0 2 4 6 8, axis(2) nogrid labsize(2))
			ylabel(-100 -75 -50 -25 0 25 50 75 100, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Percentage Change in Probability", size(2))
    		ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
    		title("", size(3)) subtitle("", size(3)) xtitle("Expected Coalition Size", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Some specific values											*;
*     ****************************************************************  *;

list MV percent_hat percent_lo percent_hi if _n==103;
list MV percent_hat percent_lo percent_hi if _n==315;
list MV percent_hat percent_lo percent_hi if _n==526;

*     ****************************************************************  *;
*		Figure 8.16c. The histogram differs slightly from the one 		*;
*		shown in Figure 8.16c because the bar widths and locations are 	*;
*		not identical.													*;
*     ****************************************************************  *;

graph twoway hist seatshare, percent color(gs13) yaxis(2)
		|| line diff_diff_hat MV, clwidth(medthick) clcolor(blue) clcolor(black)
		|| line diff_diff_lo MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line diff_diff_hi MV, clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line yline MV, clwidth(thin) clcolor(black) clpattern(solid)
		|| ,
			xlabel(0 10 20 30 40 50 60 70 80 90 100, nogrid labsize(2))
			ylabel(0 2 4 6 8, axis(2) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			ylabel(-0.0015 -0.001 -0.0005 0 0.0005 0.001, axis(1) nogrid labsize(2))
			yline(0, lcolor(black))
			ytitle("Self-Interaction Effect", size(2))
    		ytitle("Percentage of Observations", color(gs12) axis(2) size(2))
    		title("", size(3)) subtitle("", size(3)) xtitle("Expected Coalition Size", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);

*     ****************************************************************  *;
*		Some specific values											*;
*     ****************************************************************  *;

sum seatshare;
scalar total=r(N);
di total;

sum seatshare if seatshare>9.2 & seatshare<55;
scalar subtotal1 = r(N);
di subtotal1;
di (subtotal1/total)*100;

sum seatshare if seatshare>82.8;
scalar subtotal2 = r(N);
di subtotal2;
di (subtotal2/total)*100;

log close;
exit;
