version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_application/pec_collectdata.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec_collectdata.do                              *;
*       Date:           January 29, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:      	Collect data necessary to help produce some of	*;
*						the figures in Chapter8							*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec_collectdata.log                             *;
*       Data Output:    sona.csv, pec_prob.csv, pec_prob2.csv, 			*;
*						pec_prob3.csv, pec_prob4.csv, pec_prob5.csv, 	*;
*						and pec_BJPS.dta                                *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

set more off;

*     ****************************************************************  *;
*        Load dataset                                          			*;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*		Get polarization and threshold measures by election. This 		*;
*		information will be used to create histograms in several 		*;
*		figures in chapter 8.											*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum threshold;
scalar threshold_mean=r(mean);
di threshold_mean;
scalar threshold_sd=r(sd);
di threshold_sd;

sum polarization;
scalar polarization_mean=r(mean);
di polarization_mean;
scalar polarization_sd=r(sd);
di polarization_sd;

*     ****************************************************************  *;
*		Save data														*;
*     ****************************************************************  *;

outfile using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sona.csv", comma replace;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Get confidence intervals for Figure 8.12.						*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get values for our variables									*;
*     ****************************************************************  *;

sum seatshare;
scalar seatshare_mean=r(mean);
scalar seatshare_sd=r(sd);
scalar seatshare_plus=seatshare_mean+seatshare_sd;

sum incompatibility;
scalar incompatibility_mean=r(mean);
scalar incompatibility_sd=r(sd);

scalar threshold_plus=threshold_mean+threshold_sd;
scalar polarization_plus=polarization_mean+polarization_sd;
scalar constant=1;

di threshold_sd;
di threshold_mean;
di threshold_plus;
di polarization_sd;
di polarization_mean;
di polarization_plus;
di seatshare_sd;
di seatshare_mean;
di seatshare_plus;
di incompatibility_sd;
di incompatibility_mean;
di constant;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

preserve;

set seed 10101;

drawnorm SN_b1-SN_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi percent_hat percent_lo percent_hi
	prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c diff_hatc diff_loc diff_hic diff_diff_hat diff_diff_lo diff_diff_hi
    percentc_hat percentc_lo percentc_hi diff_percent_hat diff_percent_lo diff_percent_hi
    using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim.dta", replace;	
		
noisily display "start";

local a=0 ;
while `a' <= 100.1 { ;
{;

*     ****************************************************************  *;
*		xbeta in baseline												*;
*     ****************************************************************  *;

generate x_betahat0 = SN_b1*threshold_mean
		+ SN_b2*`a'
		+ SN_b3*threshold_mean*`a'
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		xbeta in counterfactual											*;
*     ****************************************************************  *;
		
generate x_betahat1 = SN_b1*threshold_plus
		+ SN_b2*`a'
		+ SN_b3*threshold_plus*`a'
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		Probability in baseline	and counterfactual						*;
*     ****************************************************************  *;
		
gen prob0 =exp(x_betahat0)/(1+exp(x_betahat0));
gen prob1 =exp(x_betahat1)/(1+exp(x_betahat1));

*     ****************************************************************  *;
*		Change and percentage change in probability						*;
*     ****************************************************************  *;

gen diff=prob1-prob0;
gen percent = (diff/prob0)*100;		
		
egen probhat0 =mean(prob0);
egen probhat1=mean(prob1);
egen diffhat=mean(diff);
egen percenthat=mean(percent);	

*     ****************************************************************  *;
*		Get information for modifying effect of a one unit increase in	*;
*		polarization													*;
*     ****************************************************************  *;
		
generate x_betahat0c = SN_b1*threshold_mean
		+ SN_b2*(`a'+1)
		+ SN_b3*threshold_mean*(`a'+1)
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
generate x_betahat1c = SN_b1*threshold_plus
		+ SN_b2*(`a'+1)
		+ SN_b3*threshold_plus*(`a'+1)
		+ SN_b4*seatshare_mean
		+ SN_b5*seatshare_mean*seatshare_mean
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
gen prob0c =exp(x_betahat0c)/(1+exp(x_betahat0c));
gen prob1c =exp(x_betahat1c)/(1+exp(x_betahat1c));
gen diffc=prob1c-prob0c;
gen diff_diff=diffc-diff;
gen percentc = (diffc/prob0c)*100;
gen diff_percent=percentc-percent;		

egen probhat0c =mean(prob0c);
egen probhat1c=mean(prob1c);
egen diffhatc=mean(diffc);
egen diff_diffhat=mean(diff_diff);
egen percentchat=mean(percentc);
egen diff_percenthat=mean(diff_percent);

tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
         percent_hat percent_lo percent_hi 
         prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c 
         diff_hatc diff_loc diff_hic  diff_diff_hat diff_diff_lo diff_diff_hi
         percentc_hat percentc_lo percentc_hi
         diff_percent_hat diff_percent_lo diff_percent_hi;

_pctile prob0, p(2.5,97.5) ;
scalar `lo0' = r(r1);
scalar `hi0' = r(r2);

_pctile prob1, p(2.5,97.5);
scalar `lo1'= r(r1);
scalar `hi1'= r(r2);

_pctile diff, p(2.5,97.5);
scalar `diff_lo'= r(r1);
scalar `diff_hi'= r(r2);

_pctile percent, p(2.5,97.5);
scalar `percent_lo'= r(r1);
scalar `percent_hi'= r(r2);

scalar `prob_hat0'=probhat0;
scalar `prob_hat1'=probhat1;
scalar `diff_hat'=diffhat;
scalar `percent_hat'=percenthat;

_pctile prob0c, p(2.5,97.5) ;
scalar `lo0c' = r(r1);
scalar `hi0c' = r(r2);

_pctile prob1c, p(2.5,97.5);
scalar `lo1c'= r(r1);
scalar `hi1c'= r(r2);

_pctile diffc, p(2.5,97.5);
scalar `diff_loc'= r(r1);
scalar `diff_hic'= r(r2);

_pctile diff_diff, p(2.5,97.5);
scalar `diff_diff_lo'= r(r1);
scalar `diff_diff_hi'= r(r2);

scalar `prob_hat0c'=probhat0c;
scalar `prob_hat1c'=probhat1c;
scalar `diff_hatc'=diffhatc;
scalar `diff_diff_hat'=diff_diffhat;

_pctile percentc, p(2.5,97.5);
scalar `percentc_lo'= r(r1);
scalar `percentc_hi'= r(r2);

_pctile diff_percent, p(2.5,97.5);
scalar `diff_percent_lo'= r(r1);
scalar `diff_percent_hi'= r(r2);

scalar `percentc_hat'=percentchat;
scalar `diff_percent_hat'=diff_percenthat;

post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
            (`diff_hat') (`diff_lo') (`diff_hi') (`percent_hat') (`percent_lo') (`percent_hi')  
            (`prob_hat0c') (`lo0c') (`hi0c') (`prob_hat1c') (`lo1c') (`hi1c') 
            (`diff_hatc') (`diff_loc') (`diff_hic') (`diff_diff_hat') (`diff_diff_lo') (`diff_diff_hi')
            (`percentc_hat') (`percentc_lo') (`percentc_hi') (`diff_percent_hat') (`diff_percent_lo') (`diff_percent_hi');

};

drop x_betahat0 x_betahat1 prob0 prob1 diff percent probhat0 probhat1 diffhat percenthat 
		x_betahat0c x_betahat1c prob0c prob1c diffc diff_diff probhat0c probhat1c diffhatc diff_diffhat 
        percentc diff_percent percentchat diff_percenthat;
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim.dta";

gen yline=0;

gen MV = (_n-1)/10;

replace MV=. if _n>1001;

*     ****************************************************************  *;
*		Save data														*;
*     ****************************************************************  *;
		
keep MV diff_lo diff_hi percent_lo percent_hi diff_diff_hat diff_diff_lo diff_diff_hi diff_percent_hat diff_percent_lo diff_percent_hi;

order MV;
    
drop if MV>96.4;

outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_prob.csv", comma nonames replace;

clear;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Get information for point estimates and confidence intervals 	*;
*		for Figures 8.13 and 8.14.										*;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*		Get values for our variables									*;
*     ****************************************************************  *;

sum seatshare;
scalar seatshare_mean=r(mean);
scalar seatshare_sd=r(sd);
scalar seatshare_plus=seatshare_mean+seatshare_sd;

sum incompatibility;
scalar incompatibility_mean=r(mean);
scalar incompatibility_sd=r(sd);

scalar threshold_plus=threshold_mean+threshold_sd;
scalar polarization_plus=polarization_mean+polarization_sd;
scalar constant=1;

di threshold_sd;
di threshold_mean;
di threshold_plus;
di polarization_sd;
di polarization_mean;
di polarization_plus;
di seatshare_sd;
di seatshare_mean;
di seatshare_plus;
di incompatibility_sd;
di incompatibility_mean;
di constant;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

*     ****************************************************************  *;
*		Predicted probability of PEC formation for sample observations	*;
*		in baseline scenario defined by sample values. This will give	*;
*		the same values as phat and can be used as a check that 		*;
*		code is correct													*;
*     ****************************************************************  *;

predictnl prob_base= exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_base);

*     ****************************************************************  *;
*		Predicted probability of PEC formation for sample observations	*;
*		in counterfactual scenario where we increase Disproportionality	*;
*		by a standard deviation											*;
*     ****************************************************************  *;

predictnl prob_counterfactual= exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_counterfactual);

*     ****************************************************************  *;
*		Change in predicted probability of PEC formation for sample 	*;
*		from baseline to counterfactual scenario						*;
*     ****************************************************************  *;

predictnl change= (exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))), se(se_change);

*     ****************************************************************  *;
*		Percentage change in predicted probability of PEC formation for *;
*		sample from baseline to counterfactual scenario					*;
*     ****************************************************************  *;

predictnl percentage_change= (((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))))/(exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))))*100, se(se_change_percent);

scalar z=invnormal(0.975);

gen lower_percentage_change=percentage_change-(z*se_change_percent);
gen upper_percentage_change=percentage_change+(z*se_change_percent);

*     ****************************************************************  *;
*		Get error for error bars for percentage change					*;
*     ****************************************************************  *;

gen error1 = z*se_change_percent;
label var error1 "width of error bar in CI for percentage change in one direction";

*     ****************************************************************  *;
*		Obtain predicted probability for each observation in the new	*;
*		baseline scenario where polarization is one unit higher than	*;
*		before.															*;
*     ****************************************************************  *;

predictnl prob_base2= exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_base2);

*     ****************************************************************  *;
*		Obtain predicted probability for each observation in the new	*;
*		counterfactual scenario where polarization is one unit higher 	*;
*		than before.													*;
*     ****************************************************************  *;

predictnl prob_counterfactual2= exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)), se(se_counterfactual2);

*     ****************************************************************  *;
*		We can now calculate the interaction effect as					*;
*		(prob_counterfactual2 - prob_base2) minus						*;
*		(prob_counterfactual - prob_base)								*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Second way gives us standard errors as well						*;
*     ****************************************************************  *;

predictnl interaction_effect=((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility))) - (exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*(polarization+1)+_b[polarization_threshold]*((polarization+1)*threshold)+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))) - ((exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*(threshold+threshold_sd)+_b[polarization]*polarization+_b[polarization_threshold]*(polarization*(threshold+threshold_sd))+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))-( exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)/(1+exp(_b[_cons]+_b[threshold]*threshold+_b[polarization]*polarization+_b[polarization_threshold]*polarization_threshold+_b[seatshare]*seatshare+_b[seatshare_2]*seatshare_2+_b[incompatibility]*incompatibility)))), se(se_interaction);

gen lower_interaction_effect=interaction_effect-(z*se_interaction);
gen upper_interaction_effect=interaction_effect+(z*se_interaction);

*     ****************************************************************  *;
*		Get error for error bars for interaction effect					*;
*     ****************************************************************  *;

gen error = z*se_interaction;
label var error "width of error bar in CI in one direction";

*     ****************************************************************  *;
*		Obtain the lowess values for upper and lower bounds of the		*;
*		confidence intervals for the interaction effect					*;
*     ****************************************************************  *;

lowess lower_interaction_effect prob_base, bwidth(0.03) generate(lowess_lower);

lowess upper_interaction_effect prob_base, bwidth(0.03) generate(lowess_upper);

lowess interaction_effect prob_base, bwidth(0.03) generate(lowess_interaction);

*     ****************************************************************  *;
*		Save data														*;
*     ****************************************************************  *;

sort prob_base;

keep prob_base interaction_effect error lower_interaction_effect upper_interaction_effect 
		lowess_lower lowess_upper lowess_interaction polarization percentage_change error1;
		
order polarization prob_base percentage_change interaction_effect error1 
	lower_interaction_effect upper_interaction_effect lowess_lower lowess_upper lowess_interaction error;

drop if prob_base==.;

save "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_temp.dta", replace;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_temp.dta", replace;

keep prob_base interaction_effect error lower_interaction_effect upper_interaction_effect lowess_lower lowess_upper lowess_interaction;

outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_prob4.csv", comma nonames replace;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_temp.dta", replace;

keep polarization percentage_change error1;

sort polarization;

outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_prob5.csv", comma nonames replace;

clear;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Get information for point estimates and confidence intervals 	*;
*		for Figure 8.15.												*;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*		Get polarization standard deviation by election.				*;
*     ****************************************************************  *;

collapse (mean) threshold polarization, by(election);

sum polarization;
scalar polarization_sd=r(sd);
di polarization_sd;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*		Summary statistics												*;
*     ****************************************************************  *;

desc;

summarize pec seatshare incompatibility polarization threshold;

tab pec;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.2 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility, or;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.15 in Stata. Percentage change	*;
*		in the odds of PEC formation associated with a one standard 	*;
*		deviation increase in Polarization.								*;
*     ****************************************************************  *;
*     ****************************************************************  *;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim2.dta", replace;	
		
noisily display "start";

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

local a=0 ;
while `a' <= 35.1 { ;
{;

lincom (_b[polarization]+_b[polarization_threshold]*`a')*polarization_sd, or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim2.dta";

gen yline=1;

gen MV = (_n-1)/10;

replace MV=. if _n>351;
	
*     ****************************************************************  *;
*		Get percentage change in odds									*;
*     ****************************************************************  *;
    
gen odds_percent=(odds_hat-1)*100;
gen odds_percent_lo=(odds_lo-1)*100;
gen odds_percent_hi=(odds_hi-1)*100;

keep MV odds_hat odds_lo odds_hi;
    
order MV;
    
drop if _n>351;
    
outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_prob2.csv" , comma nonames replace;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Get information on confidence intervals for Figure 8.16.		*;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

collapse (mean) threshold polarization, by(election);

sum threshold;
scalar threshold_mean=r(mean);
di threshold_mean;
scalar threshold_sd=r(sd);
di threshold_sd;

sum polarization;
scalar polarization_mean=r(mean);
di polarization_mean;
scalar polarization_sd=r(sd);
di polarization_sd;

clear;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_BJPS.dta", replace;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 8.16 in Stata. Effect of a 		*;
*		ten unit increase in Coalition Size on the probability of PEC	*;
*		formation when Disproportionality, Seatshare, and Ideological 	*;
*		Incompatibility are all at their means.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Get values for our variables									*;
*     ****************************************************************  *;

sum seatshare;
scalar seatshare_mean=r(mean);
scalar seatshare_sd=r(sd);
scalar seatshare_plus=seatshare_mean+seatshare_sd;

sum incompatibility;
scalar incompatibility_mean=r(mean);
scalar incompatibility_sd=r(sd);

scalar threshold_plus=threshold_mean+threshold_sd;
scalar polarization_plus=polarization_mean+polarization_sd;
scalar constant=1;

di threshold_sd;
di threshold_mean;
di threshold_plus;
di polarization_sd;
di polarization_mean;
di polarization_plus;
di seatshare_sd;
di seatshare_mean;
di seatshare_plus;
di incompatibility_sd;
di incompatibility_mean;
di constant;

logit pec threshold polarization polarization_threshold seatshare seatshare_2 incompatibility;

preserve;

set seed 10101;

drawnorm SN_b1-SN_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi percent_hat percent_lo percent_hi
	prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c diff_hatc diff_loc diff_hic diff_diff_hat diff_diff_lo diff_diff_hi
    percentc_hat percentc_lo percentc_hi diff_percent_hat diff_percent_lo diff_percent_hi
    using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim4.dta", replace;	
		
noisily display "start";

local a=0 ;
while `a' <= 100.1 { ;
{;

*     ****************************************************************  *;
*		xbeta in baseline												*;
*     ****************************************************************  *;

generate x_betahat0 = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*`a'
		+ SN_b5*`a'*`a'
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		xbeta in counterfactual											*;
*     ****************************************************************  *;
		
generate x_betahat1 = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+10)
		+ SN_b5*(`a'+10)*(`a'+10)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
*     ****************************************************************  *;
*		Probability in baseline	and counterfactual						*;
*     ****************************************************************  *;
		
gen prob0 =exp(x_betahat0)/(1+exp(x_betahat0));
gen prob1 =exp(x_betahat1)/(1+exp(x_betahat1));

*     ****************************************************************  *;
*		Change and percentage change in probability						*;
*     ****************************************************************  *;

gen diff=prob1-prob0;
gen percent = (diff/prob0)*100;		
		
egen probhat0 =mean(prob0);
egen probhat1=mean(prob1);
egen diffhat=mean(diff);
egen percenthat=mean(percent);	

*     ****************************************************************  *;
*		Get information for modifying effect of a one unit increase in	*;
*		polarization													*;
*     ****************************************************************  *;
		
generate x_betahat0c = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+1)
		+ SN_b5*(`a'+1)*(`a'+1)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
generate x_betahat1c = SN_b1*threshold_mean
		+ SN_b2*polarization_mean
		+ SN_b3*threshold_mean*polarization_mean
		+ SN_b4*(`a'+11)
		+ SN_b5*(`a'+11)*(`a'+11)
		+ SN_b6*incompatibility_mean
		+ SN_b7*constant;
		
gen prob0c =exp(x_betahat0c)/(1+exp(x_betahat0c));
gen prob1c =exp(x_betahat1c)/(1+exp(x_betahat1c));
gen diffc=prob1c-prob0c;
gen diff_diff=diffc-diff;
gen percentc = (diffc/prob0c)*100;
gen diff_percent=percentc-percent;		

egen probhat0c =mean(prob0c);
egen probhat1c=mean(prob1c);
egen diffhatc=mean(diffc);
egen diff_diffhat=mean(diff_diff);
egen percentchat=mean(percentc);
egen diff_percenthat=mean(diff_percent);

tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
         percent_hat percent_lo percent_hi 
         prob_hat0c lo0c hi0c prob_hat1c lo1c hi1c 
         diff_hatc diff_loc diff_hic  diff_diff_hat diff_diff_lo diff_diff_hi
         percentc_hat percentc_lo percentc_hi
         diff_percent_hat diff_percent_lo diff_percent_hi;

_pctile prob0, p(2.5,97.5) ;
scalar `lo0' = r(r1);
scalar `hi0' = r(r2);

_pctile prob1, p(2.5,97.5);
scalar `lo1'= r(r1);
scalar `hi1'= r(r2);

_pctile diff, p(2.5,97.5);
scalar `diff_lo'= r(r1);
scalar `diff_hi'= r(r2);

_pctile percent, p(2.5,97.5);
scalar `percent_lo'= r(r1);
scalar `percent_hi'= r(r2);

scalar `prob_hat0'=probhat0;
scalar `prob_hat1'=probhat1;
scalar `diff_hat'=diffhat;
scalar `percent_hat'=percenthat;

_pctile prob0c, p(2.5,97.5) ;
scalar `lo0c' = r(r1);
scalar `hi0c' = r(r2);

_pctile prob1c, p(2.5,97.5);
scalar `lo1c'= r(r1);
scalar `hi1c'= r(r2);

_pctile diffc, p(2.5,97.5);
scalar `diff_loc'= r(r1);
scalar `diff_hic'= r(r2);

_pctile diff_diff, p(2.5,97.5);
scalar `diff_diff_lo'= r(r1);
scalar `diff_diff_hi'= r(r2);

scalar `prob_hat0c'=probhat0c;
scalar `prob_hat1c'=probhat1c;
scalar `diff_hatc'=diffhatc;
scalar `diff_diff_hat'=diff_diffhat;

_pctile percentc, p(2.5,97.5);
scalar `percentc_lo'= r(r1);
scalar `percentc_hi'= r(r2);

_pctile diff_percent, p(2.5,97.5);
scalar `diff_percent_lo'= r(r1);
scalar `diff_percent_hi'= r(r2);

scalar `percentc_hat'=percentchat;
scalar `diff_percent_hat'=diff_percenthat;

post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
            (`diff_hat') (`diff_lo') (`diff_hi') (`percent_hat') (`percent_lo') (`percent_hi')  
            (`prob_hat0c') (`lo0c') (`hi0c') (`prob_hat1c') (`lo1c') (`hi1c') 
            (`diff_hatc') (`diff_loc') (`diff_hic') (`diff_diff_hat') (`diff_diff_lo') (`diff_diff_hi')
            (`percentc_hat') (`percentc_lo') (`percentc_hi') (`diff_percent_hat') (`diff_percent_lo') (`diff_percent_hi');

};

drop x_betahat0 x_betahat1 prob0 prob1 diff percent probhat0 probhat1 diffhat percenthat 
		x_betahat0c x_betahat1c prob0c prob1c diffc diff_diff probhat0c probhat1c diffhatc diff_diffhat 
        percentc diff_percent percentchat diff_percenthat;
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\sim4.dta";

gen yline=0;

gen MV = (_n-1)/10;

replace MV=. if _n>1001;
             
keep MV diff_lo diff_hi percent_lo percent_hi diff_diff_hat diff_diff_lo diff_diff_hi;
    
order MV;

drop if MV>100;
       
outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter8_application\pec_prob3.csv" , comma nonames replace;

log close;
exit;
