version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_exercise1/pec_exercise.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      pec_exercise.do                              	*;
*       Date:           January 30, 2022								*;
*       Author:         MG                                           	*;
*       Purpose:        Replicate results for Question 1 in Chapter 8	*;
* 	    Input File:     pec_BJPS.dta	                            	*;
*       Output File:    pec_exercise.log                             	*;
*       Data Output:    pec_BJPS.dta                                    *;             
*       Previous file:  	                                			*;
*       Machine:        laptop                          				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 50m;

use "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter8_exercise1/pec_BJPS.dta", replace;

set more off;

*     ****************************************************************  *;
*   	Create some variables                   						*;
*     ****************************************************************  *;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;
label var seatshare "size of potential coalition in percentage of seats";

generate seatshare_2 = seatshare*seatshare;
label var seatshare_2 "seatshare squared";

gen polarization_threshold = polarization*threshold;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 8.3 in Chapter 8					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

logit pec   threshold polarization polarization_threshold incompatibility;

logit pec   threshold polarization polarization_threshold incompatibility, or;

*     ****************************************************************  *;
*		Calculate marginal effect of Ideological Incompatibility when	*;
*		Disproportionality is 5, Polarization is 24.68, and Ideological	*;
*		Incompatibility is 19.51.										*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

margins, at(threshold= 5 polarization =24.68 polarization_threshold =123.4 incompatibility= 19.51) dydx(*);

logit pec c.threshold##c.polarization incompatibility;

margins, at(threshold= 5 polarization =24.68 incompatibility= 19.51) dydx(*);

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

scalar xbeta = _b[_cons]+_b[threshold]*5+_b[polarization]*24.68+_b[polarization_threshold]*5*24.68+_b[incompatibility]*19.51;
di xbeta;

scalar lambda = exp(xbeta)/(1+exp(xbeta));
di lambda;
di 1-lambda;

*     ****************************************************************  *;
*		Marginal effect of Ideological Incompatibility in chosen 		*;
*		scenario														*;
*     ****************************************************************  *;

scalar me_incompatibility = lambda*(1-lambda)*_b[incompatibility];
di me_incompatibility;

*     ****************************************************************  *;
*		Largest marginal effect of ideological incompatibility			*;
*     ****************************************************************  *;

scalar me_incompatibility_max = 0.5*0.5*_b[incompatibility];
di me_incompatibility_max;

*     ****************************************************************  *;
*		Marginal effect of Disproportionality in chosen scenario		*;
*     ****************************************************************  *;

scalar me_disproportionality = lambda*(1-lambda)*(_b[threshold]+_b[polarization_threshold]*24.68);
di me_disproportionality;

*     ****************************************************************  *;
*		Marginal effect of Polarization in chosen scenario				*;
*     ****************************************************************  *;

scalar me_polarization = lambda*(1-lambda)*(_b[polarization]+_b[polarization_threshold]*5);
di me_polarization;

*     ****************************************************************  *;
*		Calculate interaction effect of Disproportionality and 			*;
*		Polarization in chosen scenario									*;
*     ****************************************************************  *;

di lambda*(1-lambda)*_b[polarization_threshold] + lambda*(1-lambda)*(1-2*lambda)*(_b[threshold]+_b[polarization_threshold]*24.68)*(_b[polarization]+_b[polarization_threshold]*5);

*     ****************************************************************  *;
*		Calculate change and percentage change in the probability of	*;
*		PEC formation when we increase Polarization by 10 units when	*;
*		Polarization is 15, Disproportionality is 2, and Ideological	*;
*		Incompatibility is 24											*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Predicted probability when Disproportionality is 2, 			*;
*		Polarization is 15, and Ideological Incompatibility is 24		*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24));

logit pec c.threshold##c.polarization incompatibility;
margins, at(threshold= 2 polarization =15 incompatibility= 24);

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

scalar xbeta = _b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*2*15+_b[incompatibility]*24;
di xbeta;

scalar lambda = exp(xbeta)/(1+exp(xbeta));
di lambda;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di exp(-3.3622)/(1+exp(-3.3622));

*     ****************************************************************  *;
*		Predicted probability when Disproportionality is 2, 			*;
*		Polarization is 25, and Ideological Incompatibility is 24		*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24));

logit pec c.threshold##c.polarization incompatibility;

margins, at(threshold= 2 polarization =25 incompatibility= 24);

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

scalar xbeta2 = _b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*2*25+_b[incompatibility]*24;
di xbeta2;

scalar lambda2 = exp(xbeta2)/(1+exp(xbeta2));
di lambda2;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di  exp(-3.3152)/(1+exp(-3.3152));

*     ****************************************************************  *;
*		Change in probability across the two scenarios when 			*;
*		Polarization goes from 15 to 25									*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  (exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)));

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

di lambda2-lambda;

di ((lambda2-lambda)/lambda)*100;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di  (exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)));

di  (((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622))))/(exp(-3.3622)/(1+exp(-3.3622))))*100;

*     ****************************************************************  *;
*		Calculate change and percentage change in the probability of	*;
*		PEC formation when we increase Polarization by 10 units when	*;
*		Polarization is 15, Disproportionality is 10, and Ideological	*;
*		Incompatibility is 24											*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Predicted probability when Disproportionality is 10, 			*;
*		Polarization is 15, and Ideological Incompatibility is 24		*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24));

logit pec c.threshold##c.polarization incompatibility;
margins, at(threshold= 10 polarization =15 incompatibility= 24);

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

scalar xbeta3 = _b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*10*15+_b[incompatibility]*24;
di xbeta3;

scalar lambda3 = exp(xbeta3)/(1+exp(xbeta3));
di lambda3;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di exp(-3.0782)/(1+exp(-3.0782));

*     ****************************************************************  *;
*		Predicted probability when Disproportionality is 10, 			*;
*		Polarization is 25, and Ideological Incompatibility is 24		*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24));

logit pec c.threshold##c.polarization incompatibility;
margins, at(threshold= 10 polarization =25 incompatibility= 24);

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

scalar xbeta4 = _b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*10*25+_b[incompatibility]*24;
di xbeta4;

scalar lambda4 = exp(xbeta4)/(1+exp(xbeta4));
di lambda4;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di exp(-2.9912)/(1+exp(-2.9912));

*     ****************************************************************  *;
*		Change in probability across the two new scenarios when 		*;
*		Polarization goes from 15 to 25									*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

nlcom  (exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24)));

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

di lambda4-lambda3;

di ((lambda4-lambda3)/lambda3)*100;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di  (exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782)));
 
di  (((exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782))))/(exp(-3.0782)/(1+exp(-3.0782))))*100;

*     ****************************************************************  *;
*		Modifying effect of disproportionality going from 2 to 10 on 	*;
*		the effect of increasing polarization from 15 to 25				*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

nlcom  ((exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24))))-((exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24))));

nlcom  ((((exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*25+_b[polarization_threshold]*250+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*10+_b[polarization]*15+_b[polarization_threshold]*150+_b[incompatibility]*24))))-((exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)))))/((exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*25+_b[polarization_threshold]*50+_b[incompatibility]*24)))- (exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)/(1+exp(_b[_cons]+_b[threshold]*2+_b[polarization]*15+_b[polarization_threshold]*30+_b[incompatibility]*24)))))*100;

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

di (lambda4-lambda3)-(lambda2-lambda);
di (((lambda4-lambda3)-(lambda2-lambda))/(lambda2-lambda)*100);

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di  ((exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782))))-((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622))));

di  ((((exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782))))-((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)))))/((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)))))*100;

*     ****************************************************************  *;
*		Calculate the change and percentage change in the odds of PEC	*;
*		formation associated with increasing Disproportionality by 5	*;
*		units when Polarization is 10									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

lincom (_b[threshold]+_b[polarization_threshold]*10)*5, or;

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

di exp((_b[threshold]+_b[polarization_threshold]*10)*5);

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di exp((0.0280+0.0005*10)*5);

*     ****************************************************************  *;
*		Calculate the change and percentage change in the odds of PEC	*;
*		formation associated with increasing Disproportionality by 5	*;
*		units when Polarization is 30									*;
*     ****************************************************************  *;

logit pec threshold polarization polarization_threshold incompatibility;

*     ****************************************************************  *;
*		Use Stata's automated commands.									*;
*     ****************************************************************  *;

lincom (_b[threshold]+_b[polarization_threshold]*30)*5, or;

*     ****************************************************************  *;
*		Now manually													*;
*     ****************************************************************  *;

di exp((_b[threshold]+_b[polarization_threshold]*30)*5);

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di exp((0.0280+0.0005*30)*5);

*     ****************************************************************  *;
*		Modifying effect of increasing Polarization from 10 to 30		*;
*     ****************************************************************  *;

di (((exp((_b[threshold]+_b[polarization_threshold]*30)*5))-(exp((_b[threshold]+_b[polarization_threshold]*10)*5)))/(exp((_b[threshold]+_b[polarization_threshold]*10)*5)))*100;

*     ****************************************************************  *;
*		Using values provided in the book								*;
*     ****************************************************************  *;

di (((exp((0.0280+0.0005*30)*5))-(exp((0.0280+0.0005*10)*5)))/(exp((0.0280+0.0005*10)*5)))*100;

log close;
exit;
