version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter9_application/anes2012_analysis_approval.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      anes2012_analysis_approval.do                   *;
*       Date:           August 23, 2022                                 *;
*       Author:         MG                                          	*;
*       Purpose:      	Replicate main results for substantive 			*;
*						application in Chapter 9 looking at ideology, 	*;
*						race, and presidential approval for Barack 		*;
*						Obama											*;
* 	    Input File:     anes2012_small.dta       		                *;
*       Output File:    none			                                *;
*       Data Output:    none                                            *;             
*       Previous file:  					     						*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\anes2012_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*       Drop respondents who are not white or black						*;
*     ****************************************************************  *;

keep if white==1 | black==1;

sum;

*     ****************************************************************  *;
*		Generate interaction term for race and ideology					*;
*     ****************************************************************  *;

gen black_leftright=black*left_right;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 9.1 in Chapter 9					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

listcoef, help;

ologit obama_approval left_right black black_leftright worse_off_national female age, or;

*     ****************************************************************  *;
*		Check that cutpoints are different								*;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

test /cut1=/cut2;
test /cut2=/cut3;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 9.4a in Stata showing how the 		*;
*		effect of a one unit increase in ideology on the propensity to	*;
*		approve of Obama varies by race									*;
*     ****************************************************************  *;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

*     ****************************************************************  *;
*		Create a 3 x 2 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot = J(3, 2, .);
matrix coln plot = estimate se;

*     ****************************************************************  *;
*		Obtain the point estimates and standard errors for the effects	*;
*		shown in Figure 9.4a and place them in the matrix				*;
*     ****************************************************************  *;

lincom _b[black_leftright];
matrix plot[1,1]=r(estimate);
matrix plot[1,2]=r(se);

lincom _b[left_right]+_b[black_leftright]*0;
matrix plot[2,1]=r(estimate);
matrix plot[2,2]=r(se);

lincom _b[left_right]+_b[black_leftright]*1;
matrix plot[3,1]=r(estimate);
matrix plot[3,2]=r(se);

*     ****************************************************************  *;
*		Produce Figure 9.4a using coefplot								*;
*     ****************************************************************  *;

coefplot (matrix(plot[.,1]), se(plot[.,2]) offset(0) lwidth(thick) 
		m(smcircle) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204"))), 
		legend(off) xtitle("Effect Size", size(2)) levels(95) 
		xlab(-1.2 -1 -0.8 -0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8 1, tlcolor(black) labcolor(black) labsize(2) format(%9.1f) ) 		
		coeflabels(r1="Interaction Effect for Liberal-Conservative and Black" r2="Conservative Ideology among Whites" 
		r3="Conservative Ideology among Blacks", tlcolor(black) labcolor(black) labsize(2.)) 
		yscale(noline) xscale(noline) mlabel format(%9.2f) mlabposition(12) mlabgap(*2) mlabsize(2.5)  
		xline(0, lcolor(gray)) scheme(burd);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 9.4b in Stata showing how the 		*;
*		effect of being Black on the propensity to approve of Obama 	*;
*		varies with ideology											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

sum left_right;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar b7=b[1,7];
scalar b8=b[1,8];
scalar b9=b[1,9];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar varb4=V[4,4];
scalar varb5=V[5,5];
scalar varb6=V[6,6];
scalar covb1b3=V[1,3];
scalar covb3b2=V[3,2];
scalar covb4b5=V[4,5];

scalar list b1 b2 b3 b4 b5 b6 b7 b8 b9 varb1 varb2 varb3  varb4 varb5 varb6 covb1b3 covb3b2 covb4b5;

estat vce;

generate MV=(_n-1)/10;

replace MV=. if _n>72;

gen conbx=b2+b3*MV if _n<72;

gen consx=sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2) if _n<72;

scalar z=invnormal(0.975);

gen lowerx=conbx-(z*consx);

gen upperx=conbx+(z*consx);

*ssc install scheme-burd, replace;

*     ****************************************************************  *;
*		Produce the plot like Figure 9.4b. The plot is not identical	*;
*		to the one in Figure 9.4b  because the histogram doesn't 		*;
*		distinguish between Blacks and Whites. It is possible to add	*;
*		histograms by Blacks and Whites but the two histograms each sum	*;
*		to 100 percent when we want them together to sum to 100 		*;
*		percent. There's probably an easy way to get this, but we 		*;
*		didn't use Stata.												*;
*     ****************************************************************  *;

graph twoway hist left_right, percent color(gs13) lcolor(white) yaxis(2) 
		|| line upperx MV if MV>0.99, color(ebblue) clpattern(longdash) 
		|| line lowerx MV if MV>0.99, color(ebblue) clpattern(longdash)  
		|| line conbx MV if MV>0.99,color(black) lwidth(medthick) legend(off) clpattern(solid) 
			ytitle("Effect of being Black instead of White", size(2)) title("", size(3)) subtitle("", size(2)) 
			xtitle("Liberal-Conservative Ideology of Respondent", size(2.5)) ytitle("Percentage of Observations", axis(2) size(2))
     		xscale(titlegap(4)) yscale(titlegap(4)) 
		|| function y = 0, range(0 7) clpatter(shortdash) color(black) 
		||,   
			xlabel(1 2 3 4 5 6 7, tlcolor(black) labcolor(black) labsize(2))
	    	ylabel(-1 0 1 2 3 4 5 6, tlcolor(black) labcolor(black) axis(1) labsize(2)) 
	    	ylabel(0 5 10 15 20 25 30 35, axis(2)  tlcolor(gs13) labcolor(gs13) labsize(2))
	    	yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)  
	    	xsca(titlegap(2)) ysca(titlegap(2)) scheme(burd);
	    
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Information about percentage of observations in different		*;
*		regions based on marginal effect plot.							*;
*     ****************************************************************  *;
*     ****************************************************************  *;

sum left_right;
scalar total = r(N);
di total;

sum left_right if left_right>1.1;
scalar more = r(N);
di more;

di (more/total)*100;

drop MV conbx consx upperx lowerx;

*     ****************************************************************  *;
*		Get data for histograms	to be used in Figure 9.4				*;
*     ****************************************************************  *;

sort left_right;

sum black if black==1 & left_right~=.;

sum left_right if black~=.;

by left_right: tab black;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 9.5 in Stata showing how the 		*;
*		effect of a one unit increase in ideology on the probability of	*;
*		different approval categories for Obama by race					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

preserve;

set seed 339487731;

drawnorm MG_b1-MG_b9, n(1000) means(e(b)) cov(e(V)) clear;

save simulated_betas, replace;

restore;

merge using simulated_betas;

summarize _merge;

drop _merge;

summarize;

*     ****************************************************************  *;
*		Calculate the marginal of left_right on the probability of 		*;
*		different approval categories for whites and blacks	when age is *;
*		45, female is 1, and worse off is 3.							*;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		Set values of some of the variables								*;
*     ****************************************************************  *;

scalar h_economyworse = 3;
scalar h_age = 45;
scalar h_black = 1;
scalar h_female = 1;
scalar h_white = 0;
scalar h_left_right = 3;
rename MG_b7 tau1;
rename MG_b8 tau2;
rename MG_b9 tau3;

*ologit obama_approval left_right black black_leftright worse_off_national female age;

*     ****************************************************************  *;
*		Create a 8 x 3 matrix to store inputs for creating plot			*;
*     ****************************************************************  *;

matrix plot2 = J(8, 3, .);
matrix coln plot2 = estimate ci_lo ci_hi;

*     ****************************************************************  *;
*		Baseline scenarios 												*;
*     ****************************************************************  *;

* Whites;

generate xb_white = MG_b1*h_left_right + MG_b2*h_white + MG_b3*h_left_right*h_white
            + MG_b4*h_economyworse+ MG_b5*h_female+MG_b6*h_age;
            
gen me_w = MG_b1+MG_b3*h_white;

* Blacks;
            
generate xb_black = MG_b1*h_left_right + MG_b2*h_black + MG_b3*h_left_right*h_black
            + MG_b4*h_economyworse+ MG_b5*h_female+MG_b6*h_age;
            
gen me_b = MG_b1+MG_b3*h_black;
          
*     ****************************************************************  *;
*		Marginal effect of left_right for Strong Disapproval 			*;
*		(category 1)													*;
*     ****************************************************************  *;

* Whites;

gen me_whites1 = (exp(tau1-xb_white)/((1+exp(tau1-xb_white))*(1+exp(tau1-xb_white))))*-me_w;

sum me_whites1;
matrix plot2[1,1]=r(mean);

centile me_whites1, centile(2.5 97.5);
matrix plot2[1,2]=r(c_1);
matrix plot2[1,3]=r(c_2);

* Blacks;

gen me_blacks1 = (exp(tau1-xb_black)/((1+exp(tau1-xb_black))*(1+exp(tau1-xb_black))))*-me_b;

sum me_blacks1;
matrix plot2[2,1]=r(mean);

centile me_blacks1, centile(2.5 97.5);
matrix plot2[2,2]=r(c_1);
matrix plot2[2,3]=r(c_2);

* interaction effect *;

gen int_effect1=me_blacks1-me_whites1;
gen ratio1 = me_whites1/me_blacks1;
sum int_effect1 ratio1;
centile int_effect1 ratio1, centile(2.5 97.5);

*     ****************************************************************  *;
*		Marginal effect of left_right for Disapproval (category 2)		*;
*     ****************************************************************  *;

* Whites;

gen me_whites2 = ((exp(tau1-xb_white)/((1+exp(tau1-xb_white))*(1+exp(tau1-xb_white))))*me_w)-((exp(tau2-xb_white)/((1+exp(tau2-xb_white))*(1+exp(tau2-xb_white))))*me_w);

sum me_whites2;
matrix plot2[3,1]=r(mean);

centile me_whites2, centile(2.5 97.5);
matrix plot2[3,2]=r(c_1);
matrix plot2[3,3]=r(c_2);

* Blacks *;

gen me_blacks2 = ((exp(tau1-xb_black)/((1+exp(tau1-xb_black))*(1+exp(tau1-xb_black))))*me_b)- ((exp(tau2-xb_black)/((1+exp(tau2-xb_black))*(1+exp(tau2-xb_black))))*me_b);

sum me_blacks2;
matrix plot2[4,1]=r(mean);

centile me_blacks2, centile(2.5 97.5);
matrix plot2[4,2]=r(c_1);
matrix plot2[4,3]=r(c_2);

* interaction effect *;

gen int_effect2=me_blacks2-me_whites2;
gen ratio2 = me_whites2/me_blacks2;
sum int_effect2 ratio2;
centile int_effect2 ratio2, centile(2.5 97.5);

*     ****************************************************************  *;
*		Marginal effect of left_right for Approval (category 3)			*;
*     ****************************************************************  *;

* Whites;

gen me_whites3 = ((exp(tau2-xb_white)/((1+exp(tau2-xb_white))*(1+exp(tau2-xb_white))))*me_w)-((exp(tau3-xb_white)/((1+exp(tau3-xb_white))*(1+exp(tau3-xb_white))))*me_w);

sum me_whites3;
matrix plot2[5,1]=r(mean);

centile me_whites3, centile(2.5 97.5);
matrix plot2[5,2]=r(c_1);
matrix plot2[5,3]=r(c_2);

* Blacks;

gen me_blacks3 = ((exp(tau2-xb_black)/((1+exp(tau2-xb_black))*(1+exp(tau2-xb_black))))*me_b)- ((exp(tau3-xb_black)/((1+exp(tau3-xb_black))*(1+exp(tau3-xb_black))))*me_b);

sum me_blacks3;
matrix plot2[6,1]=r(mean);

centile me_blacks3, centile(2.5 97.5);
matrix plot2[6,2]=r(c_1);
matrix plot2[6,3]=r(c_2);

* interaction effect *;

gen int_effect3=me_blacks3-me_whites3;
gen ratio3 = me_whites3/me_blacks3;
sum int_effect3 ratio3;
centile int_effect3 ratio3, centile(2.5 97.5);

*     ****************************************************************  *;
*		Marginal effect of left_right for Strong Approval (category 4)	*;
*     ****************************************************************  *;

* Whites;

gen me_whites4 = (exp(tau3-xb_white)/((1+exp(tau3-xb_white))*(1+exp(tau3-xb_white))))*me_w;

sum me_whites4;
matrix plot2[7,1]=r(mean);

centile me_whites4, centile(2.5 97.5);
matrix plot2[7,2]=r(c_1);
matrix plot2[7,3]=r(c_2);

* Blacks;

gen me_blacks4 = (exp(tau3-xb_black)/((1+exp(tau3-xb_black))*(1+exp(tau3-xb_black))))*me_b;

sum me_blacks4;
matrix plot2[8,1]=r(mean);

centile me_blacks4, centile(2.5 97.5);
matrix plot2[8,2]=r(c_1);
matrix plot2[8,3]=r(c_2);

* interaction effect *;

gen int_effect4=me_blacks4-me_whites4;
gen ratio4 = me_whites4/me_blacks4;
sum int_effect4 ratio4;
centile int_effect4 ratio4, centile(2.5 97.5);

matrix list plot2;

*     ****************************************************************  *;
*		Produce Figure 9.5 using coefplot								*;
*     ****************************************************************  *;


coefplot (matrix(plot2[.,1]), ci((plot2[.,2] plot2[.,3])) offset(0) lwidth(thick) 
		m(smcircle) msize(vsmall) mfcolor("126 163 204") mlc("126 163 204") ciop(lcolor("126 163 204")))||, 
		legend(off) xtitle("Marginal Effect of Liberal-Conservative", size(2)) levels(95) 
		xlab(-0.25 -0.2 -0.15 -0.1 -0.05 0 0.05 0.1 0.15, tlcolor(black) labcolor(black) labsize(2) format(%9.2f) ) 		
		coeflabels(r1="Strong Disapproval: Whites" r2="Strong Disapproval: Blacks" 
		r3="Disapproval: Whites" r4="Disapproval: Blacks" r5="Approval: Whites" r6="Approval: Blacks"
		r7="Strong Approval: Whites" r8="Strong Approval: Blacks", tlcolor(black) labcolor(black) labsize(2)) 
		yscale(noline) xscale(noline) mlabel format(%9.3f) mlabposition(12) mlabgap(*2) mlabsize(2)  
		xline(0, lcolor(gray)) scheme(burd);
		
*     ****************************************************************  *;
*     ****************************************************************  *;
*		Calculate the information to go in Table 9.2 examining the 		*;
*		effect of a one unit increase in ideology on the probability of	*;
*		different approval categories for Obama by race					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		We already have our baseline scenarios. Let's get our 			*;
*		counterfactual scenarios.										*;
*     ****************************************************************  *;

generate xb_white_c = MG_b1*(h_left_right+1) + MG_b2*h_white + MG_b3*(h_left_right+1)*h_white
            + MG_b4*h_economyworse+ MG_b5*h_female+MG_b6*h_age;
            
generate xb_black_c = MG_b1*(h_left_right+1) + MG_b2*h_black + MG_b3*(h_left_right+1)*h_black
            + MG_b4*h_economyworse+ MG_b5*h_female+MG_b6*h_age;
            
*     ****************************************************************  *;
*		Effect of one unit increase in left_right for Strong 			*;
*		Disapproval (category 1)										*;
*     ****************************************************************  *;

* Whites *;

gen prob_whites1b= (exp(tau1-xb_white))/(1+exp(tau1-xb_white));

gen prob_whites1c= (exp(tau1-xb_white_c))/(1+exp(tau1-xb_white_c));

gen diff_whites1= prob_whites1c-prob_whites1b;

gen percent_whites1= (diff_whites1/prob_whites1b)*100;

sum prob_whites1b prob_whites1c diff_whites1 percent_whites1;

centile prob_whites1b prob_whites1c diff_whites1 percent_whites1, centile(2.5 97.5);

* Blacks *;

gen prob_blacks1b= (exp(tau1-xb_black))/(1+exp(tau1-xb_black));

gen prob_blacks1c= (exp(tau1-xb_black_c))/(1+exp(tau1-xb_black_c));

gen diff_blacks1= prob_blacks1c-prob_blacks1b;

gen percent_blacks1= (diff_blacks1/prob_blacks1b)*100;

sum prob_blacks1b prob_blacks1c diff_blacks1 percent_blacks1;

centile prob_blacks1b prob_blacks1c diff_blacks1 percent_blacks1, centile(2.5 97.5);

* Interaction Effect *;

gen diffb1=prob_blacks1b-prob_whites1b;
gen diffc1=prob_blacks1c-prob_whites1c;

sum diffb1 diffc1;
centile diffb1 diffc1, centile(2.5 97.5);

gen interaction_effect1 = diff_blacks1 - diff_whites1;
gen percent_interaction_effect1 = (1-(percent_blacks1/percent_whites1))*100;

sum interaction_effect1 percent_interaction_effect1;
centile interaction_effect1 percent_interaction_effect1, centile(2.5 97.5);

*     ****************************************************************  *;
*		Effect of one unit increase in left_right for Disapproval		*;
*		(category 2)													*;
*     ****************************************************************  *;

* Whites *;

gen prob_whites2b= ((exp(tau2-xb_white))/(1+exp(tau2-xb_white))) - ((exp(tau1-xb_white))/(1+exp(tau1-xb_white)));

gen prob_whites2c = ((exp(tau2-xb_white_c))/(1+exp(tau2-xb_white_c))) - ((exp(tau1-xb_white_c))/(1+exp(tau1-xb_white_c)));

gen diff_whites2= prob_whites2c-prob_whites2b;

gen percent_whites2= (diff_whites2/prob_whites2b)*100;

sum prob_whites2b prob_whites2c diff_whites2 percent_whites2;

centile prob_whites2b prob_whites2c diff_whites2 percent_whites2, centile(2.5 97.5);

* Blacks *;

gen prob_blacks2b= ((exp(tau2-xb_black))/(1+exp(tau2-xb_black))) - ((exp(tau1-xb_black))/(1+exp(tau1-xb_black)));

gen prob_blacks2c = ((exp(tau2-xb_black_c))/(1+exp(tau2-xb_black_c))) - ((exp(tau1-xb_black_c))/(1+exp(tau1-xb_black_c)));

gen diff_blacks2= prob_blacks2c-prob_blacks2b;

gen percent_blacks2= (diff_blacks2/prob_blacks2b)*100;

sum prob_blacks2b prob_blacks2c diff_blacks2 percent_blacks2;

centile prob_blacks2b prob_blacks2c diff_blacks2 percent_blacks2, centile(2.5 97.5);

* Interaction Effect *;

gen diffb2=prob_blacks2b-prob_whites2b;
gen diffc2=prob_blacks2c-prob_whites2c;

sum diffb2 diffc2;
centile diffb2 diffc2, centile(2.5 97.5);

gen interaction_effect2 = diff_blacks2 - diff_whites2;
gen percent_interaction_effect2 = (1-(percent_blacks2/percent_whites2))*100;

sum interaction_effect2 percent_interaction_effect2;
centile interaction_effect2 percent_interaction_effect2, centile(2.5 97.5);

*     ****************************************************************  *;
*		Effect of one unit increase in left_right for Approval			*;
*		(category 3)													*;
*     ****************************************************************  *;

* Whites *;

gen prob_whites3b= ((exp(tau3-xb_white))/(1+exp(tau3-xb_white))) - ((exp(tau2-xb_white))/(1+exp(tau2-xb_white)));

gen prob_whites3c = ((exp(tau3-xb_white_c))/(1+exp(tau3-xb_white_c))) - ((exp(tau2-xb_white_c))/(1+exp(tau2-xb_white_c)));

gen diff_whites3= prob_whites3c-prob_whites3b;

gen percent_whites3= (diff_whites3/prob_whites3b)*100;

sum prob_whites3b prob_whites3c diff_whites3 percent_whites3;

centile prob_whites3b prob_whites3c diff_whites3 percent_whites3, centile(2.5 97.5);

*     ****************************************************************  *;
*     ****************************************************************  *;
*		So, marginal effect of left-right on category 3 for whites is	*;
*		positive but the effect of a one unit increase in left-right	*;
*		is negative. To check this is correct, I calculated the 		*;
*		marginal effect again using a different formula using Lambda 	*;
*		instead of lambda. It seems to be correct.						*;
*     ****************************************************************  *;
*     ****************************************************************  *;

gen t2=(exp(tau2-xb_white))/(1+exp(tau2-xb_white));

gen t3=(exp(tau3-xb_white))/(1+exp(tau3-xb_white));

gen me = ((t2*(1-t2))-(t3*(1-t3)))*MG_b1;

sum me;

centile me, centile(2.5 97.5);

*     ****************************************************************  *;
*     ****************************************************************  *;

* Blacks *;

gen prob_blacks3b= ((exp(tau3-xb_black))/(1+exp(tau3-xb_black))) - ((exp(tau2-xb_black))/(1+exp(tau2-xb_black)));

gen prob_blacks3c = ((exp(tau3-xb_black_c))/(1+exp(tau3-xb_black_c))) - ((exp(tau2-xb_black_c))/(1+exp(tau2-xb_black_c)));

gen diff_blacks3= prob_blacks3c-prob_blacks3b;

gen percent_blacks3= (diff_blacks3/prob_blacks3b)*100;

sum prob_blacks3b prob_blacks3c diff_blacks3 percent_blacks3;

centile prob_blacks3b prob_blacks3c diff_blacks3 percent_blacks3, centile(2.5 97.5);

* Interaction Effect *;

gen diffb3=prob_blacks3b-prob_whites3b;
gen diffc3=prob_blacks3c-prob_whites3c;

sum diffb3 diffc3;
centile diffb3 diffc3, centile(2.5 97.5);

gen interaction_effect3 = diff_blacks3 - diff_whites3;
gen percent_interaction_effect3 = (1-(percent_blacks3/percent_whites3))*100;

sum interaction_effect3 percent_interaction_effect3;
centile interaction_effect3 percent_interaction_effect3, centile(2.5 97.5);

*     ****************************************************************  *;
*		Effect of one unit increase in left_right for Strong Approval	*;
*		(category 4)													*;
*     ****************************************************************  *;

* Whites *;

gen prob_whites4b= 1-((exp(tau3-xb_white))/(1+exp(tau3-xb_white)));

gen prob_whites4c= 1-((exp(tau3-xb_white_c))/(1+exp(tau3-xb_white_c)));

gen diff_whites4= prob_whites4c-prob_whites4b;

gen percent_whites4= (diff_whites4/prob_whites4b)*100;

sum prob_whites4b prob_whites4c diff_whites4 percent_whites4;

centile prob_whites4b prob_whites4c diff_whites4 percent_whites4, centile(2.5 97.5);

* Blacks *;

gen prob_blacks4b= 1-((exp(tau3-xb_black))/(1+exp(tau3-xb_black)));

gen prob_blacks4c= 1-((exp(tau3-xb_black_c))/(1+exp(tau3-xb_black_c)));

gen diff_blacks4= prob_blacks4c-prob_blacks4b;

gen percent_blacks4= (diff_blacks4/prob_blacks4b)*100;

sum prob_blacks4b prob_blacks4c diff_blacks4 percent_blacks4;

centile prob_blacks4b prob_blacks4c diff_blacks4 percent_blacks4, centile(2.5 97.5);

* Interaction Effect *;

gen diffb4=prob_blacks4b-prob_whites4b;
gen diffc4=prob_blacks4c-prob_whites4c;

sum diffb4 diffc4;
centile diffb4 diffc4, centile(2.5 97.5);

gen interaction_effect4 = diff_blacks4 - diff_whites4;
gen percent_interaction_effect4 = (1-(percent_blacks4/percent_whites4))*100;

sum interaction_effect4 percent_interaction_effect4;
centile interaction_effect4 percent_interaction_effect4, centile(2.5 97.5);


*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce a figure like Figure 9.6 in Stata showing how the 		*;
*		factor change associated with being Black in the odds of an 	*;
*		approval category greater than some category k versus a lower	*;
*		approval category varies across different levels of 			*;
*		conservative ideology											*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*		We'll use Stata's lincom command to get odds ratios				*;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

lincom (_b[black]+_b[black_leftright]*1), or;
scalar low = r(estimate);
di low;

lincom (_b[black]+_b[black_leftright]*7), or;
scalar hi = r(estimate);
di hi;

di  hi/low;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\sim.dta", replace;	
		
noisily display "start";

ologit obama_approval left_right black black_leftright worse_off_national female age;

local a=0 ;
while `a' <= 7.1 { ;
{;

lincom (_b[black]+_b[black_leftright]*`a'), or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\sim.dta";

gen yline=1;

gen MV = (_n-1)/10;

replace MV=. if _n>71;

*     ****************************************************************  *;
*		Produce Figure 9.6												*;
*     ****************************************************************  *;

graph twoway hist left_right, percent color(gs13) yaxis(2)
		|| line odds_hat MV , clwidth(medthick) clcolor(blue) clcolor(black)
		|| line odds_lo MV , clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| line odds_hi MV , clpattern(longdash) clwidth(thin) clcolor(ebblue)
		|| ,
			xlabel(1 2 3 4 5 6 7, nogrid labsize(2))
			ylabel(0 5 10 15 20 25 30 35, axis(2) nogrid labsize(2))
			ylabel(0 50 100 150 200 250 300, axis(1) nogrid labsize(2))
			yscale(noline alt) yscale(noline alt axis(2)) xscale(noline) legend(off)
			yline(0, lcolor(black))
			ytitle("Factor Change in the Odds of Y > k", size(2))
			ytitle("Percentage of Respondents", color(gs12) axis(2) size(2))
			title("", size(3)) subtitle("", size(3)) xtitle("Liberal-Conservative Ideology of Respondent", size(2)) xscale(titlegap(2)) yscale(titlegap(2)) scheme(burd);
			
log close;

clear;