version 16.0
log using "/Users/mrg19/Dropbox/InteractionsBook/replications/chapter9_application/approval_collectdata.log", replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      approval_collectdata.do                   		*;
*       Date:           August 23, 2022                                 *;
*       Author:         MG                                          	*;
*       Purpose:      	Collect data necessary to help produce some of	*;
*						the figures in Chapter9							*;
* 	    Input File:     anes2012_small.dta       		                *;
*       Output File:    approval_collectdata.log                        *;
*       Data Output:    odds.csv                                        *;             
*       Previous file:  					     						*;
*       Machine:        desktop/laptop                     				*;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*        Load data                                                      *;
*     ****************************************************************  *;

use "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\anes2012_small.dta", clear;

*     ****************************************************************  *;
*           Variable description                  						*;
*     ****************************************************************  *;

desc;

sum;

*     ****************************************************************  *;
*       Drop respondents who are not white or black						*;
*     ****************************************************************  *;

keep if white==1 | black==1;

sum;

*     ****************************************************************  *;
*		Generate interaction term for race and ideology					*;
*     ****************************************************************  *;

gen black_leftright=black*left_right;

*     ****************************************************************  *;
*     ****************************************************************  *;
*		Produce results shown in Table 9.1 in Chapter 9					*;
*     ****************************************************************  *;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

*     ****************************************************************  *;
*		We'll use Stata's lincom command to get odds ratios				*;
*     ****************************************************************  *;

ologit obama_approval left_right black black_leftright worse_off_national female age;

preserve;

postutil clear;

postfile mypost odds_hat odds_lo odds_hi 	
		using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\sim.dta", replace;	
		
noisily display "start";

ologit obama_approval left_right black black_leftright worse_off_national female age;

local a=0 ;
while `a' <= 7.1 { ;
{;

lincom (_b[black]+_b[black_leftright]*`a'), or;

tempname odds_hat odds_lo odds_hi;

scalar `odds_lo' = r(lb);
scalar `odds_hi' = r(ub);
scalar `odds_hat'=r(estimate);

post mypost (`odds_hat') (`odds_lo') (`odds_hi');

};
		
local a=`a'+ 0.1;

display "." _c;

} ;

display "";

postclose mypost;

restore;

merge using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\sim.dta";

gen yline=1;

gen MV = (_n-1)/10;

replace MV=. if _n>71;

gen odds_percent=(odds_hat-1)*100;
gen odds_percent_lo=(odds_lo-1)*100;
gen odds_percent_hi=(odds_hi-1)*100;

keep MV odds_hat odds_lo odds_hi odds_percent odds_percent_lo odds_percent_hi;
    
order MV;
  
drop if _n>71;

drop if _n<11;

outsheet using "C:\Users\mrg19\Dropbox\InteractionsBook\replications\chapter9_application\odds.csv", comma nonames replace;

log close;

clear;